@@ -30,14 +30,16 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <ctype.h>
 #ifndef IS_MINGW
 #ifndef IS_SOLARIS
 #include <endian.h>
 #endif
 #endif
 #include <sys/stat.h>
+#include <pthread.h>
 
-const char *plugin_version="LiVES asf/wmv decoder version 1.0";
+const char *plugin_version="LiVES asf/wmv decoder version 1.1";
 
 #ifdef HAVE_AV_CONFIG_H
 #undef HAVE_AV_CONFIG_H
@@ -57,11 +59,36 @@ const char *plugin_version="LiVES asf/wmv decoder version 1.0";
 #endif
 
 #include <libavformat/avformat.h>
+#include <libavcodec/version.h>
 #include <libavutil/avstring.h>
 
 #include "decplugin.h"
 #include "asf_decoder.h"
 
+#if (LIBAVCODEC_VERSION_MAJOR > 54)
+#define CodecID AVCodecID
+#define CODEC_ID_NONE AV_CODEC_ID_NONE
+#define CODEC_ID_WMV1 AV_CODEC_ID_WMV1
+#define CODEC_ID_WMV2 AV_CODEC_ID_WMV2
+#define CODEC_ID_WMV3 AV_CODEC_ID_WMV3
+#define CODEC_ID_DVVIDEO AV_CODEC_ID_DVVIDEO
+#define CODEC_ID_MPEG4 AV_CODEC_ID_MPEG4
+#define CODEC_ID_H264 AV_CODEC_ID_H264
+#define CODEC_ID_MPEG1VIDEO AV_CODEC_ID_MPEG1VIDEO
+#define CODEC_ID_MPEG2VIDEO AV_CODEC_ID_MPEG2VIDEO
+#endif
+
+#if !HAVE_AVCODEC_OPEN2
+#define avcodec_open2(a, b, c) avcodec_open(a, b)
+#endif
+
+#if HAVE_AVFORMAT_NEW_STREAM
+#define av_new_stream(a, b) avformat_new_stream(a, NULL)
+#endif
+
+#if HAVE_AVPRIV_SET_PTS_INFO
+#define av_set_pts_info(a,b,c,d) avpriv_set_pts_info(a,b,c,d)
+#endif
 
 static enum CodecID ff_codec_get_id(const AVCodecTag *tags, unsigned int tag)
 {
@@ -80,6 +107,10 @@ static enum CodecID ff_codec_get_id(const AVCodecTag *tags, unsigned int tag)
   return CODEC_ID_NONE;
 }
 
+static index_container_t **indices;
+static int nidxc;
+static pthread_mutex_t indices_mutex;
+static pthread_mutexattr_t mattr;
 
 
 ////////////////////////////////////////////////////////////////////////////
@@ -363,7 +394,7 @@ static index_entry *add_keyframe(const lives_clip_data_t *cdata, int64_t offs, i
   lives_asf_priv_t *priv=cdata->priv;
   index_entry *idx,*lidx,*nidx;
 
-  lidx=idx=priv->idx;
+  lidx=idx=priv->idxc->idx;
 
   while (idx!=NULL) {
     if (idx->dts==dts) return idx; // already indexed
@@ -371,7 +402,7 @@ static index_entry *add_keyframe(const lives_clip_data_t *cdata, int64_t offs, i
       // insert before idx
       nidx=idx_alloc(offs,frag,dts);
       nidx->next=idx;
-      if (idx==priv->idx) priv->idx=nidx;
+      if (idx==priv->idxc->idx) priv->idxc->idx=nidx;
       else lidx->next=nidx;
       return nidx;
     }
@@ -384,7 +415,7 @@ static index_entry *add_keyframe(const lives_clip_data_t *cdata, int64_t offs, i
   nidx=idx_alloc(offs,frag,dts);
 
   if (lidx!=NULL) lidx->next=nidx;
-  else priv->idx=nidx;
+  else priv->idxc->idx=nidx;
 
   nidx->next=NULL;
 
@@ -666,7 +697,10 @@ static int get_next_video_packet(const lives_clip_data_t *cdata, int tfrag, int6
 #endif
 
 	if (asf->packet_key_frame&&asf->packet_frag_offset==0&&priv->have_start_dts) {
+	  pthread_mutex_lock(&priv->idxc->mutex);
 	  priv->kframe=add_keyframe(cdata,priv->hdr_start,priv->fragnum,asf->packet_frag_timestamp-priv->start_dts);
+	  pthread_mutex_unlock(&priv->idxc->mutex);
+
 #ifdef DEBUG
 	  printf("and is keyframe !\n");
 #endif
@@ -735,7 +769,7 @@ static int get_next_video_packet(const lives_clip_data_t *cdata, int tfrag, int6
     // no more fragments left, skip remainder of asf packet
 
 #ifdef DEBUG
-    printf("skipping %d %ld\n",asf->packet_size_left + asf->packet_padsize - 2, asf->packet_padsize);
+    //printf("skipping %d %ld\n",asf->packet_size_left + asf->packet_padsize - 2, asf->packet_padsize);
 #endif
 
     priv->input_position+=asf->packet_size_left + asf->packet_padsize - 2;
@@ -749,8 +783,8 @@ static int get_next_video_packet(const lives_clip_data_t *cdata, int tfrag, int6
 
 static index_entry *get_idx_for_pts(const lives_clip_data_t *cdata, int64_t pts) {
   lives_asf_priv_t *priv=cdata->priv;
-  int64_t tdts=pts-priv->start_dts;
-  index_entry *idx=priv->idx,*lidx=idx;
+  int64_t tdts=pts;
+  index_entry *idx=priv->idxc->idx,*lidx=idx;
   int ret;
 
   while (idx!=NULL) {
@@ -774,7 +808,9 @@ static int get_last_video_dts(const lives_clip_data_t *cdata) {
   // get last vido frame dts (relative to start dts)
   lives_asf_priv_t *priv=cdata->priv;
 
+  pthread_mutex_lock(&priv->idxc->mutex);
   priv->kframe=get_idx_for_pts(cdata,frame_to_dts(cdata,0)-priv->start_dts);
+  pthread_mutex_unlock(&priv->idxc->mutex);
   // this will parse through the file, adding keyframes, until we reach EOF
 
   priv->input_position=priv->kframe->offs;
@@ -788,6 +824,109 @@ static int get_last_video_dts(const lives_clip_data_t *cdata) {
 
 //////////////////////////////////////////////
 
+static index_container_t *idxc_for(lives_clip_data_t *cdata) {
+  // check all idxc for string match with URI
+  index_container_t *idxc;
+  register int i;
+
+  pthread_mutex_lock(&indices_mutex);
+
+  for (i=0;i<nidxc;i++) {
+    if (indices[i]->clients[0]->current_clip==cdata->current_clip&&
+	!strcmp(indices[i]->clients[0]->URI,cdata->URI)) {
+      idxc=indices[i];
+      // append cdata to clients
+      idxc->clients=(lives_clip_data_t **)realloc(idxc->clients,(idxc->nclients+1)*sizeof(lives_clip_data_t *));
+      idxc->clients[idxc->nclients]=cdata;
+      idxc->nclients++;
+      //
+      pthread_mutex_unlock(&indices_mutex);
+      return idxc;
+    }
+  }
+
+  indices=(index_container_t **)realloc(indices,(nidxc+1)*sizeof(index_container_t *));
+
+  // match not found, create a new index container
+  idxc=(index_container_t *)malloc(sizeof(index_container_t));
+
+  idxc->idx=NULL;
+
+  idxc->nclients=1;
+  idxc->clients=(lives_clip_data_t **)malloc(sizeof(lives_clip_data_t *));
+  idxc->clients[0]=cdata;
+
+  pthread_mutex_init(&idxc->mutex,&mattr);
+
+  indices[nidxc]=idxc;
+  pthread_mutex_unlock(&indices_mutex);
+
+  nidxc++;
+
+  return idxc;
+}
+
+
+static void idxc_release(lives_clip_data_t *cdata) {
+  lives_asf_priv_t *priv=cdata->priv;
+  index_container_t *idxc=priv->idxc;
+  register int i,j;
+
+  if (idxc==NULL) return;
+
+  pthread_mutex_lock(&indices_mutex);
+
+  if (idxc->nclients==1) {
+    // remove this index
+    index_free(idxc->idx);
+    free(idxc->clients);
+    for (i=0;i<nidxc;i++) {
+      if (indices[i]==idxc) {
+	nidxc--;
+	for (j=i;j<nidxc;j++) {
+	  indices[j]=indices[j+1];
+	}
+	free(idxc);
+	if (nidxc==0) {
+	  free(indices);
+	  indices=NULL;
+	}
+	else indices=(index_container_t **)realloc(indices,nidxc*sizeof(index_container_t *));
+	break;
+      }
+    }
+  }
+  else {
+    // reduce client count by 1
+    for (i=0;i<idxc->nclients;i++) {
+      if (idxc->clients[i]==cdata) {
+	// remove this entry
+	idxc->nclients--;
+	for (j=i;j<idxc->nclients;j++) {
+	  idxc->clients[j]=idxc->clients[j+1];
+	}
+	idxc->clients=(lives_clip_data_t **)realloc(idxc->clients,idxc->nclients*sizeof(lives_clip_data_t *));
+	break;
+      }
+    }
+  }
+
+  pthread_mutex_unlock(&indices_mutex);
+
+}
+
+
+static void idxc_release_all(void) {
+  register int i;
+
+  for (i=0;i<nidxc;i++) {
+    index_free(indices[i]->idx);
+    free(indices[i]->clients);
+    free(indices[i]);
+  }
+  nidxc=0;
+}
+
 
 static void detach_stream (lives_clip_data_t *cdata) {
   // close the file, free the decoder
@@ -796,6 +935,8 @@ static void detach_stream (lives_clip_data_t *cdata) {
   cdata->seek_flag=0;
 
   if (priv->avpkt.data!=NULL) free(priv->avpkt.data);
+  priv->avpkt.data=NULL;
+  priv->avpkt.size=0;
 
   if (priv->ctx!=NULL) {
     avcodec_close(priv->ctx);
@@ -807,11 +948,6 @@ static void detach_stream (lives_clip_data_t *cdata) {
   priv->ctx=NULL;
   priv->picture=NULL;
   
-  if (priv->idx!=NULL) 
-    index_free(priv->idx);
-
-  priv->idx=NULL;
-
   if (cdata->palettes!=NULL) free(cdata->palettes);
   cdata->palettes=NULL;
 
@@ -832,16 +968,20 @@ static void detach_stream (lives_clip_data_t *cdata) {
 
 
 
-static boolean attach_stream(lives_clip_data_t *cdata) {
+static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
   // open the file and get metadata
   lives_asf_priv_t *priv=cdata->priv;
   char header[16];
   unsigned char buffer[4096];
   unsigned char flags;
+
   int i,len,retval;
   int size;
+
   boolean got_vidst=FALSE;
   boolean got_picture=FALSE;
+  boolean gotframe2=FALSE;
+  boolean is_partial_clone=FALSE;
 
   double fps;
 
@@ -849,7 +989,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   AVCodecContext *ctx;
   AVStream *vidst=NULL;
 
-  int64_t pts=AV_NOPTS_VALUE;
+  int64_t pts=AV_NOPTS_VALUE,pts2=pts;
   int64_t gsize;
   int64_t ftime;
 
@@ -866,6 +1006,13 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   fprintf(stderr,"\n");
 #endif
 
+  if (isclone&&!priv->inited) {
+    isclone=FALSE;
+    if (cdata->fps>0.&&cdata->nframes>0)
+      is_partial_clone=TRUE;
+  }
+
+
   if ((priv->fd=open(cdata->URI,O_RDONLY))==-1) {
     fprintf(stderr, "asf_decoder: unable to open %s\n",cdata->URI);
     return FALSE;
@@ -875,6 +1022,12 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   setmode(priv->fd,O_BINARY);
 #endif
 
+  if (isclone) {
+    lseek(priv->fd, ASF_PROBE_SIZE+14, SEEK_SET);
+    priv->input_position=ASF_PROBE_SIZE+14;
+    goto seek_skip;
+  }
+
   if (read (priv->fd, header, ASF_PROBE_SIZE) < ASF_PROBE_SIZE) {
     // for example, might be a directory
 #ifdef DEBUG
@@ -889,7 +1042,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   // test header
   if (guidcmp(header, &lives_asf_header)) {
 #ifdef DEBUG
-    fprintf(stderr, "asf_decoder: not asf header %32x and %32x for %s\n",*header,*lives_asf_header,cdata->URI);
+    fprintf(stderr, "asf_decoder: not asf header\n");
 #endif
     close(priv->fd);
     return FALSE;
@@ -910,28 +1063,31 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   cdata->asamps=0;
   sprintf(cdata->audio_name,"%s","");
 
-  priv->idx=NULL;
-
   cdata->seek_flag=LIVES_SEEK_FAST|LIVES_SEEK_NEEDS_CALCULATION;
 
   cdata->offs_x=0;
   cdata->offs_y=0;
 
+  fstat(priv->fd,&sb);
+  priv->filesize=sb.st_size;
+
+ seek_skip:
+
+  priv->idxc=idxc_for(cdata);
+
   priv->asf=(ASFContext *)malloc(sizeof(ASFContext));
   memset(&priv->asf->asfid2avid, -1, sizeof(priv->asf->asfid2avid));
   priv->s = avformat_alloc_context();
   priv->s->priv_data=priv->asf;
   av_init_packet(&priv->avpkt);
   priv->avpkt.data=NULL;
+  priv->avpkt.size=0;
   priv->st=NULL;
   priv->asf_st=NULL;
   priv->ctx=NULL;
 
   for (i=0;i<128;i++) dar[i].num=dar[i].den=0;
 
-  fstat(priv->fd,&sb);
-  priv->filesize=sb.st_size;
- 
   for(;;) {
     int64_t gpos=priv->input_position;
 
@@ -1957,6 +2113,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   }
 
 
+  priv->inited=TRUE;
+
   priv->data_start=priv->input_position;
 
   priv->start_dts=0; // will reset this later
@@ -1966,6 +2124,15 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   priv->input_position=priv->data_start;
   lseek(priv->fd,priv->input_position,SEEK_SET);
 
+  priv->ctx=ctx=vidst->codec;
+
+  if (vidst->codec) codec = avcodec_find_decoder(vidst->codec->codec_id);
+
+  if (isclone) {
+    retval=avcodec_open2(vidst->codec, codec, NULL);
+    return TRUE;
+  }
+
   switch(vidst->codec->codec_id) {
   case CODEC_ID_WMV1:
     snprintf(cdata->video_name,16,"wmv1"); break;
@@ -1988,7 +2155,6 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     fprintf(stderr,"add video format %d\n",vidst->codec->codec_id); break;
   }
 
-  if (vidst->codec) codec = avcodec_find_decoder(vidst->codec->codec_id);
 
 #ifdef DEBUG
   fprintf(stderr,"video type is %s %d x %d (%d x %d +%d +%d)\n",cdata->video_name,
@@ -2003,20 +2169,24 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     return FALSE;
   }
 
-  if ((retval=avcodec_open(vidst->codec, codec)) < 0) {
+
+  if ((retval=avcodec_open2(vidst->codec, codec, NULL)) < 0) {
     fprintf(stderr, "asf_decoder: Could not open avcodec context (%d) %d\n",retval,vidst->codec->frame_number);
     detach_stream(cdata);
     return FALSE;
   }
 
-  priv->picture = avcodec_alloc_frame();
 
   priv->input_position=priv->data_start;
   asf_reset_header(priv->s);
 
+  pthread_mutex_lock(&priv->idxc->mutex);
   priv->kframe=add_keyframe(cdata,priv->data_start,0,0);
+  pthread_mutex_unlock(&priv->idxc->mutex);
   priv->def_packet_size=priv->asf->hdr.max_pktsize*10;
 
+  priv->picture = avcodec_alloc_frame();
+
   do {
     if (priv->avpkt.data!=NULL) free(priv->avpkt.data);
     retval = get_next_video_packet(cdata,0,-1);
@@ -2054,7 +2224,10 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   pts=priv->start_dts=priv->frame_dts;
   priv->have_start_dts=TRUE;
+  cdata->video_start_time=(double)pts/10000.;
 
+  cdata->sync_hint=0;
+  //#define DEBUG
 #ifdef DEBUG
   printf("first pts is %ld\n",pts);
 #endif  
@@ -2066,7 +2239,6 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   }
 
 
-
   do {
     free(priv->avpkt.data);
     retval = get_next_video_packet(cdata,-1,-1);
@@ -2088,16 +2260,56 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 	}
 
 	pts=priv->frame_dts-pts;
+	pts2=priv->frame_dts;
 
 #ifdef DEBUG
-	printf("delta pts is %ld\n",pts);
+	printf("delta pts is %ld %ld\n",pts,priv->frame_dts);
 #endif
       
 	if (pts>0) cdata->fps=1000./(double)pts;
+	gotframe2=TRUE;
       }
     }
   } while (retval<0&&retval!=-2);
 
+
+  if (gotframe2) {
+    do {
+      free(priv->avpkt.data);
+      retval = get_next_video_packet(cdata,-1,-1);
+      
+      // try to get dts of second frame
+      if (retval!=-2) { // eof
+	if (retval==0) {
+
+	  if (priv->frame_dts==AV_NOPTS_VALUE) {
+	    break;
+	  }
+
+	  if (priv->asf->packet_time_delta!=0) {
+	    fprintf(stderr, "asf_decoder: packet time delta of (%d) not understood\n",priv->asf->packet_time_delta);
+	    detach_stream(cdata);
+	    return FALSE;
+	  }
+
+	  if (priv->frame_dts-pts2!=pts) {
+	    // 2->3 delta can be more accurate than 1 - 2 delta
+	    pts=priv->frame_dts-pts2;
+	    if (pts>0) cdata->fps=1000./(double)pts;
+	    priv->start_dts=pts2-pts;
+	    priv->have_start_dts=TRUE;
+	    cdata->video_start_time=(double)priv->start_dts/10000.;
+	  }
+
+#ifdef DEBUG
+	  printf("3delta pts is %ld %ld\n",pts,priv->frame_dts);
+#endif
+      
+	}
+      }
+    } while (retval<0&&retval!=-2);
+  }
+
   free(priv->avpkt.data);
   priv->avpkt.data=NULL;
   priv->avpkt.size=0;
@@ -2113,11 +2325,9 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   cdata->YUV_subspace=WEED_YUV_SUBSPACE_YCBCR;
   if (ctx->colorspace==AVCOL_SPC_BT709) cdata->YUV_subspace=WEED_YUV_SUBSPACE_BT709;
 
-  cdata->palettes=(int *)malloc(2*sizeof(int));
 
   cdata->palettes[0]=avi_pix_fmt_to_weed_palette(ctx->pix_fmt,
 						 &cdata->YUV_clamping);
-  cdata->palettes[1]=WEED_PALETTE_END;
 
   if (cdata->palettes[0]==WEED_PALETTE_END) {
     fprintf(stderr, "asf_decoder: Could not find a usable palette for (%d) %s\n",ctx->pix_fmt,cdata->URI);
@@ -2203,6 +2413,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   priv->last_frame=-1;
   priv->black_fill=FALSE;
 
+  if (is_partial_clone) return TRUE;
+
   vidst->duration = get_last_video_dts(cdata);
 
   cdata->nframes = dts_to_frame(cdata,vidst->duration+priv->start_dts)+2;
@@ -2213,6 +2425,10 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     cdata->nframes--;
   }
 
+  if (cdata->width!=cdata->frame_width||cdata->height!=cdata->frame_height)
+    fprintf(stderr,"asf_decoder: info frame size=%d x %d, pixel size=%d x %d\n",cdata->frame_width,cdata->frame_height,cdata->width,cdata->height);
+
+
   return TRUE;
 }
 
@@ -2224,6 +2440,13 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
 const char *module_check_init(void) {
   avcodec_register_all();
+  indices=NULL;
+  nidxc=0;
+
+  pthread_mutexattr_init(&mattr);
+  pthread_mutexattr_settype(&mattr,PTHREAD_MUTEX_RECURSIVE); 
+
+  pthread_mutex_init(&indices_mutex,NULL);
   return NULL;
 }
 
@@ -2247,15 +2470,118 @@ static lives_clip_data_t *init_cdata (void) {
   priv->ctx=NULL;
   priv->picture=NULL;
 
-  cdata->palettes=NULL;
+  cdata->palettes=(int *)malloc(2*sizeof(int));
+  cdata->palettes[1]=WEED_PALETTE_END;
+
+  priv->idxc=NULL;
   
+  priv->inited=FALSE;
+
   cdata->sync_hint=0;
 
+  cdata->video_start_time=0.;
+
+  memset(cdata->author,0,1);
+  memset(cdata->title,0,1);
+  memset(cdata->comment,0,1);
+
   return cdata;
 }
 
 
+static lives_clip_data_t *asf_clone(lives_clip_data_t *cdata) {
+  lives_clip_data_t *clone=init_cdata();
+  lives_asf_priv_t *dpriv,*spriv;
 
+  // copy from cdata to clone, with a new context for clone
+  clone->URI=strdup(cdata->URI);
+  clone->nclips=cdata->nclips;
+  snprintf(clone->container_name,512,"%s",cdata->container_name);
+  clone->current_clip=cdata->current_clip;
+  clone->width=cdata->width;
+  clone->height=cdata->height;
+  clone->nframes=cdata->nframes;
+  clone->interlace=cdata->interlace;
+  clone->offs_x=cdata->offs_x;
+  clone->offs_y=cdata->offs_y;
+  clone->frame_width=cdata->frame_width;
+  clone->frame_height=cdata->frame_height;
+  clone->par=cdata->par;
+  clone->fps=cdata->fps;
+  if (cdata->palettes!=NULL) clone->palettes[0]=cdata->palettes[0];
+  clone->current_palette=cdata->current_palette;
+  clone->YUV_sampling=cdata->YUV_sampling;
+  clone->YUV_clamping=cdata->YUV_clamping;
+  snprintf(clone->video_name,512,"%s",cdata->video_name);
+  clone->arate=cdata->arate;
+  clone->achans=cdata->achans;
+  clone->asamps=cdata->asamps;
+  clone->asigned=cdata->asigned;
+  clone->ainterleaf=cdata->ainterleaf;
+  snprintf(clone->audio_name,512,"%s",cdata->audio_name);
+  clone->seek_flag=cdata->seek_flag;
+  clone->sync_hint=cdata->sync_hint;
+
+  snprintf(clone->author,256,"%s",cdata->author);
+  snprintf(clone->title,256,"%s",cdata->title);
+  snprintf(clone->comment,256,"%s",cdata->comment);
+
+  // create "priv" elements
+  dpriv=clone->priv;
+  spriv=cdata->priv;
+
+  if (spriv!=NULL) {
+    dpriv->filesize=spriv->filesize;
+    dpriv->inited=TRUE;
+  }
+
+  if (!attach_stream(clone,TRUE)) {
+    free(clone->URI);
+    clone->URI=NULL;
+    clip_data_free(clone);
+    return NULL;
+  }
+
+  asf_reset_header(dpriv->s);
+
+  if (spriv!=NULL) {
+    dpriv->def_packet_size=spriv->def_packet_size;
+    dpriv->start_dts=spriv->start_dts;
+    dpriv->have_start_dts=TRUE;
+    dpriv->st->duration=spriv->st->duration;
+
+    dpriv->last_frame=-1;
+    dpriv->black_fill=FALSE;
+  }
+  else {  
+    clone->nclips=1;
+
+    ///////////////////////////////////////////////////////////
+
+    sprintf(clone->container_name,"%s","asf");
+
+    // clone->height was set when we attached the stream
+
+    clone->interlace=LIVES_INTERLACE_NONE;
+
+    clone->frame_width=clone->width+clone->offs_x*2;
+    clone->frame_height=clone->height+clone->offs_y*2;
+
+    if (dpriv->ctx->width==clone->frame_width) clone->offs_x=0;
+    if (dpriv->ctx->height==clone->frame_height) clone->offs_y=0;
+
+    ////////////////////////////////////////////////////////////////////
+
+    clone->asigned=TRUE;
+    clone->ainterleaf=TRUE;
+
+  }
+
+  if (dpriv->picture!=NULL) av_free(dpriv->picture);
+  dpriv->picture=NULL;
+
+  return clone;
+}
 
 
 
@@ -2272,6 +2598,10 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
 
   lives_asf_priv_t *priv;
 
+  if (URI==NULL&&cdata!=NULL) {
+    // create a clone of cdata - we also need to be able to handle a "fake" clone with only URI, nframes and fps set (priv == NULL)
+    return asf_clone(cdata);
+  }
 
   if (cdata!=NULL&&cdata->current_clip>0) {
     // currently we only support one clip per container
@@ -2290,7 +2620,7 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
       free(cdata->URI);
     }
     cdata->URI=strdup(URI);
-    if (!attach_stream(cdata)) {
+    if (!attach_stream(cdata,FALSE)) {
       free(cdata->URI);
       cdata->URI=NULL;
       clip_data_free(cdata);
@@ -2323,6 +2653,9 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
   cdata->asigned=TRUE;
   cdata->ainterleaf=TRUE;
 
+  if (priv->picture!=NULL) av_free(priv->picture);
+  priv->picture=NULL;
+
   return cdata;
 }
 
@@ -2378,18 +2711,24 @@ static size_t write_black_pixel(unsigned char *idst, int pal, int npixels, int y
 boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstrides, int height, void **pixel_data) {
   // seek to frame,
 
-  int64_t nextframe=0;
-  int tfrag=0;
   lives_asf_priv_t *priv=cdata->priv;
+
+  int64_t nextframe=0;
   int64_t target_pts=frame_to_dts(cdata,tframe);
+
+  unsigned char *dst,*src;
+  unsigned char black[4]={0,0,0,255};
+
+  boolean got_picture=FALSE;
+  boolean hit_target=FALSE;
+
+  int tfrag=0;
   int xheight=cdata->frame_height,pal=cdata->current_palette,nplanes=1,dstwidth=cdata->width,psize=1;
   int btop=cdata->offs_y,bbot=xheight-1-btop;
   int bleft=cdata->offs_x,bright=cdata->frame_width-cdata->width-bleft;
   int rescan_limit=16;  // pick some arbitrary value
   int y_black=(cdata->YUV_clamping==WEED_YUV_CLAMPING_CLAMPED)?16:0;
-  boolean got_picture=FALSE;
-  unsigned char *dst,*src;
-  unsigned char black[4]={0,0,0,255};
+
   register int i,p;
 
 #ifdef DEBUG_KFRAMES
@@ -2414,7 +2753,8 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
     
     if (pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) psize=3;
     
-    if (pal==WEED_PALETTE_RGBA32||pal==WEED_PALETTE_BGRA32||pal==WEED_PALETTE_ARGB32||pal==WEED_PALETTE_UYVY8888||pal==WEED_PALETTE_YUYV8888||pal==WEED_PALETTE_YUV888||pal==WEED_PALETTE_YUVA8888) psize=4;
+    if (pal==WEED_PALETTE_RGBA32||pal==WEED_PALETTE_BGRA32||pal==WEED_PALETTE_ARGB32||pal==WEED_PALETTE_UYVY8888||
+	pal==WEED_PALETTE_YUYV8888||pal==WEED_PALETTE_YUV888||pal==WEED_PALETTE_YUVA8888) psize=4;
     
     if (pal==WEED_PALETTE_YUV411) psize=6;
     
@@ -2439,23 +2779,30 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
   if (tframe!=priv->last_frame) {
 
+    if (priv->picture!=NULL) av_free(priv->picture);
+    priv->picture=NULL;
+
     if (priv->last_frame==-1 || (tframe<priv->last_frame) || (tframe - priv->last_frame > rescan_limit)) {
+
       if (priv->avpkt.data!=NULL) free(priv->avpkt.data);
       priv->avpkt.data=NULL;
       priv->avpkt.size=0;
 
+      pthread_mutex_lock(&priv->idxc->mutex);
       if ((priv->kframe=get_idx_for_pts(cdata,target_pts-priv->start_dts))!=NULL) {
 	priv->input_position=priv->kframe->offs;
 	nextframe=dts_to_frame(cdata,priv->kframe->dts+priv->start_dts);
 	tfrag=priv->kframe->frag;
       }
       else priv->input_position=priv->data_start;
+      pthread_mutex_unlock(&priv->idxc->mutex);
 	
       // we are now at the kframe before or at target - parse packets until we hit target
       
-
+      //#define DEBUG_KFRAMES
 #ifdef DEBUG_KFRAMES
-      if (priv->kframe!=NULL) printf("got kframe %ld frag %d for frame %ld\n",dts_to_frame(cdata,priv->kframe->dts+priv->start_dts),priv->kframe->frag,tframe);
+      if (priv->kframe!=NULL) printf("got kframe %ld frag %d for frame %ld\n",
+				     dts_to_frame(cdata,priv->kframe->dts+priv->start_dts),priv->kframe->frag,tframe);
 #endif
 
       avcodec_flush_buffers (priv->ctx);
@@ -2467,17 +2814,15 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
       tfrag=-1;
     }
 
-    priv->ctx->skip_frame=AVDISCARD_NONREF;
+    //priv->ctx->skip_frame=AVDISCARD_NONREF;
 
     priv->last_frame=tframe;
-
-
+ 
     // do this until we reach target frame //////////////
 
-    while (nextframe<=tframe) {
-      int len,ret;
 
-      if (nextframe==tframe) priv->ctx->skip_frame=AVDISCARD_DEFAULT;
+    while (1) {
+      int ret;
 
       if (priv->avpkt.size==0) {
 	ret = get_next_video_packet(cdata,tfrag,-1);
@@ -2496,31 +2841,36 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 	}
       }
 
-#if LIBAVCODEC_VERSION_MAJOR >= 52
-      len=avcodec_decode_video2(priv->ctx, priv->picture, &got_picture, &priv->avpkt );
+
+      // decode any frames from this packet
+      if (priv->picture==NULL) priv->picture=avcodec_alloc_frame();
+
+#if LIBAVCODEC_VERSION_MAJOR >= 53
+      avcodec_decode_video2( priv->ctx, priv->picture, &got_picture, &priv->avpkt );
 #else 
-      len=avcodec_decode_video(priv->ctx, priv->picture, &got_picture, priv->avpkt.data, priv->avpkt.size );
+      avcodec_decode_video( priv->ctx, priv->picture, &got_picture, priv->avpkt.data, priv->avpkt.size );
 #endif
 
-      priv->avpkt.size-=len;
+      free(priv->avpkt.data);
+      priv->avpkt.data=NULL;
+      priv->avpkt.size=0;
 
-#ifdef DEBUG_FRAMES
-      fprintf(stderr,"vals here %ld %ld %d\n",nextframe,tframe,priv->avpkt.size);
-#endif
+      if (nextframe==tframe) hit_target=TRUE;
 
-      if (priv->avpkt.size==0) {
-	free(priv->avpkt.data);
-	priv->avpkt.data=NULL;
+      if (hit_target&&got_picture) break;
+
+      // otherwise discard this frame
+      if (got_picture) {
+	av_free(priv->picture);
+	priv->picture=NULL;
+	tfrag=-1;
+	nextframe++;
       }
-      tfrag=-1;
-      nextframe++;
     }
-
-    /////////////////////////////////////////////////////
-
   }
 
-  if (pixel_data==NULL) return TRUE;
+
+  if (priv->picture==NULL||pixel_data==NULL) return TRUE;
 
   if (priv->black_fill) btop=cdata->frame_height;
 
@@ -2531,7 +2881,8 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
     for (i=0;i<xheight;i++) {
       if (i<btop||i>bbot) {
 	// top or bottom border, copy black row
-	if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||pal==WEED_PALETTE_YUV444P||pal==WEED_PALETTE_YUVA4444P||pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) {
+	if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||pal==WEED_PALETTE_YUV444P||
+	    pal==WEED_PALETTE_YUVA4444P||pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) {
 	  memset(dst,black[p],dstwidth+(bleft+bright)*psize);
 	  dst+=dstwidth+(bleft+bright)*psize;
 	}
@@ -2540,7 +2891,8 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
       }
 
       if (bleft>0) {
-	if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||pal==WEED_PALETTE_YUV444P||pal==WEED_PALETTE_YUVA4444P||pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) {
+	if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||pal==WEED_PALETTE_YUV444P||
+	    pal==WEED_PALETTE_YUVA4444P||pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) {
 	  memset(dst,black[p],bleft*psize);
 	  dst+=bleft*psize;
 	}
@@ -2551,7 +2903,8 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
       dst+=dstwidth;
 
       if (bright>0) {
-	if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||pal==WEED_PALETTE_YUV444P||pal==WEED_PALETTE_YUVA4444P||pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) {
+	if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||pal==WEED_PALETTE_YUV444P||
+	    pal==WEED_PALETTE_YUVA4444P||pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) {
 	  memset(dst,black[p],bright*psize);
 	  dst+=bright*psize;
 	}
@@ -2579,6 +2932,15 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
 
 void clip_data_free(lives_clip_data_t *cdata) {
+  lives_asf_priv_t *priv=cdata->priv;
+
+  if (cdata->palettes!=NULL) free(cdata->palettes);
+  cdata->palettes=NULL;
+
+  if (priv->idxc!=NULL) 
+    idxc_release(cdata);
+
+  priv->idxc=NULL;
 
   if (cdata->URI!=NULL) {
     detach_stream(cdata);
@@ -2591,7 +2953,7 @@ void clip_data_free(lives_clip_data_t *cdata) {
 
 
 void module_unload(void) {
-
+  idxc_release_all();
 }
 
 
