@@ -33,7 +33,7 @@
 #include <stdlib.h>
 #include <math.h>
 
-const char *plugin_version="LiVES flv decoder version 1.0";
+const char *plugin_version="LiVES flv decoder version 1.1";
 
 #ifdef HAVE_AV_CONFIG_H
 #undef HAVE_AV_CONFIG_H
@@ -59,10 +59,34 @@ const char *plugin_version="LiVES flv decoder version 1.0";
 #include <libavformat/avformat.h>
 #include <libavutil/avstring.h>
 #include <libavcodec/avcodec.h>
+#include <libavcodec/version.h>
+
+#include <pthread.h>
 
 #include "decplugin.h"
 #include "flv_decoder.h"
 
+
+#if (LIBAVCODEC_VERSION_MAJOR > 54)
+#define CodecID AVCodecID
+#define CODEC_ID_NONE AV_CODEC_ID_NONE
+#define CODEC_ID_FLV1 AV_CODEC_ID_FLV1
+#define CODEC_ID_FLASHSV AV_CODEC_ID_FLASHSV
+#define CODEC_ID_FLASHSV2 AV_CODEC_ID_FLASHSV2
+#define CODEC_ID_VP6A AV_CODEC_ID_VP6A
+#define CODEC_ID_VP6F AV_CODEC_ID_VP6F
+#define CODEC_ID_H264 AV_CODEC_ID_H264
+#endif
+
+#if !HAVE_AVCODEC_OPEN2
+#define avcodec_open2(a, b, c) avcodec_open(a, b)
+#endif
+
+
+static index_container_t **indices;
+static int nidxc;
+static pthread_mutex_t indices_mutex;
+
 ////////////////////////////////////////////////////////////////////////////
 
 
@@ -256,7 +280,7 @@ static index_entry *index_walk(index_entry *idx, int pts) {
 index_entry *index_upto(const lives_clip_data_t *cdata, int pts) {
   lives_flv_priv_t *priv=cdata->priv;
   lives_flv_pack_t pack;
-  index_entry *nidx=priv->idxht,*oldht=nidx;
+  index_entry *nidx=priv->idxc->idxht,*oldht=nidx;
   int mid_dts=frame_to_dts(cdata,cdata->nframes-1)>>1;
 
   if (nidx==NULL) priv->input_position=priv->data_start;
@@ -271,25 +295,25 @@ index_entry *index_upto(const lives_clip_data_t *cdata, int pts) {
     if (pack.type==FLV_TAG_TYPE_VIDEO&&pack.size>0) {
       if (is_keyframe(priv->fd)) {
 
-	if (pack.dts>mid_dts||(priv->idxth!=NULL&&pack.dts>=priv->idxth->dts)) {
+	if (pack.dts>mid_dts||(priv->idxc->idxth!=NULL&&pack.dts>=priv->idxc->idxth->dts)) {
 	  // handle case where we cross the mid point, or head and tail list have met
-	  if (priv->idxth!=NULL&&pack.dts>=priv->idxth->dts) {
+	  if (priv->idxc->idxth!=NULL&&pack.dts>=priv->idxc->idxth->dts) {
 	    // two lists are now contiguous; swap pointers to indicate this; update old head-tail and return it
 	    
 	    // we found no keyframes between idxht and idxth, so therefore extend idxht
-	    priv->idxht->dts_max=priv->idxth->dts-1;
-	    priv->idxht->next=priv->idxth;
-	    nidx=priv->idxht; // this is the value we will return
+	    priv->idxc->idxht->dts_max=priv->idxc->idxth->dts-1;
+	    priv->idxc->idxht->next=priv->idxc->idxth;
+	    nidx=priv->idxc->idxht; // this is the value we will return
 	    
 	    // cross the pointers
-	    priv->idxht=index_walk(priv->idxht,mid_dts*4/3);
-	    priv->idxth=index_walk(priv->idxhh,mid_dts*2/3);
+	    priv->idxc->idxht=index_walk(priv->idxc->idxht,mid_dts*4/3);
+	    priv->idxc->idxth=index_walk(priv->idxc->idxhh,mid_dts*2/3);
 	    
 	    return nidx;
 	  }
 	  
-	  priv->idxht->dts_max=pack.dts-1;
-	  if (pack.dts>pts) return priv->idxht;
+	  priv->idxc->idxht->dts_max=pack.dts-1;
+	  if (pack.dts>pts) return priv->idxc->idxht;
 
 	  // we crossed the mid point but head list is too short
 	  return index_downto(cdata,pts); // index from head of tail list down to pts
@@ -300,14 +324,14 @@ index_entry *index_upto(const lives_clip_data_t *cdata, int pts) {
 	nidx->offs=priv->input_position-11;
 	nidx->dts=nidx->dts_max=pack.dts;
 	nidx->next=NULL;
-	if (priv->idxht!=NULL) {
-	  oldht=priv->idxht;
+	if (priv->idxc->idxht!=NULL) {
+	  oldht=priv->idxc->idxht;
 	  oldht->dts_max=pack.dts-1;
 	  oldht->next=nidx;
 	}
-	else priv->idxhh=nidx;
+	else priv->idxc->idxhh=nidx;
     
-	priv->idxht=nidx;
+	priv->idxc->idxht=nidx;
       }
 
       if (pack.dts==pts) {
@@ -337,7 +361,7 @@ index_entry *index_downto(const lives_clip_data_t *cdata, int pts) {
   lives_flv_priv_t *priv=cdata->priv;
   lives_flv_pack_t pack;
   int delta;
-  index_entry *nidx=priv->idxth;
+  index_entry *nidx=priv->idxc->idxth;
   int mid_dts=frame_to_dts(cdata,cdata->nframes-1)>>1;
 
   if (nidx==NULL) priv->input_position=get_last_packet_pos(cdata);
@@ -361,22 +385,22 @@ index_entry *index_downto(const lives_clip_data_t *cdata, int pts) {
     }
 
 
-    if (pack.dts<=mid_dts||(priv->idxht!=NULL&&pack.dts<=priv->idxht->dts_max)) {
+    if (pack.dts<=mid_dts||(priv->idxc->idxht!=NULL&&pack.dts<=priv->idxc->idxht->dts_max)) {
       // handle case where we cross the mid point, or head and tail list have met
-      if (priv->idxht!=NULL&&pack.dts<=priv->idxht->dts_max) {
+      if (priv->idxc->idxht!=NULL&&pack.dts<=priv->idxc->idxht->dts_max) {
 	// two lists are now contiguous; swap pointers to indicate this; update old head-tail and return it
 
 	// we found no keyframes between idxth (or last_dts) and idxht, so therefore extend idxht
-	if (priv->idxth!=NULL) {
-	  priv->idxht->dts_max=priv->idxth->dts-1;
-	  priv->idxht->next=priv->idxth;
+	if (priv->idxc->idxth!=NULL) {
+	  priv->idxc->idxht->dts_max=priv->idxc->idxth->dts-1;
+	  priv->idxc->idxht->next=priv->idxc->idxth;
 	}
-	else priv->idxht->dts_max=frame_to_dts(cdata,cdata->nframes)-1;
-	nidx=priv->idxht; // this is the value we will return
+	else priv->idxc->idxht->dts_max=frame_to_dts(cdata,cdata->nframes)-1;
+	nidx=priv->idxc->idxht; // this is the value we will return
 
 	// cross the pointers
-	priv->idxht=index_walk(priv->idxht,mid_dts*4/3);
-	priv->idxth=index_walk(priv->idxhh,mid_dts*2/3);
+	priv->idxc->idxht=index_walk(priv->idxc->idxht,mid_dts*4/3);
+	priv->idxc->idxth=index_walk(priv->idxc->idxhh,mid_dts*2/3);
 
 	return nidx;
       }
@@ -391,16 +415,16 @@ index_entry *index_downto(const lives_clip_data_t *cdata, int pts) {
     nidx=(index_entry *)malloc(sizeof(index_entry));
     nidx->offs=priv->input_position-11;
     nidx->dts=pack.dts;
-    if (priv->idxth!=NULL) {
-      nidx->dts_max=priv->idxth->dts-1;
-      nidx->next=priv->idxth;
+    if (priv->idxc->idxth!=NULL) {
+      nidx->dts_max=priv->idxc->idxth->dts-1;
+      nidx->next=priv->idxc->idxth;
     }
     else {
       nidx->dts_max=frame_to_dts(cdata,cdata->nframes)-1;
       nidx->next=NULL;
     }
     
-    priv->idxth=nidx;
+    priv->idxc->idxth=nidx;
     if (nidx->dts<=pts) break; // found what we were looking for
 
     lseek(priv->fd,-17,SEEK_CUR);
@@ -418,9 +442,9 @@ index_entry *index_downto(const lives_clip_data_t *cdata, int pts) {
 static index_entry *get_idx_for_pts(const lives_clip_data_t *cdata, int64_t pts) {
   lives_flv_priv_t *priv=cdata->priv;
   int ldts;
-  index_entry *idxhh=priv->idxhh;
-  index_entry *idxth=priv->idxth;
-  index_entry *idxht=priv->idxht;
+  index_entry *idxhh=priv->idxc->idxhh;
+  index_entry *idxth=priv->idxc->idxth;
+  index_entry *idxht=priv->idxc->idxht;
 
   if (idxht!=NULL&&pts>=idxht->dts&&pts<=idxht->dts_max) return idxht;
   if (idxth!=NULL&&pts>=idxth->dts&&pts<=idxth->dts_max) return idxth;
@@ -479,6 +503,113 @@ static int amf_get_string(unsigned char *inp, char *buf, size_t size) {
   return len+2;
 }
 
+static index_container_t *idxc_for(lives_clip_data_t *cdata) {
+  // check all idxc for string match with URI
+  index_container_t *idxc;
+  register int i;
+
+  pthread_mutex_lock(&indices_mutex);
+
+  for (i=0;i<nidxc;i++) {
+    if (indices[i]->clients[0]->current_clip==cdata->current_clip&&
+	!strcmp(indices[i]->clients[0]->URI,cdata->URI)) {
+      idxc=indices[i];
+      // append cdata to clients
+      idxc->clients=(lives_clip_data_t **)realloc(idxc->clients,(idxc->nclients+1)*sizeof(lives_clip_data_t *));
+      idxc->clients[idxc->nclients]=cdata;
+      idxc->nclients++;
+      //
+      pthread_mutex_unlock(&indices_mutex);
+      return idxc;
+    }
+  }
+
+  indices=(index_container_t **)realloc(indices,(nidxc+1)*sizeof(index_container_t *));
+
+  // match not found, create a new index container
+  idxc=(index_container_t *)malloc(sizeof(index_container_t));
+
+  idxc->idxhh=NULL;
+  idxc->idxht=NULL;
+  idxc->idxth=NULL;
+
+  idxc->nclients=1;
+  idxc->clients=(lives_clip_data_t **)malloc(sizeof(lives_clip_data_t *));
+  idxc->clients[0]=cdata;
+  pthread_mutex_init(&idxc->mutex,NULL);
+
+  indices[nidxc]=idxc;
+  pthread_mutex_unlock(&indices_mutex);
+
+  nidxc++;
+
+  return idxc;
+}
+
+
+static void idxc_release(lives_clip_data_t *cdata) {
+  lives_flv_priv_t *priv=cdata->priv;
+  index_container_t *idxc=priv->idxc;
+  register int i,j;
+
+  if (idxc==NULL) return;
+
+  pthread_mutex_lock(&indices_mutex);
+
+  if (idxc->nclients==1) {
+    // remove this index
+    if (idxc->idxth!=NULL&&(idxc->idxht==NULL||(idxc->idxth->dts>idxc->idxht->dts))) 
+      index_free(priv->idxc->idxth);
+    if (idxc->idxhh!=NULL) index_free(idxc->idxhh);
+    free(idxc->clients);
+    for (i=0;i<nidxc;i++) {
+      if (indices[i]==idxc) {
+	nidxc--;
+	for (j=i;j<nidxc;j++) {
+	  indices[j]=indices[j+1];
+	}
+	free(idxc);
+	if (nidxc==0) {
+	  free(indices);
+	  indices=NULL;
+	}
+	else indices=(index_container_t **)realloc(indices,nidxc*sizeof(index_container_t *));
+	break;
+      }
+    }
+  }
+  else {
+    // reduce client count by 1
+    for (i=0;i<idxc->nclients;i++) {
+      if (idxc->clients[i]==cdata) {
+	// remove this entry
+	idxc->nclients--;
+	for (j=i;j<idxc->nclients;j++) {
+	  idxc->clients[j]=idxc->clients[j+1];
+	}
+	idxc->clients=(lives_clip_data_t **)realloc(idxc->clients,idxc->nclients*sizeof(lives_clip_data_t *));
+	break;
+      }
+    }
+  }
+
+  pthread_mutex_unlock(&indices_mutex);
+
+}
+
+
+static void idxc_release_all(void) {
+  register int i;
+
+  for (i=0;i<nidxc;i++) {
+    if (indices[i]->idxth!=NULL&&(indices[i]->idxht==NULL||(indices[i]->idxth->dts>indices[i]->idxht->dts))) 
+      index_free(indices[i]->idxth);
+    if (indices[i]->idxhh!=NULL) index_free(indices[i]->idxhh);
+    free(indices[i]->clients);
+    free(indices[i]);
+  }
+  nidxc=0;
+}
 
 static void detach_stream (lives_clip_data_t *cdata) {
   // close the file, free the decoder
@@ -491,28 +622,24 @@ static void detach_stream (lives_clip_data_t *cdata) {
     av_free(priv->ctx);
   }
 
+  if (priv->idxc!=NULL) idxc_release(cdata);
+  priv->idxc=NULL;
+
   if (priv->picture!=NULL) av_free(priv->picture);
 
   priv->ctx=NULL;
   priv->codec=NULL;
   priv->picture=NULL;
 
-  if (priv->idxth!=NULL&&(priv->idxht==NULL||(priv->idxth->dts>priv->idxht->dts))) 
-    index_free(priv->idxth);
-  if (priv->idxhh!=NULL) index_free(priv->idxhh);
-
-  priv->idxhh=NULL;
-  priv->idxht=NULL;
-  priv->idxth=NULL;
-
   if (cdata->palettes!=NULL) free(cdata->palettes);
+  cdata->palettes=NULL;
 
   close(priv->fd);
 }
 
 
 
-static boolean attach_stream(lives_clip_data_t *cdata) {
+static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
   // open the file and get a handle
   lives_flv_priv_t *priv=cdata->priv;
   lives_flv_pack_t pack;
@@ -520,23 +647,32 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   char buffer[FLV_META_SIZE];
   unsigned char flags,avctype;
   int type,size,vcodec=0,ldts;
+
   boolean gotmeta=FALSE,in_array=FALSE;
   boolean hasaudio;
   boolean got_astream=FALSE,got_vstream=FALSE;
+  boolean is_partial_clone=FALSE;
+
   char *key=NULL;
   size_t offs=0;
   double num_val,fps;
 
   AVCodec *codec=NULL;
-  AVCodecContext *ctx;
+  AVCodecContext *ctx=NULL;
 
   boolean got_picture=FALSE,got_avcextradata=FALSE;
 
-  //#define DEBUG
+  //  #define DEBUG
 #ifdef DEBUG
   fprintf(stderr,"\n");
 #endif
 
+  if (isclone&&!priv->inited) {
+    isclone=FALSE;
+    if (cdata->fps>0.&&cdata->nframes>0)
+      is_partial_clone=TRUE;
+  }
+
   if ((priv->fd=open(cdata->URI,O_RDONLY))==-1) {
     fprintf(stderr, "flv_decoder: unable to open %s\n",cdata->URI);
     return FALSE;
@@ -571,7 +707,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   priv->input_position=4+((header[5]&0xFF)<<24)+((header[6]&0xFF)<<16)+((header[7]&0xFF)<<8)+((header[8]&0xFF));
 
-  cdata->fps=0.;
+  if (!is_partial_clone) cdata->fps=0.;
   cdata->width=cdata->frame_width=cdata->height=cdata->frame_height=0;
   cdata->offs_x=cdata->offs_y=0;
 
@@ -579,9 +715,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   cdata->achans=0;
   cdata->asamps=16;
 
-  priv->idxhh=NULL;
-  priv->idxht=NULL;
-  priv->idxth=NULL;
+  priv->idxc=idxc_for(cdata);
+  priv->inited=TRUE;
 
   if (!lives_flv_parse_pack_header(cdata,&pack)) {
     close(priv->fd);
@@ -635,12 +770,18 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
 	// deal with string
 	if (key!=NULL) {
+	  if (!strcmp(key,"comment")) snprintf(cdata->comment,256,"%s",buffer);
+	  if (!strcmp(key,"author")) snprintf(cdata->author,256,"%s",buffer);
+	  if (!strcmp(key,"title")) snprintf(cdata->title,256,"%s",buffer);
 	  free(key);
 	  key=NULL;
 #ifdef DEBUG
 	  fprintf(stderr,"%s\n",buffer);
 #endif
 
+
+
+
 	  // read eoo
 	  if (!in_array) offs++;
 	}
@@ -679,8 +820,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
 	offs+=8;
 
-	if (!strcmp(key,"framerate")) cdata->fps=num_val;
-	if (!strcmp(key,"videoframerate")) cdata->fps=num_val;
+	if (!is_partial_clone&&!strcmp(key,"framerate")) cdata->fps=num_val;
+	if (!is_partial_clone&&!strcmp(key,"videoframerate")) cdata->fps=num_val;
 	if (!strcmp(key,"audiosamplerate")) cdata->arate=num_val;
 	if (!strcmp(key,"audiosamplesize")) cdata->asamps=num_val;
 	//if (!strcmp(key,"lasttimestamp")) lasttimestamp=num_val;
@@ -727,6 +868,9 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
     }
 
+    if (key!=NULL) free(key);
+    key=NULL;
+
     free(pack.data);
 
     if (!gotmeta) {
@@ -754,7 +898,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   if (!hasaudio) got_astream=TRUE;
 
-  priv->ctx=ctx = avcodec_alloc_context();
+  priv->ctx = NULL;
 
   sprintf(cdata->audio_name,"%s","");
 
@@ -883,6 +1027,9 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 	priv->pack_offset=2;
 	break;
       case FLV_CODECID_VP6A  :
+	codec = avcodec_find_decoder(CODEC_ID_VP6A);
+	priv->ctx = ctx = avcodec_alloc_context3(codec);
+
 	sprintf(cdata->video_name,"%s","vp6a");
 	cdata->offs_x=(pack.data[1]&0X0F)>>1; // divide by 2 for offset
 	cdata->offs_y=(pack.data[1]&0XF0)>>5; // divide by 2 for offset
@@ -894,7 +1041,6 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 	}
 	ctx->extradata[0] = pack.data[1];
 
-	codec = avcodec_find_decoder(CODEC_ID_VP6A);
 	priv->pack_offset=2;
 	break;
       case FLV_CODECID_H264:
@@ -915,6 +1061,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   }
 
+
+
 #ifdef DEBUG
   fprintf(stderr,"video type is %s %d x %d (%d x %d +%d +%d)\n",cdata->video_name,
 	  cdata->width,cdata->height,cdata->frame_width,cdata->frame_height,cdata->offs_x,cdata->offs_y);
@@ -928,7 +1076,10 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     return FALSE;
   }
 
-  if (avcodec_open(ctx, codec) < 0) {
+  if (ctx==NULL) 
+    priv->ctx = ctx = avcodec_alloc_context3(codec);
+
+  if (avcodec_open2(ctx, codec, NULL) < 0) {
     fprintf(stderr, "flv_decoder: Could not open avcodec context\n");
     detach_stream(cdata);
     return FALSE;
@@ -999,6 +1150,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   }
   else if (priv->pack_offset!=0) lseek(priv->fd,priv->pack_offset,SEEK_CUR);
 
+  if (isclone) return TRUE;
+
   pack.data=malloc(pack.size-priv->pack_offset+FF_INPUT_BUFFER_PADDING_SIZE);
 
   av_init_packet(&priv->avpkt);
@@ -1091,11 +1244,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   cdata->YUV_subspace=WEED_YUV_SUBSPACE_YCBCR;
   if (ctx->colorspace==AVCOL_SPC_BT709) cdata->YUV_subspace=WEED_YUV_SUBSPACE_BT709;
 
-  cdata->palettes=(int *)malloc(2*sizeof(int));
-
   cdata->palettes[0]=avi_pix_fmt_to_weed_palette(ctx->pix_fmt,
 						 &cdata->YUV_clamping);
-  cdata->palettes[1]=WEED_PALETTE_END;
 
   if (cdata->palettes[0]==WEED_PALETTE_END) {
     fprintf(stderr, "flv_decoder: Could not find a usable palette for (%d) %s\n",ctx->pix_fmt,cdata->URI);
@@ -1125,9 +1275,11 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   cdata->par=(double)ctx->sample_aspect_ratio.num/(double)ctx->sample_aspect_ratio.den;
   if (cdata->par==0.) cdata->par=1.;
 
-  if (ctx->time_base.den>0&&ctx->time_base.num>0) {
-    fps=(double)ctx->time_base.den/(double)ctx->time_base.num;
-    if (fps!=1000.) cdata->fps=fps;
+  if (!is_partial_clone) {
+    if (ctx->time_base.den>0&&ctx->time_base.num>0) {
+      fps=(double)ctx->time_base.den/(double)ctx->time_base.num;
+      if (fps!=1000.) cdata->fps=fps;
+    }
   }
 
 #ifndef IS_MINGW
@@ -1178,6 +1330,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   priv->last_frame=-1;
 
+  if (is_partial_clone) return TRUE;
+
   ldts=get_last_video_dts(cdata);
 
   if (ldts==-1) {
@@ -1211,6 +1365,9 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
 const char *module_check_init(void) {
   avcodec_register_all();
+  indices=NULL;
+  nidxc=0;
+  pthread_mutex_init(&indices_mutex,NULL);
   return NULL;
 }
 
@@ -1234,13 +1391,115 @@ static lives_clip_data_t *init_cdata (void) {
   priv->ctx=NULL;
   priv->codec=NULL;
   priv->picture=NULL;
+  priv->inited=FALSE;
+
+  cdata->palettes=(int *)malloc(2*sizeof(int));
+  cdata->palettes[1]=WEED_PALETTE_END;
+
+  cdata->video_start_time=0.;
+
+  cdata->sync_hint=0;
+
+  memset(cdata->author,0,1);
+  memset(cdata->title,0,1);
+  memset(cdata->comment,0,1);
 
-  cdata->palettes=NULL;
-  
   return cdata;
 }
 
 
+static lives_clip_data_t *flv_clone(lives_clip_data_t *cdata) {
+  lives_clip_data_t *clone=init_cdata();
+  lives_flv_priv_t *dpriv,*spriv;
+
+  // copy from cdata to clone, with a new context for clone
+  clone->URI=strdup(cdata->URI);
+  clone->nclips=cdata->nclips;
+  snprintf(clone->container_name,512,"%s",cdata->container_name);
+  clone->current_clip=cdata->current_clip;
+
+  clone->width=cdata->width;
+  clone->height=cdata->height;
+  clone->nframes=cdata->nframes;
+  clone->interlace=cdata->interlace;
+  clone->offs_x=cdata->offs_x;
+  clone->offs_y=cdata->offs_y;
+  clone->frame_width=cdata->frame_width;
+  clone->frame_height=cdata->frame_height;
+  clone->par=cdata->par;
+  clone->fps=cdata->fps;
+  if (cdata->palettes!=NULL) clone->palettes[0]=cdata->palettes[0];
+  clone->current_palette=cdata->current_palette;
+  clone->YUV_sampling=cdata->YUV_sampling;
+  clone->YUV_clamping=cdata->YUV_clamping;
+  snprintf(clone->video_name,512,"%s",cdata->video_name);
+  clone->arate=cdata->arate;
+  clone->achans=cdata->achans;
+  clone->asamps=cdata->asamps;
+  clone->asigned=cdata->asigned;
+  clone->ainterleaf=cdata->ainterleaf;
+  snprintf(clone->audio_name,512,"%s",cdata->audio_name);
+  clone->seek_flag=cdata->seek_flag;
+  clone->sync_hint=cdata->sync_hint;
+
+  snprintf(clone->author,256,"%s",cdata->author);
+  snprintf(clone->title,256,"%s",cdata->title);
+  snprintf(clone->comment,256,"%s",cdata->comment);
+
+  // create "priv" elements
+  dpriv=clone->priv;
+  spriv=cdata->priv;
+
+  if (spriv!=NULL) {
+    dpriv->inited=TRUE;
+  }
+
+  if (!attach_stream(clone,TRUE)) {
+    free(clone->URI);
+    clone->URI=NULL;
+    clip_data_free(clone);
+    return NULL;
+  }
+
+  if (spriv!=NULL) {
+    dpriv->data_start=spriv->data_start;
+  }
+  else {
+    clone->nclips=1;
+
+    ///////////////////////////////////////////////////////////
+
+    sprintf(clone->container_name,"%s","flv");
+
+    // cdata->height was set when we attached the stream
+
+    clone->interlace=LIVES_INTERLACE_NONE;
+
+    clone->frame_width=clone->width+clone->offs_x*2;
+    clone->frame_height=clone->height+clone->offs_y*2;
+
+    // TODO - check this = spec suggests we should cut right and bottom
+    if (dpriv->ctx->width==clone->frame_width) clone->offs_x=0;
+    if (dpriv->ctx->height==clone->frame_height) clone->offs_y=0;
+
+    ////////////////////////////////////////////////////////////////////
+
+    clone->asigned=TRUE;
+    clone->ainterleaf=TRUE;
+
+  }
+
+  if (dpriv->picture!=NULL) av_free(dpriv->picture);
+  dpriv->picture=NULL;
+
+  dpriv->last_frame=-1;
+  dpriv->picture=NULL;
+  dpriv->avpkt.data=NULL;
+  dpriv->avpkt.size=0;
+
+  return clone;
+}
+
 
 
 
@@ -1258,6 +1517,10 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
 
   lives_flv_priv_t *priv;
 
+  if (URI==NULL&&cdata!=NULL) {
+    // create a clone of cdata - we also need to be able to handle a "fake" clone with only URI, nframes and fps set (priv == NULL)
+    return flv_clone(cdata);
+  }
 
   if (cdata!=NULL&&cdata->current_clip>0) {
     // currently we only support one clip per container
@@ -1276,7 +1539,7 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
       free(cdata->URI);
     }
     cdata->URI=strdup(URI);
-    if (!attach_stream(cdata)) {
+    if (!attach_stream(cdata,FALSE)) {
       free(cdata->URI);
       cdata->URI=NULL;
       clip_data_free(cdata);
@@ -1309,6 +1572,12 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
   cdata->asigned=TRUE;
   cdata->ainterleaf=TRUE;
 
+  if (priv->picture!=NULL) av_free(priv->picture);
+  priv->picture=NULL;
+
+  if (cdata->width!=cdata->frame_width||cdata->height!=cdata->frame_height)
+    fprintf(stderr,"flv_decoder: info - frame size=%d x %d, pixel size=%d x %d\n",cdata->frame_width,cdata->frame_height,cdata->width,cdata->height);
+
   return cdata;
 }
 
@@ -1427,12 +1696,14 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
   if (tframe!=priv->last_frame) {
 
     if (priv->last_frame==-1 || (tframe<priv->last_frame) || (tframe - priv->last_frame > rescan_limit)) {
-
+      
+      pthread_mutex_lock(&priv->idxc->mutex);
       if ((idx=get_idx_for_pts(cdata,target_pts))!=NULL) {
 	priv->input_position=idx->offs;
 	nextframe=dts_to_frame(cdata,idx->dts);
       }
       else priv->input_position=priv->data_start;
+      pthread_mutex_unlock(&priv->idxc->mutex);
       
       // we are now at the kframe before or at target - parse packets until we hit target
       
@@ -1451,6 +1722,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
     priv->ctx->skip_frame=AVDISCARD_NONREF;
 
     priv->last_frame=tframe;
+    if (priv->picture==NULL) priv->picture = avcodec_alloc_frame();
 
 
     // do this until we reach target frame //////////////
@@ -1520,7 +1792,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
   }
 
-  if (pixel_data==NULL) return TRUE;
+  if (priv->picture==NULL||pixel_data==NULL) return TRUE;
   
   for (p=0;p<nplanes;p++) {
     dst=pixel_data[p];
@@ -1577,6 +1849,8 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
 
 void clip_data_free(lives_clip_data_t *cdata) {
+  if (cdata->palettes!=NULL) free(cdata->palettes);
+  cdata->palettes=NULL;
 
   if (cdata->URI!=NULL) {
     detach_stream(cdata);
@@ -1589,7 +1863,7 @@ void clip_data_free(lives_clip_data_t *cdata) {
 
 
 void module_unload(void) {
-
+  idxc_release_all();
 }
 
 int main(void) {
