@@ -36,7 +36,9 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <ctype.h>
 #include <sys/stat.h>
+#include <pthread.h>
 
 const char *plugin_version="LiVES mkv decoder version 1.2";
 
@@ -63,17 +65,60 @@ const char *plugin_version="LiVES mkv decoder version 1.2";
 
 #include <libavformat/avformat.h>
 #include <libavutil/avstring.h>
+#include <libavcodec/version.h>
 #include <libavutil/mem.h>
 
 #include "decplugin.h"
 
-#include "mkv_decoder.h"
-
 #include <libavutil/intfloat_readwrite.h>
 #include <libavutil/intreadwrite.h>
 #include <libavutil/lzo.h>
 #include <libavutil/dict.h>
 
+
+#if (LIBAVCODEC_VERSION_MAJOR > 54)
+#define CodecID AVCodecID
+#define CODEC_ID_NONE AV_CODEC_ID_NONE
+#define CODEC_ID_TEXT AV_CODEC_ID_TEXT
+#define CODEC_ID_SSA AV_CODEC_ID_SSA
+#define CODEC_ID_VP8 AV_CODEC_ID_VP8
+#define CODEC_ID_THEORA AV_CODEC_ID_THEORA
+#define CODEC_ID_SNOW AV_CODEC_ID_SNOW
+#define CODEC_ID_DIRAC AV_CODEC_ID_DIRAC
+#define CODEC_ID_MJPEG AV_CODEC_ID_MJPEG
+#define CODEC_ID_MPEG1VIDEO AV_CODEC_ID_MPEG1VIDEO
+#define CODEC_ID_MPEG2VIDEO AV_CODEC_ID_MPEG2VIDEO
+#define CODEC_ID_MPEG4 AV_CODEC_ID_MPEG4
+#define CODEC_ID_H264 AV_CODEC_ID_H264
+#define CODEC_ID_MSMPEG4V3 AV_CODEC_ID_MSMPEG4V3
+#define CODEC_ID_RV10 AV_CODEC_ID_RV10
+#define CODEC_ID_RV20 AV_CODEC_ID_RV20
+#define CODEC_ID_RV30 AV_CODEC_ID_RV30
+#define CODEC_ID_RV40 AV_CODEC_ID_RV40
+#define CODEC_ID_RAWVIDEO AV_CODEC_ID_RAWVIDEO
+#endif
+
+
+#if !HAVE_AVCODEC_OPEN2
+#define avcodec_open2(a, b, c) avcodec_open(a, b)
+#endif
+
+#if !HAVE_AVCODEC_ALLOC_CONTEXT3
+#define avcodec_alloc_context3(a) avcodec_alloc_context()
+#endif
+
+#if HAVE_AVFORMAT_NEW_STREAM
+#define av_new_stream(a, b) avformat_new_stream(a, NULL)
+#endif
+
+#if HAVE_AVPRIV_SET_PTS_INFO
+#define av_set_pts_info(a,b,c,d) avpriv_set_pts_info(a,b,c,d)
+#endif
+
+
+#include "mkv_decoder.h"
+
+
 #if CONFIG_ZLIB
 #include <zlib.h>
 #endif
@@ -81,6 +126,11 @@ const char *plugin_version="LiVES mkv decoder version 1.2";
 #include <bzlib.h>
 #endif
 
+
+static index_container_t **indices;
+static int nidxc;
+static pthread_mutex_t indices_mutex;
+
 ////////////////////////////////////////////////////////////////////////////
 
 
@@ -96,7 +146,6 @@ const uint8_t ff_log2_tab[256]={
 };
 
 
-
 static enum CodecID ff_codec_get_id(const AVCodecTag *tags, unsigned int tag)
 {
   int i;
@@ -967,7 +1016,9 @@ static void matroska_add_index_entries(const lives_clip_data_t *cdata) {
     for (j = 0; j < pos_list->nb_elem; j++) {
       MatroskaTrack *track = matroska_find_track_by_num(matroska, pos[j].track);
       if (track && track->stream && track->stream==priv->vidst) {
+	pthread_mutex_lock(&priv->idxc->mutex);
 	lives_add_idx(cdata, pos[j].pos + matroska->segment_start, (uint32_t)(index[i].time/index_scale));
+	pthread_mutex_unlock(&priv->idxc->mutex);
 	//printf("ADD INDEX %ld %ld\n", pos[j].pos + matroska->segment_start, index[i].time/index_scale);
       }
     }
@@ -1047,10 +1098,13 @@ static int get_last_video_dts(lives_clip_data_t *cdata) {
   uint64_t frames=0;
   boolean got_picture=FALSE;
 
-  if (priv->idxht==NULL) return 0;
-
+  pthread_mutex_lock(&priv->idxc->mutex);
+  if (priv->idxc->idxht==NULL) {
+    pthread_mutex_unlock(&priv->idxc->mutex);
+    return 0;
+  }
   // jump to last dts in keyframe index
-  ldts=priv->idxht->dts;
+  ldts=priv->idxc->idxht->dts;
 
   // never trust the given duration in a video clip.
   //
@@ -1060,6 +1114,7 @@ static int get_last_video_dts(lives_clip_data_t *cdata) {
   cdata->nframes=1000000000; // allow seeking to end
 
   matroska_read_seek(cdata,ldts);
+  pthread_mutex_unlock(&priv->idxc->mutex);
 
   frames=dts_to_frame(cdata,ldts);
 
@@ -1112,13 +1167,16 @@ static uint32_t calc_dts_delta(const lives_clip_data_t *cdata) {
 
   lives_mkv_priv_t *priv=cdata->priv;
 
-  uint32_t deltadts,origdts;
+  uint32_t deltadts,origdts,idxdts;
   index_entry *idx;
   int frames=0;
   boolean got_picture=FALSE;
 
-  if (priv->idxhh==NULL) return 0;
-
+  pthread_mutex_lock(&priv->idxc->mutex);
+  if (priv->idxc->idxhh==NULL) {
+    pthread_mutex_unlock(&priv->idxc->mutex);
+    return 0;
+  }
   // seek to 0
 
   idx=matroska_read_seek(cdata,0);
@@ -1126,7 +1184,12 @@ static uint32_t calc_dts_delta(const lives_clip_data_t *cdata) {
 
   idx=idx->next;
 
-  if (idx==NULL) return 0;
+  if (idx==NULL) {
+    pthread_mutex_unlock(&priv->idxc->mutex);
+    return 0;
+  }
+  idxdts=idx->dts;
+  pthread_mutex_unlock(&priv->idxc->mutex);
 
   got_eof=FALSE;
 
@@ -1160,7 +1223,7 @@ static uint32_t calc_dts_delta(const lives_clip_data_t *cdata) {
 
   // divide 2nd dts by nframes, this gives delta dts
 
-  deltadts=((double)(idx->dts-origdts)/(double)(frames)+.5);
+  deltadts=((double)(idxdts-origdts)/(double)(frames)+.5);
 
   return deltadts;
 
@@ -1204,9 +1267,11 @@ static index_entry *index_walk(index_entry *idx, uint32_t pts) {
 
 index_entry *lives_add_idx(const lives_clip_data_t *cdata, uint64_t offset, uint32_t pts) {
   lives_mkv_priv_t *priv=cdata->priv;
-  index_entry *nidx=priv->idxht;
+  index_entry *nidx;
   index_entry *nentry;
 
+  nidx=priv->idxc->idxht;
+
   nentry=malloc(sizeof(index_entry));
 
   nentry->dts=pts;
@@ -1215,25 +1280,25 @@ index_entry *lives_add_idx(const lives_clip_data_t *cdata, uint64_t offset, uint
 
   if (nidx==NULL) {
     // first entry in list
-    priv->idxhh=priv->idxht=nentry;
+    priv->idxc->idxhh=priv->idxc->idxht=nentry;
     return nentry;
   }
 
   if (nidx->dts < pts) {
     // last entry in list
     nidx->next=nentry;
-    priv->idxht=nentry;
+    priv->idxc->idxht=nentry;
     return nentry;
   }
 
-  if (priv->idxhh->dts>pts) {
+  if (priv->idxc->idxhh->dts>pts) {
     // before head
-    nentry->next=priv->idxhh;
-    priv->idxhh=nentry;
+    nentry->next=priv->idxc->idxhh;
+    priv->idxc->idxhh=nentry;
     return nentry;
   }
 
-  nidx=index_walk(priv->idxhh,pts);
+  nidx=index_walk(priv->idxc->idxhh,pts);
 
   // after nidx in list
 
@@ -1247,7 +1312,7 @@ index_entry *lives_add_idx(const lives_clip_data_t *cdata, uint64_t offset, uint
 
 static index_entry *get_idx_for_pts(const lives_clip_data_t *cdata, uint32_t pts) {
   lives_mkv_priv_t *priv=cdata->priv;
-  return index_walk(priv->idxhh,pts);
+  return index_walk(priv->idxc->idxhh,pts);
 }
 
 
@@ -1338,7 +1403,9 @@ static int lives_mkv_read_header(lives_clip_data_t *cdata) {
     if (track->type == MATROSKA_TRACK_TYPE_VIDEO) {
 
       if (priv->has_video) {
+#ifdef DEBUG
 	fprintf(stderr,"mkv_decoder: duplicate video streams found\n");
+#endif
 	//continue;
       }
 
@@ -1367,6 +1434,9 @@ static int lives_mkv_read_header(lives_clip_data_t *cdata) {
       cdata->frame_width=track->video.display_width;
       cdata->frame_height=track->video.display_height;
 
+      if (cdata->width!=cdata->frame_width||cdata->height!=cdata->frame_height)
+	fprintf(stderr,"mkv_decoder: info frame size=%d x %d, pixel size=%d x %d\n",cdata->frame_width,cdata->frame_height,cdata->width,cdata->height);
+
       if (track->video.flag_interlaced) cdata->interlace=LIVES_INTERLACE_BOTTOM_FIRST;
 
     } else if (track->type == MATROSKA_TRACK_TYPE_AUDIO) {
@@ -1546,6 +1616,9 @@ static int lives_mkv_read_header(lives_clip_data_t *cdata) {
 	  }
       }
     }
+    else {
+      avcodec_close(st->codec);
+    }
   }
 
   if (priv->vidst==NULL) {
@@ -1558,7 +1631,7 @@ static int lives_mkv_read_header(lives_clip_data_t *cdata) {
     matroska_parse_cues(cdata);
   }
 
-  if (priv->idxhh==NULL) {
+  if (priv->idxc->idxhh==NULL) {
     fprintf(stderr,"mkv_decoder: no seek info found\n");
     return -6;
   }
@@ -1589,6 +1662,111 @@ static int lives_mkv_read_header(lives_clip_data_t *cdata) {
 
 
 
+
+static index_container_t *idxc_for(lives_clip_data_t *cdata) {
+  // check all idxc for string match with URI
+  index_container_t *idxc;
+  register int i;
+
+  pthread_mutex_lock(&indices_mutex);
+
+  for (i=0;i<nidxc;i++) {
+    if (indices[i]->clients[0]->current_clip==cdata->current_clip&&
+	!strcmp(indices[i]->clients[0]->URI,cdata->URI)) {
+      idxc=indices[i];
+      // append cdata to clients
+      idxc->clients=(lives_clip_data_t **)realloc(idxc->clients,(idxc->nclients+1)*sizeof(lives_clip_data_t *));
+      idxc->clients[idxc->nclients]=cdata;
+      idxc->nclients++;
+      //
+      pthread_mutex_unlock(&indices_mutex);
+      return idxc;
+    }
+  }
+
+  indices=(index_container_t **)realloc(indices,(nidxc+1)*sizeof(index_container_t *));
+
+  // match not found, create a new index container
+  idxc=(index_container_t *)malloc(sizeof(index_container_t));
+
+  idxc->idxhh=NULL;
+  idxc->idxht=NULL;
+
+  idxc->nclients=1;
+  idxc->clients=(lives_clip_data_t **)malloc(sizeof(lives_clip_data_t *));
+  idxc->clients[0]=cdata;
+  pthread_mutex_init(&idxc->mutex,NULL);
+
+  indices[nidxc]=idxc;
+  pthread_mutex_unlock(&indices_mutex);
+
+  nidxc++;
+
+  return idxc;
+}
+
+
+static void idxc_release(lives_clip_data_t *cdata) {
+  lives_mkv_priv_t *priv=cdata->priv;
+  index_container_t *idxc=priv->idxc;
+  register int i,j;
+
+  if (idxc==NULL) return;
+
+  pthread_mutex_lock(&indices_mutex);
+
+  if (idxc->nclients==1) {
+    // remove this index
+    index_free(idxc->idxhh);
+    free(idxc->clients);
+    for (i=0;i<nidxc;i++) {
+      if (indices[i]==idxc) {
+	nidxc--;
+	for (j=i;j<nidxc;j++) {
+	  indices[j]=indices[j+1];
+	}
+	free(idxc);
+	if (nidxc==0) {
+	  free(indices);
+	  indices=NULL;
+	}
+	else indices=(index_container_t **)realloc(indices,nidxc*sizeof(index_container_t *));
+	break;
+      }
+    }
+  }
+  else {
+    // reduce client count by 1
+    for (i=0;i<idxc->nclients;i++) {
+      if (idxc->clients[i]==cdata) {
+	// remove this entry
+	idxc->nclients--;
+	for (j=i;j<idxc->nclients;j++) {
+	  idxc->clients[j]=idxc->clients[j+1];
+	}
+	idxc->clients=(lives_clip_data_t **)realloc(idxc->clients,idxc->nclients*sizeof(lives_clip_data_t *));
+	break;
+      }
+    }
+  }
+
+  pthread_mutex_unlock(&indices_mutex);
+
+}
+
+
+static void idxc_release_all(void) {
+  register int i;
+
+  for (i=0;i<nidxc;i++) {
+    index_free(indices[i]->idxhh);
+    free(indices[i]->clients);
+    free(indices[i]);
+  }
+  nidxc=0;
+}
+
+
 static void detach_stream (lives_clip_data_t *cdata) {
   // close the file, free the decoder
   lives_mkv_priv_t *priv=cdata->priv;
@@ -1602,9 +1780,7 @@ static void detach_stream (lives_clip_data_t *cdata) {
     av_free(priv->ctx);
   }
 
-  if (priv->s!=NULL) {
-    av_free(priv->s);
-  }
+  avcodec_close(priv->vidst->codec);
 
   if (priv->picture!=NULL) av_free(priv->picture);
 
@@ -1612,12 +1788,8 @@ static void detach_stream (lives_clip_data_t *cdata) {
   priv->codec=NULL;
   priv->picture=NULL;
 
-  if (priv->idxhh!=NULL) index_free(priv->idxhh);
-
-  priv->idxhh=NULL;
-  priv->idxht=NULL;
-
   if (cdata->palettes!=NULL) free(cdata->palettes);
+  cdata->palettes=NULL;
 
   if (priv->avpkt.data!=NULL) {
     free(priv->avpkt.data);
@@ -1636,7 +1808,7 @@ static void detach_stream (lives_clip_data_t *cdata) {
 #define MKV_PROBE_SIZE 5
 #define MKV_META_SIZE 1024
 
-static boolean attach_stream(lives_clip_data_t *cdata) {
+static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
   // open the file and get a handle
   lives_mkv_priv_t *priv=cdata->priv;
   unsigned char header[MKV_PROBE_SIZE];
@@ -1649,6 +1821,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   int err;
 
   boolean got_picture=FALSE;
+  boolean is_partial_clone=FALSE;
 
   struct stat sb;
   //#define DEBUG
@@ -1656,6 +1829,12 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   fprintf(stderr,"\n\n\n\nDEBUG MKV");
 #endif
 
+  if (isclone&&!priv->inited) {
+    isclone=FALSE;
+    if (cdata->fps>0.&&cdata->nframes>0)
+      is_partial_clone=TRUE;
+  }
+
   priv->has_audio=priv->has_video=FALSE;
   priv->vidst=NULL;
   priv->vididx=-1;
@@ -1669,6 +1848,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   setmode(priv->fd,O_BINARY);
 #endif
 
+  if (isclone) goto skip_probe;
+
   if ((err=read (priv->fd, header, MKV_PROBE_SIZE)) < MKV_PROBE_SIZE) {
     // for example, might be a directory
 #ifdef DEBUG
@@ -1689,10 +1870,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     return FALSE;
   }
   
-  priv->input_position=0;
-  lseek(priv->fd,priv->input_position,SEEK_SET);
-
-  cdata->fps=0.;
+  if (!is_partial_clone) cdata->fps=0.;
   cdata->width=cdata->frame_width=cdata->height=cdata->frame_height=0;
   cdata->offs_x=cdata->offs_y=0;
 
@@ -1700,14 +1878,19 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   cdata->achans=0;
   cdata->asamps=16;
 
-  priv->idxhh=NULL;
-  priv->idxht=NULL;
-
   fstat(priv->fd,&sb);
   priv->filesize=sb.st_size;
 
   sprintf(cdata->audio_name,"%s","");
 
+ skip_probe:
+
+  priv->idxc=idxc_for(cdata);
+  priv->inited=TRUE;
+
+  priv->input_position=0;
+  lseek(priv->fd,priv->input_position,SEEK_SET);
+
   priv->s = avformat_alloc_context();
 
   memset(&priv->matroska,0,sizeof(priv->matroska));
@@ -1716,6 +1899,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   av_init_packet(&priv->avpkt);
   priv->avpkt.data=NULL;
+  priv->avpkt.size=0;
   priv->ctx=NULL;
 
   if (lives_mkv_read_header(cdata)) {
@@ -1748,9 +1932,9 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
     return FALSE;
   }
 
-  priv->ctx = ctx = avcodec_alloc_context();
+  priv->ctx = ctx = avcodec_alloc_context3(codec);
 
-  if (avcodec_open(ctx, codec) < 0) {
+  if (avcodec_open2(ctx, codec, NULL) < 0) {
     fprintf(stderr, "mkv_decoder: Could not open avcodec context for codec\n");
     detach_stream(cdata);
     return FALSE;
@@ -1758,13 +1942,17 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   priv->codec=codec;
 
+  if (isclone) return TRUE;
+
   // re-scan with avcodec; priv->data_start holds video data start position
 
   av_init_packet(&priv->avpkt);
 
   priv->picture = avcodec_alloc_frame();
 
+  pthread_mutex_lock(&priv->idxc->mutex);
   matroska_read_seek(cdata,0);
+  pthread_mutex_unlock(&priv->idxc->mutex);
 
   while (!got_picture&&!got_eof) {
     matroska_read_packet(cdata,&priv->avpkt);
@@ -1820,11 +2008,9 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   cdata->YUV_subspace=WEED_YUV_SUBSPACE_YCBCR;
   if (ctx->colorspace==AVCOL_SPC_BT709) cdata->YUV_subspace=WEED_YUV_SUBSPACE_BT709;
 
-  cdata->palettes=(int *)malloc(2*sizeof(int));
 
   cdata->palettes[0]=avi_pix_fmt_to_weed_palette(ctx->pix_fmt,
 						 &cdata->YUV_clamping);
-  cdata->palettes[1]=WEED_PALETTE_END;
 
   if (cdata->palettes[0]==WEED_PALETTE_END) {
     fprintf(stderr, "mkv_decoder: Could not find a usable palette for (%d) %s\n",ctx->pix_fmt,cdata->URI);
@@ -1854,7 +2040,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   cdata->par=(double)ctx->sample_aspect_ratio.num/(double)ctx->sample_aspect_ratio.den;
   if (cdata->par==0.) cdata->par=1.;
 
-  if (ctx->time_base.den>0&&ctx->time_base.num>0) {
+  if (!is_partial_clone&&ctx->time_base.den>0&&ctx->time_base.num>0) {
     fps=(double)ctx->time_base.den/(double)ctx->time_base.num;
     if (fps!=1000.) cdata->fps=fps;
   }
@@ -1918,6 +2104,8 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   priv->last_frame=-1;
 
+  if (is_partial_clone) return TRUE;
+
   ldts=get_last_video_dts(cdata);
 
   if (ldts==0) ldts=duration*1000.;
@@ -1957,6 +2145,9 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 const char *module_check_init(void) {
   avcodec_register_all();
   av_log_set_level(AV_LOG_ERROR);
+  indices=NULL;
+  nidxc=0;
+  pthread_mutex_init(&indices_mutex,NULL);
   return NULL;
 }
 
@@ -1980,10 +2171,12 @@ static lives_clip_data_t *init_cdata (void) {
   priv->ctx=NULL;
   priv->codec=NULL;
   priv->picture=NULL;
+  priv->inited=FALSE;
 
   priv->expect_eof=FALSE;
 
-  cdata->palettes=NULL;
+  cdata->palettes=(int *)malloc(2*sizeof(int));
+  cdata->palettes[1]=WEED_PALETTE_END;
 
   cdata->interlace=LIVES_INTERLACE_NONE;
 
@@ -1991,13 +2184,113 @@ static lives_clip_data_t *init_cdata (void) {
 
   cdata->sync_hint=0;
 
+  cdata->video_start_time=0.;
+
+  priv->idxc=NULL;
+
   got_eof=FALSE;
   errval=0;
   
+  memset(cdata->author,0,1);
+  memset(cdata->title,0,1);
+  memset(cdata->comment,0,1);
+
   return cdata;
 }
 
 
+static lives_clip_data_t *mkv_clone(lives_clip_data_t *cdata) {
+  lives_clip_data_t *clone=init_cdata();
+  lives_mkv_priv_t *dpriv,*spriv;
+
+  // copy from cdata to clone, with a new context for clone
+  clone->URI=strdup(cdata->URI);
+  clone->nclips=cdata->nclips;
+  snprintf(clone->container_name,512,"%s",cdata->container_name);
+  clone->current_clip=cdata->current_clip;
+  clone->width=cdata->width;
+  clone->height=cdata->height;
+  clone->nframes=cdata->nframes;
+  clone->interlace=cdata->interlace;
+  clone->offs_x=cdata->offs_x;
+  clone->offs_y=cdata->offs_y;
+  clone->frame_width=cdata->frame_width;
+  clone->frame_height=cdata->frame_height;
+  clone->par=cdata->par;
+  clone->fps=cdata->fps;
+  if (cdata->palettes!=NULL) clone->palettes[0]=cdata->palettes[0];
+  clone->current_palette=cdata->current_palette;
+  clone->YUV_sampling=cdata->YUV_sampling;
+  clone->YUV_clamping=cdata->YUV_clamping;
+  snprintf(clone->video_name,512,"%s",cdata->video_name);
+  clone->arate=cdata->arate;
+  clone->achans=cdata->achans;
+  clone->asamps=cdata->asamps;
+  clone->asigned=cdata->asigned;
+  clone->ainterleaf=cdata->ainterleaf;
+  snprintf(clone->audio_name,512,"%s",cdata->audio_name);
+  clone->seek_flag=cdata->seek_flag;
+  clone->sync_hint=cdata->sync_hint;
+
+  snprintf(clone->author,256,"%s",cdata->author);
+  snprintf(clone->title,256,"%s",cdata->title);
+  snprintf(clone->comment,256,"%s",cdata->comment);
+
+  // create "priv" elements
+  dpriv=clone->priv;
+  spriv=cdata->priv;
+
+  if (spriv!=NULL) {
+    dpriv->filesize=spriv->filesize;
+    dpriv->inited=TRUE;
+  }
+
+  if (!attach_stream(clone,TRUE)) {
+    free(clone->URI);
+    clone->URI=NULL;
+    clip_data_free(clone);
+    return NULL;
+  }
+
+  if (spriv==NULL) {
+    clone->nclips=1;
+
+    ///////////////////////////////////////////////////////////
+
+    sprintf(clone->container_name,"%s","mkv");
+
+    // clone->height was set when we attached the stream
+
+    if (clone->frame_width==0||clone->frame_width<clone->width) clone->frame_width=clone->width;
+    else {
+      clone->offs_x=(clone->frame_width-clone->width)/2;
+    }
+
+    if (clone->frame_height==0||clone->frame_height<clone->height) clone->frame_height=clone->height;
+    else {
+      clone->offs_y=(clone->frame_height-clone->height)/2;
+    }
+
+    clone->frame_width=clone->width+clone->offs_x*2;
+    clone->frame_height=clone->height+clone->offs_y*2;
+
+    if (dpriv->ctx->width==clone->frame_width) clone->offs_x=0;
+    if (dpriv->ctx->height==clone->frame_height) clone->offs_y=0;
+
+    ////////////////////////////////////////////////////////////////////
+
+    clone->asigned=TRUE;
+    clone->ainterleaf=TRUE;
+  }
+
+  if (dpriv->picture!=NULL) av_free(dpriv->picture);
+  dpriv->picture=NULL;
+
+  dpriv->last_frame=-1;
+  dpriv->expect_eof=FALSE;
+
+  return clone;
+}
 
 
 
@@ -2015,6 +2308,11 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
 
   lives_mkv_priv_t *priv;
 
+  if (URI==NULL&&cdata!=NULL) {
+    // create a clone of cdata - we also need to be able to handle a "fake" clone with only URI, nframes and fps set (priv == NULL)
+    return mkv_clone(cdata);
+  }
+
   got_eof=FALSE;
   errval=0;
 
@@ -2035,7 +2333,7 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
       free(cdata->URI);
     }
     cdata->URI=strdup(URI);
-    if (!attach_stream(cdata)) {
+    if (!attach_stream(cdata,FALSE)) {
       free(cdata->URI);
       cdata->URI=NULL;
       clip_data_free(cdata);
@@ -2076,6 +2374,9 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
   cdata->asigned=TRUE;
   cdata->ainterleaf=TRUE;
 
+  if (priv->picture!=NULL) av_free(priv->picture);
+  priv->picture=NULL;
+
   return cdata;
 }
 
@@ -2472,11 +2773,15 @@ static index_entry * matroska_read_seek(const lives_clip_data_t *cdata,
 
   index_entry *idx;
 
-  if (!priv->idxhh) return NULL;
+  // lock idxc_mutex before calling
+
+  if (!priv->idxc->idxhh) {
+    return NULL;
+  }
 
   if (timestamp!=0) {
     timestamp = FFMIN(timestamp, frame_to_dts(cdata,cdata->nframes));
-    timestamp = FFMAX(timestamp, priv->idxhh->dts);
+    timestamp = FFMAX(timestamp, priv->idxc->idxhh->dts);
   }
 
   idx=get_idx_for_pts(cdata,timestamp);
@@ -2536,7 +2841,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
   int rescan_limit=16;  // pick some arbitrary value
   int y_black=(cdata->YUV_clamping==WEED_YUV_CLAMPING_CLAMPED)?16:0;
   boolean got_picture=FALSE;
-  unsigned char *dst,*src;//,flags;
+  unsigned char *dst,*src;
   unsigned char black[4]={0,0,0,255};
   index_entry *idx;
   register int i,p;
@@ -2590,7 +2895,9 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
   if (tframe!=priv->last_frame) {
 
     if (priv->last_frame==-1 || (tframe<priv->last_frame) || (tframe - priv->last_frame > rescan_limit)) {
+      pthread_mutex_lock(&priv->idxc->mutex);
       idx=matroska_read_seek(cdata,target_pts);
+      pthread_mutex_unlock(&priv->idxc->mutex);
       nextframe=dts_to_frame(cdata,idx->dts);
       avcodec_flush_buffers (priv->ctx);
 #ifdef DEBUG_KFRAMES
@@ -2604,6 +2911,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
     //priv->ctx->skip_frame=AVDISCARD_NONREF;
 
     priv->last_frame=tframe;
+    if (priv->picture==NULL) priv->picture = avcodec_alloc_frame();
 
     // do this until we reach target frame //////////////
 
@@ -2640,7 +2948,7 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
   }
 
-  if (pixel_data==NULL) return TRUE;
+  if (priv->picture==NULL||pixel_data==NULL) return TRUE;
   
   for (p=0;p<nplanes;p++) {
     dst=pixel_data[p];
@@ -2700,6 +3008,13 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int *rowstride
 
 
 void clip_data_free(lives_clip_data_t *cdata) {
+  lives_mkv_priv_t *priv=cdata->priv;
+
+  if (cdata->palettes!=NULL) free(cdata->palettes);
+  cdata->palettes=NULL;
+
+  if (priv->idxc!=NULL) idxc_release(cdata);
+  priv->idxc=NULL;
 
   if (cdata->URI!=NULL) {
     detach_stream(cdata);
@@ -2712,5 +3027,5 @@ void clip_data_free(lives_clip_data_t *cdata) {
 
 
 void module_unload(void) {
-
+  idxc_release_all();
 }
