@@ -262,7 +262,9 @@ struct AVMetadataConv{
     const char *native;
     const char *generic;
 };
-#if !FF_API_OLD_METADATA2
+
+#if FF_API_OLD_METADATA2
+#else
 typedef struct AVMetadataConv AVMetadataConv;
 #endif
 
@@ -1044,8 +1046,19 @@ struct _index_entry {
 };
 
 
+typedef struct {
+  index_entry *idxhh;  ///< head of head list
+  index_entry *idxht; ///< tail of head list
+
+  int nclients;
+  lives_clip_data_t **clients;
+  pthread_mutex_t mutex;
+} index_container_t;
+
+
 typedef struct {
   int fd;
+  boolean inited;
   boolean has_video;
   boolean has_audio;
   int vididx;
@@ -1060,10 +1073,7 @@ typedef struct {
   AVFrame *picture;
   AVPacket avpkt;
   int64_t last_frame; ///< last frame displayed
-
-  index_entry *idxhh;  ///< head of head list
-  index_entry *idxht; ///< tail of head list
-
+  index_container_t *idxc;
   boolean expect_eof;
 } lives_mkv_priv_t;
 
