@@ -56,6 +56,7 @@
 #include <schroedinger/schro.h>
 #endif
 
+#include <pthread.h>
 
 #include "ogg_decoder.h"
 
@@ -64,8 +65,11 @@
 static boolean ogg_data_process(lives_clip_data_t *cdata, void *yuvbuffer, boolean cont);
 
 
-static const char *plugin_version="LiVES ogg decoder version 1.1";
+static const char *plugin_version="LiVES ogg decoder version 1.2";
 
+static index_container_t **indices;
+static int nidxc;
+static pthread_mutex_t indices_mutex;
 
 /////////////////////////////////////////
 // schroed stuff
@@ -156,13 +160,13 @@ static index_entry *theora_index_entry_add (lives_clip_data_t *cdata, int64_t gr
 
   if (tkframe<1) return NULL;
 
-  oidx=idx=priv->idx;
+  oidx=idx=priv->idxc->idx;
 
   if (idx==NULL) {
     index_entry *ie=index_entry_new();
     ie->value=granule;
     ie->pagepos=pagepos;
-    priv->idx=ie;
+    priv->idxc->idx=ie;
     return ie;
   }
 
@@ -234,7 +238,7 @@ static index_entry *dirac_index_entry_add (lives_clip_data_t *cdata, int64_t pag
   // add a new entry in order, and return a pointer to it
 
   lives_ogg_priv_t *priv=(lives_ogg_priv_t *)cdata->priv;
-  index_entry *new_idx=priv->idx,*last_idx=NULL;
+  index_entry *new_idx=priv->idxc->idx,*last_idx=NULL;
 
   //printf("ADDING IDX for frame %ld region %ld to %ld\n",frame,pagepos,pagepos_end);
 
@@ -278,7 +282,7 @@ static index_entry *get_bounds_for (lives_clip_data_t *cdata, int64_t tframe, in
   int64_t kframe,frame,gpos;
 
   lives_ogg_priv_t *priv=(lives_ogg_priv_t *)cdata->priv;
-  index_entry *idx=priv->idx;
+  index_entry *idx=priv->idxc->idx;
 
   *ppos_lower=*ppos_upper=-1;
 
@@ -390,7 +394,9 @@ static int64_t get_page(lives_clip_data_t *cdata, int64_t inpos) {
     if (priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA) {
       if (ogg_page_serialno(&(opriv->current_page))==priv->vstream->stream_id) {
 	gpos=ogg_page_granulepos(&(opriv->current_page));
+	pthread_mutex_lock(&priv->idxc->mutex);
 	theora_index_entry_add (cdata, gpos, inpos);
+	pthread_mutex_unlock(&priv->idxc->mutex);
       }
     }
   }
@@ -496,6 +502,110 @@ static int dirac_bool( bs_t *p_bs )
 
 
 
+static index_container_t *idxc_for(lives_clip_data_t *cdata) {
+  // check all idxc for string match with URI
+  index_container_t *idxc;
+  register int i;
+
+  pthread_mutex_lock(&indices_mutex);
+
+  for (i=0;i<nidxc;i++) {
+    if (indices[i]->clients[0]->current_clip==cdata->current_clip&&
+	!strcmp(indices[i]->clients[0]->URI,cdata->URI)) {
+      idxc=indices[i];
+      // append cdata to clients
+      idxc->clients=(lives_clip_data_t **)realloc(idxc->clients,(idxc->nclients+1)*sizeof(lives_clip_data_t *));
+      idxc->clients[idxc->nclients]=cdata;
+      idxc->nclients++;
+      //
+      pthread_mutex_unlock(&indices_mutex);
+      return idxc;
+    }
+  }
+
+  indices=(index_container_t **)realloc(indices,(nidxc+1)*sizeof(index_container_t *));
+
+  // match not found, create a new index container
+  idxc=(index_container_t *)malloc(sizeof(index_container_t));
+
+  idxc->idx=NULL;
+
+  idxc->nclients=1;
+  idxc->clients=(lives_clip_data_t **)malloc(sizeof(lives_clip_data_t *));
+  idxc->clients[0]=cdata;
+  pthread_mutex_init(&idxc->mutex,NULL);
+
+  indices[nidxc]=idxc;
+  pthread_mutex_unlock(&indices_mutex);
+
+  nidxc++;
+
+  return idxc;
+}
+
+
+static void idxc_release(lives_clip_data_t *cdata) {
+  lives_ogg_priv_t *priv=cdata->priv;
+  index_container_t *idxc=priv->idxc;
+  register int i,j;
+
+  if (idxc==NULL) return;
+
+  pthread_mutex_lock(&indices_mutex);
+
+  if (idxc->nclients==1) {
+    // remove this index
+    index_entries_free(idxc->idx);
+    free(idxc->clients);
+    for (i=0;i<nidxc;i++) {
+      if (indices[i]==idxc) {
+	nidxc--;
+	for (j=i;j<nidxc;j++) {
+	  indices[j]=indices[j+1];
+	}
+	free(idxc);
+	if (nidxc==0) {
+	  free(indices);
+	  indices=NULL;
+	}
+	else indices=(index_container_t **)realloc(indices,nidxc*sizeof(index_container_t *));
+	break;
+      }
+    }
+  }
+  else {
+    // reduce client count by 1
+    for (i=0;i<idxc->nclients;i++) {
+      if (idxc->clients[i]==cdata) {
+	// remove this entry
+	idxc->nclients--;
+	for (j=i;j<idxc->nclients;j++) {
+	  idxc->clients[j]=idxc->clients[j+1];
+	}
+	idxc->clients=(lives_clip_data_t **)realloc(idxc->clients,idxc->nclients*sizeof(lives_clip_data_t *));
+	break;
+      }
+    }
+  }
+
+  pthread_mutex_unlock(&indices_mutex);
+
+}
+
+
+static void idxc_release_all(void) {
+  register int i;
+
+  for (i=0;i<nidxc;i++) {
+    index_entries_free(indices[i]->idx);
+    free(indices[i]->clients);
+    free(indices[i]);
+  }
+  nidxc=0;
+
+}
+
+
 
 
 static int setup_tracks(lives_clip_data_t *cdata) {
@@ -1038,7 +1148,9 @@ static int64_t find_first_page (lives_clip_data_t *cdata, int64_t pos1, int64_t
 
     if (page_packets_checked) {
       granulepos = ogg_page_granulepos(&(opriv->current_page));
+      pthread_mutex_lock(&priv->idxc->mutex);
       theora_index_entry_add(cdata,granulepos,pos1);
+      pthread_mutex_unlock(&priv->idxc->mutex);
     
       *kframe =
 	  granulepos >> priv->vstream->stpriv->keyframe_granule_shift;
@@ -1122,7 +1234,7 @@ static int64_t find_first_sync_frame (lives_clip_data_t *cdata, int64_t pos1, in
 
   lives_ogg_priv_t *priv=(lives_ogg_priv_t *)cdata->priv;
 
-  index_entry *idx=priv->idx;
+  index_entry *idx=priv->idxc->idx;
   index_entry *extend=NULL;
 
   int64_t bytes;
@@ -1235,7 +1347,9 @@ static int64_t find_first_sync_frame (lives_clip_data_t *cdata, int64_t pos1, in
     }
 
 
-    if ( (idx=find_pagepos_in_index(priv->idx,priv->input_position))!=NULL ) {
+    pthread_mutex_lock(&priv->idxc->mutex);
+
+    if ( (idx=find_pagepos_in_index(priv->idxc->idx,priv->input_position))!=NULL ) {
       // this part was already checked
       
       //printf("WE ALREADY CHECKED THIS\n");
@@ -1244,10 +1358,11 @@ static int64_t find_first_sync_frame (lives_clip_data_t *cdata, int64_t pos1, in
 	// we already found a sync frame here
 	if (extend!=NULL) {
 	  extend->pagepos_end=idx->pagepos-1;
-	  if (extend->pagepos_end<extend->pagepos) priv->idx=index_entry_delete(extend);
+	  if (extend->pagepos_end<extend->pagepos) priv->idxc->idx=index_entry_delete(extend);
 	}
 
 	*frame=idx->value;
+	pthread_mutex_unlock(&priv->idxc->mutex);
 	//printf("As I recall, the sync frame was %ld\n",*frame);
 	return idx->pagepos;
       }
@@ -1256,6 +1371,7 @@ static int64_t find_first_sync_frame (lives_clip_data_t *cdata, int64_t pos1, in
       if (pages_checked>=2&&idx->pagepos<pos1) idx->pagepos=pos1;
       
       pos1=priv->input_position=idx->pagepos_end+1;
+      pthread_mutex_unlock(&priv->idxc->mutex);
       
       //printf("no seq frames, skipping\n");
 
@@ -1325,28 +1441,30 @@ static int64_t find_first_sync_frame (lives_clip_data_t *cdata, int64_t pos1, in
 	
 	ogg_stream_reset(&priv->vstream->stpriv->os);
 	
+	pthread_mutex_lock(&priv->idxc->mutex);
 	if (priv->last_frame>-1) {
 	  // finish off the previous search area
 	  if (extend!=NULL) {
 	    extend->pagepos_end=pos1-1;
-	    if (extend->pagepos_end<extend->pagepos) priv->idx=index_entry_delete(extend);
+	    if (extend->pagepos_end<extend->pagepos) priv->idxc->idx=index_entry_delete(extend);
 	  }
 	  
 	  // and add this one
 	  extend=dirac_index_entry_add(cdata,pos1,priv->input_position+result-1,*frame);
 	  
-	  if (extend->pagepos_end<extend->pagepos) priv->idx=index_entry_delete(extend);
-	  else if (extend->prev==NULL) priv->idx=extend;
+	  if (extend->pagepos_end<extend->pagepos) priv->idxc->idx=index_entry_delete(extend);
+	  else if (extend->prev==NULL) priv->idxc->idx=extend;
 	  
 	}
 	else {
 	  // we got no frames, we must have reached EOF
 	  if (extend!=NULL) {
 	    extend->pagepos_end=priv->input_position-1;
-	    if (extend->pagepos_end<extend->pagepos) priv->idx=index_entry_delete(extend);
+	    if (extend->pagepos_end<extend->pagepos) priv->idxc->idx=index_entry_delete(extend);
 	  }
 	  pos1=-1;
 	}
+	pthread_mutex_unlock(&priv->idxc->mutex);
 	
 	return pos1; // return offset of start page
 	
@@ -1369,18 +1487,20 @@ static int64_t find_first_sync_frame (lives_clip_data_t *cdata, int64_t pos1, in
 	// if we checked from one packet to the next and found no seq header.
 	// We now know that the first pages had no seq header
 	// so we can start marking from pos1 up to start of this page - 1
+	pthread_mutex_lock(&priv->idxc->mutex);
 	if (extend==NULL) {
 	  extend=dirac_index_entry_add(cdata,pos1,priv->input_position-1,-1);
-	  if (extend->prev==NULL) priv->idx=extend;
+	  if (extend->prev==NULL) priv->idxc->idx=extend;
 	}
 	else {
 	  extend->pagepos_end=priv->input_position-1;
 	}
-	if (extend->pagepos_end<extend->pagepos) priv->idx=index_entry_delete(extend);
+	if (extend->pagepos_end<extend->pagepos) priv->idxc->idx=index_entry_delete(extend);
 	else if (extend->prev!=NULL&&extend->prev->pagepos_end==extend->pagepos-1&&extend->prev->value==-1) {
 	  extend->prev->pagepos_end=extend->pagepos_end;
 	  index_entry_delete(extend);
 	}
+	pthread_mutex_unlock(&priv->idxc->mutex);
       }
 
     }
@@ -1576,14 +1696,23 @@ static int open_ogg(lives_clip_data_t *cdata) {
 
 
 
-static boolean attach_stream(lives_clip_data_t *cdata) {
+
+static boolean attach_stream(lives_clip_data_t *cdata, boolean isclone) {
   // open the file and get a handle
 
   struct stat sb;
 
+  int64_t gpos;
+
+  double stream_duration;
+
+  boolean is_partial_clone=FALSE;
+
   lives_ogg_priv_t *priv=(lives_ogg_priv_t *)cdata->priv;
   ogg_t *opriv=priv->opriv=(ogg_t *)malloc(sizeof(ogg_t));
 
+  register int i;
+
   if ((opriv->fd=open(cdata->URI,O_RDONLY))==-1) {
     fprintf(stderr, "ogg_theora_decoder: unable to open %s\n",cdata->URI);
     free(opriv);
@@ -1595,12 +1724,22 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   setmode(opriv->fd,O_BINARY);
 #endif
 
-  stat(cdata->URI,&sb);
+  if (isclone&&!priv->inited) {
+    isclone=FALSE;
+    if (cdata->fps>0.&&cdata->nframes>0)
+      is_partial_clone=TRUE;
+  }
 
-  opriv->total_bytes=sb.st_size;
+  if (!isclone) {
+    stat(cdata->URI,&sb);
+    opriv->total_bytes=sb.st_size;
+  }
 
   opriv->page_valid=0;
 
+  // index init 
+  priv->idxc=idxc_for(cdata);
+
   /* get ogg info */
   if (!open_ogg(cdata)) {
     close(opriv->fd);
@@ -1612,9 +1751,7 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
 
   priv->last_kframe=10000000;
   priv->last_frame=100000000;
-
-  // index init 
-  priv->idx=NULL;
+  priv->inited=TRUE;
 
 
 #ifdef HAVE_THEORA
@@ -1681,6 +1818,201 @@ static boolean attach_stream(lives_clip_data_t *cdata) {
   }
 #endif
 
+  if (isclone) return TRUE;
+
+  cdata->nclips=1;
+
+  // video part
+  cdata->interlace=LIVES_INTERLACE_NONE;
+
+  cdata->par=1.;
+
+  // TODO
+  cdata->offs_x=0;
+  cdata->offs_y=0;
+  cdata->frame_width=cdata->width;
+  cdata->frame_height=cdata->height;
+
+  cdata->YUV_clamping=WEED_YUV_CLAMPING_CLAMPED;
+  cdata->YUV_subspace=WEED_YUV_SUBSPACE_YCBCR;
+  cdata->YUV_sampling=WEED_YUV_SAMPLING_DEFAULT;
+
+
+
+  /* Get format */
+  
+#ifdef HAVE_THEORA
+  if (priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA) {
+    theora_priv_t *tpriv=priv->tpriv;
+    cdata->width  = cdata->frame_width = opriv->y_width = tpriv->ti.frame_width;
+    cdata->height = cdata->frame_height = opriv->y_height = tpriv->ti.frame_height;
+    
+    if (cdata->fps==0.) cdata->fps  = (float)tpriv->ti.fps_numerator/(float)tpriv->ti.fps_denominator;
+    
+    switch(tpriv->ti.pixelformat) {
+    case OC_PF_420:
+      cdata->palettes[0] = WEED_PALETTE_YUV420P;
+      opriv->uv_width = opriv->y_width>>1;
+      break;
+    case OC_PF_422:
+      cdata->palettes[0] = WEED_PALETTE_YUV422P;
+      opriv->uv_width = opriv->y_width>>1;
+      break;
+    case OC_PF_444:
+      cdata->palettes[0] = WEED_PALETTE_YUV444P;
+      opriv->uv_width = opriv->y_width;
+      break;
+    default:
+      fprintf(stderr, "Unknown pixelformat %d", tpriv->ti.pixelformat);
+      return FALSE;
+    }
+
+    cdata->palettes[1]=WEED_PALETTE_END;
+    cdata->current_palette=cdata->palettes[0];
+    sprintf(cdata->video_name,"%s","theora");
+
+    if (tpriv->tc.comments>0) {
+      size_t lenleft=256,csize;
+      char *cbuf=cdata->comment;
+      for (i=0;i<=tpriv->tc.comments;i++) {
+	csize=tpriv->tc.comment_lengths[i];
+	if (csize>lenleft) csize=lenleft;
+	snprintf(cbuf,csize,"%s",tpriv->tc.user_comments[i]);
+	cbuf+=csize;
+	lenleft-=csize;
+	if (lenleft==0) break;
+	if (i+1<=tpriv->tc.comments) {
+	  if (lenleft<strlen("\n")+1) break;
+	  sprintf(cbuf,"\n");
+	  cbuf+=strlen("\n");
+	  lenleft-=strlen("\n");
+	}
+      }
+    }
+
+  }
+#endif
+  
+
+#ifdef HAVE_DIRAC
+  if (priv->vstream->stpriv->fourcc_priv==FOURCC_DIRAC) {
+    // feed some pages to the decoder so it gets the idea
+    dirac_priv_t *dpriv=priv->dpriv;
+    int64_t start_pos=priv->input_position;
+
+    seek_byte(cdata,priv->vstream->data_start);
+
+    while (1) {
+      int64_t input_pos;
+      boolean done=FALSE;
+
+      opriv->page_valid=0;
+
+      if (!(input_pos=get_page(cdata,priv->input_position))) {
+	// should never reach here
+	fprintf(stderr, "EOF1 while decoding\n");
+	return FALSE;
+      }
+      
+      priv->input_position+=input_pos;
+
+      if (ogg_page_serialno(&(opriv->current_page))!=priv->vstream->stream_id) continue;
+      ogg_stream_pagein(&priv->vstream->stpriv->os, &(opriv->current_page));
+      
+      while (ogg_stream_packetout(&priv->vstream->stpriv->os, &opriv->op) > 0) {
+	// feed packets to decoder
+        SchroBuffer *schrobuffer;
+	int state;
+
+        schrobuffer = schro_buffer_new_with_data( opriv->op.packet, opriv->op.bytes );
+	schro_decoder_autoparse_push( dpriv->schrodec, schrobuffer );
+
+	state = schro_decoder_autoparse_wait( dpriv->schrodec );
+	
+	if (state==SCHRO_DECODER_FIRST_ACCESS_UNIT) {
+	  // should have our cdata now
+	  get_dirac_cdata(cdata,dpriv->schrodec);
+	  done=TRUE;
+	  break;
+	}
+	if (done) break;
+      }
+      if (done) break;
+    }
+
+    cdata->current_palette=cdata->palettes[0];
+
+    // reset and seek back to start
+    //fprintf(stderr,"got dirac fps=%.4f %d x %d\n",cdata->fps,cdata->width,cdata->height);
+
+
+    schro_decoder_reset( dpriv->schrodec );
+    seek_byte(cdata,start_pos);
+    ogg_stream_reset(&priv->vstream->stpriv->os);
+
+    // find first keyframe
+    find_first_sync_frame(cdata, priv->vstream->data_start, opriv->total_bytes, &priv->kframe_offset); 
+
+    sprintf(cdata->video_name,"%s","dirac");
+
+ }
+
+#endif
+
+
+  sprintf(cdata->container_name,"%s","ogg");
+
+
+  // audio part
+  cdata->asigned=FALSE;
+  cdata->achans=0;
+  cdata->ainterleaf=TRUE;
+  cdata->asamps=0;
+
+  if (priv->astream!=NULL) {
+    sprintf(cdata->audio_name,"%s","vorbis");
+  }
+  else memset(cdata->audio_name,0,1);
+  
+
+  if (isclone) return TRUE;
+
+  // get duration
+
+
+  if (priv->astream!=NULL) {
+    ogg_stream_reset(&priv->astream->stpriv->os);
+    gpos=get_last_granulepos(cdata,priv->astream->stream_id);
+    stream_duration =
+      granulepos_2_time(priv->astream,gpos);
+    priv->astream->duration=stream_duration;
+    priv->astream->stpriv->last_granulepos=gpos;
+    //printf("priv->astream duration is %.4f\n",stream_duration);
+  }
+
+  if (priv->vstream!=NULL) {
+    ogg_stream_reset(&priv->vstream->stpriv->os);
+    gpos=get_last_granulepos(cdata,priv->vstream->stream_id);
+
+    /*  kframe=gpos >> priv->vstream->priv->keyframe_granule_shift;
+	priv->vstream->nframes = kframe + gpos-(kframe<<priv->vstream->priv->keyframe_granule_shift);*/
+
+    priv->vstream->nframes=gpos;
+
+    stream_duration = 
+      granulepos_2_time(priv->vstream,gpos);
+    priv->vstream->duration=stream_duration;
+    priv->vstream->stpriv->last_granulepos=gpos;
+    //printf("priv->vstream duration is %.4f %ld\n",stream_duration,priv->vstream->nframes);
+  }
+
+  if (is_partial_clone) return TRUE;
+
+
+  cdata->nframes=priv->vstream->nframes;
+
+  if (cdata->width!=cdata->frame_width||cdata->height!=cdata->frame_height)
+    fprintf(stderr,"ogg_decoder: info - frame size=%d x %d, pixel size=%d x %d\n",cdata->frame_width,cdata->frame_height,cdata->width,cdata->height);
 
 
   return TRUE;
@@ -1748,9 +2080,9 @@ static void detach_stream (lives_clip_data_t *cdata) {
   }
 
 
-  // free index entries
-  if (priv->idx!=NULL) index_entries_free(priv->idx);
-  priv->idx=NULL;
+  if (cdata->palettes!=NULL) free(cdata->palettes);
+  cdata->palettes=NULL;
+
 
 }
 
@@ -1900,7 +2232,9 @@ static int64_t ogg_seek(lives_clip_data_t *cdata, int64_t tframe, int64_t ppos_l
     priv->cpagepos=best_pagepos;
     // TODO - add to vlc
     if (priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA) {
+      pthread_mutex_lock(&priv->idxc->mutex);
       theora_index_entry_add((lives_clip_data_t *)cdata,gpos,priv->cpagepos);
+      pthread_mutex_unlock(&priv->idxc->mutex);
     }
     gpos=frame_to_gpos(cdata,best_kframe,best_frame);
     return gpos;
@@ -1924,6 +2258,13 @@ const char *version(void) {
 }
 
 
+const char *module_check_init(void) {
+  indices=NULL;
+  nidxc=0;
+  pthread_mutex_init(&indices_mutex,NULL);
+  return NULL;
+}
+
 
 lives_clip_data_t *init_cdata(void) {
   lives_clip_data_t *cdata=(lives_clip_data_t *)malloc(sizeof(lives_clip_data_t));
@@ -1934,6 +2275,7 @@ lives_clip_data_t *init_cdata(void) {
 
   priv->vstream=NULL;
   priv->astream=NULL;
+  priv->inited=FALSE;
 
   priv->opriv=NULL;
 
@@ -1945,31 +2287,119 @@ lives_clip_data_t *init_cdata(void) {
   priv->dpriv=NULL;
 #endif
 
-  priv->idx=NULL;
+  priv->idxc=NULL;
 
+  cdata->video_start_time=0.;
   cdata->sync_hint=0;
 
+  cdata->fps=0.;
+
   cdata->palettes=malloc(2*sizeof(int));
+  cdata->palettes[1]=WEED_PALETTE_END;
+
   cdata->URI=NULL;
 
+  memset(cdata->author,0,1);
+  memset(cdata->title,0,1);
+  memset(cdata->comment,0,1);
+
   return cdata;
 }
 
 
+static lives_clip_data_t *ogg_clone(lives_clip_data_t *cdata) {
+  lives_clip_data_t *clone=init_cdata();
+  lives_ogg_priv_t *dpriv,*spriv;
+
+  ogg_t *dopriv;
+  ogg_t *sopriv;
+
+  // copy from cdata to clone, with a new context for clone
+  clone->URI=strdup(cdata->URI);
+  clone->nclips=cdata->nclips;
+  snprintf(clone->container_name,512,"%s",cdata->container_name);
+  clone->current_clip=cdata->current_clip;
+  clone->width=cdata->width;
+  clone->height=cdata->height;
+  clone->nframes=cdata->nframes;
+  clone->interlace=cdata->interlace;
+  clone->offs_x=cdata->offs_x;
+  clone->offs_y=cdata->offs_y;
+  clone->frame_width=cdata->frame_width;
+  clone->frame_height=cdata->frame_height;
+  clone->par=cdata->par;
+  clone->fps=cdata->fps;
+  if (cdata->palettes!=NULL) clone->palettes[0]=cdata->palettes[0];
+  clone->current_palette=cdata->current_palette;
+  clone->YUV_sampling=cdata->YUV_sampling;
+  clone->YUV_clamping=cdata->YUV_clamping;
+  snprintf(clone->video_name,512,"%s",cdata->video_name);
+  clone->arate=cdata->arate;
+  clone->achans=cdata->achans;
+  clone->asamps=cdata->asamps;
+  clone->asigned=cdata->asigned;
+  clone->ainterleaf=cdata->ainterleaf;
+  snprintf(clone->audio_name,512,"%s",cdata->audio_name);
+  clone->seek_flag=cdata->seek_flag;
+  clone->sync_hint=cdata->sync_hint;
+  clone->video_start_time=cdata->video_start_time;
+
+  snprintf(clone->author,256,"%s",cdata->author);
+  snprintf(clone->title,256,"%s",cdata->title);
+  snprintf(clone->comment,256,"%s",cdata->comment);
+
+  // create "priv" elements
+  dpriv=clone->priv;
+  spriv=cdata->priv;
+
+  if (spriv!=NULL) {
+    sopriv=spriv->opriv;
+    dopriv=dpriv->opriv;
+    dpriv->inited=TRUE;
+    dopriv->total_bytes=sopriv->total_bytes;
+  }
+
+  if (!attach_stream(clone,TRUE)) {
+    free(clone->URI);
+    clone->URI=NULL;
+    clip_data_free(clone);
+    return NULL;
+  }
+
+  if (spriv!=NULL) {
+    ogg_stream_reset(&dpriv->astream->stpriv->os);
+    dpriv->astream->duration=spriv->astream->duration;
+    dpriv->astream->stpriv->last_granulepos=spriv->astream->stpriv->last_granulepos;
+
+    ogg_stream_reset(&dpriv->vstream->stpriv->os);
+    dpriv->vstream->nframes=spriv->vstream->nframes;
+    dpriv->vstream->duration=spriv->vstream->duration;
+    dpriv->vstream->stpriv->last_granulepos=spriv->vstream->stpriv->last_granulepos;
+
+  }
+
+  dpriv->last_frame=-1;
+
+  return clone;
+}
+
+
+
 
 
 lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
-  // the first time this is called, caller should pass NULL as the cdata
+  // the first time this is called, caller should pass NULL as the clone
   // subsequent calls to this should re-use the same cdata
 
   // if the host wants a different URI, a different current_clip, or a different current_palette, 
   // this must be called again with the same
   // cdata as the second parameter
   lives_ogg_priv_t *priv;
-  ogg_t *opriv;
 
-  double stream_duration;
-  int64_t gpos;
+  if (URI==NULL&&cdata!=NULL) {
+    // create a clone of cdata - we also need to be able to handle a "fake" clone with only URI, nframes and fps set (priv == NULL)
+    return ogg_clone(cdata);
+  }
 
   if (cdata!=NULL&&cdata->current_clip>0) {
     // currently we only support one clip per container
@@ -1990,7 +2420,7 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
       free(cdata->URI);
     }
     cdata->URI=strdup(URI);
-    if (!attach_stream(cdata)) {
+    if (!attach_stream(cdata,FALSE)) {
       free(cdata->URI);
       cdata->URI=NULL;
       clip_data_free(cdata);
@@ -2004,176 +2434,6 @@ lives_clip_data_t *get_clip_data(const char *URI, lives_clip_data_t *cdata) {
     return NULL;
   }
 
-  opriv=priv->opriv;
-
-  cdata->nclips=1;
-
-  // video part
-  cdata->interlace=LIVES_INTERLACE_NONE;
-
-  cdata->par=1.;
-
-  // TODO
-  cdata->offs_x=0;
-  cdata->offs_y=0;
-  cdata->frame_width=cdata->width;
-  cdata->frame_height=cdata->height;
-
-  cdata->YUV_clamping=WEED_YUV_CLAMPING_CLAMPED;
-  cdata->YUV_subspace=WEED_YUV_SUBSPACE_YCBCR;
-  cdata->YUV_sampling=WEED_YUV_SAMPLING_DEFAULT;
-
-
-
-  /* Get format */
-  
-#ifdef HAVE_THEORA
-  if (priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA) {
-    theora_priv_t *tpriv=priv->tpriv;
-    cdata->width  = cdata->frame_width = opriv->y_width = tpriv->ti.frame_width;
-    cdata->height = cdata->frame_height = opriv->y_height = tpriv->ti.frame_height;
-    
-    cdata->fps  = (float)tpriv->ti.fps_numerator/(float)tpriv->ti.fps_denominator;
-    
-    switch(tpriv->ti.pixelformat) {
-    case OC_PF_420:
-      cdata->palettes[0] = WEED_PALETTE_YUV420P;
-      opriv->uv_width = opriv->y_width>>1;
-      break;
-    case OC_PF_422:
-      cdata->palettes[0] = WEED_PALETTE_YUV422P;
-      opriv->uv_width = opriv->y_width>>1;
-      break;
-    case OC_PF_444:
-      cdata->palettes[0] = WEED_PALETTE_YUV444P;
-      opriv->uv_width = opriv->y_width;
-      break;
-    default:
-      fprintf(stderr, "Unknown pixelformat %d", tpriv->ti.pixelformat);
-      return NULL;
-    }
-
-    cdata->palettes[1]=WEED_PALETTE_END;
-    cdata->current_palette=cdata->palettes[0];
-    sprintf(cdata->video_name,"%s","theora");
-  }
-#endif
-  
-
-#ifdef HAVE_DIRAC
-  if (priv->vstream->stpriv->fourcc_priv==FOURCC_DIRAC) {
-    // feed some pages to the decoder so it gets the idea
-    dirac_priv_t *dpriv=priv->dpriv;
-    int64_t start_pos=priv->input_position;
-
-    seek_byte(cdata,priv->vstream->data_start);
-
-    while (1) {
-      int64_t input_pos;
-      boolean done=FALSE;
-
-      opriv->page_valid=0;
-
-      if (!(input_pos=get_page(cdata,priv->input_position))) {
-	// should never reach here
-	fprintf(stderr, "EOF1 while decoding\n");
-	return FALSE;
-      }
-      
-      priv->input_position+=input_pos;
-
-      if (ogg_page_serialno(&(opriv->current_page))!=priv->vstream->stream_id) continue;
-      ogg_stream_pagein(&priv->vstream->stpriv->os, &(opriv->current_page));
-      
-      while (ogg_stream_packetout(&priv->vstream->stpriv->os, &opriv->op) > 0) {
-	// feed packets to decoder
-        SchroBuffer *schrobuffer;
-	int state;
-
-        schrobuffer = schro_buffer_new_with_data( opriv->op.packet, opriv->op.bytes );
-	schro_decoder_autoparse_push( dpriv->schrodec, schrobuffer );
-
-	state = schro_decoder_autoparse_wait( dpriv->schrodec );
-	
-	if (state==SCHRO_DECODER_FIRST_ACCESS_UNIT) {
-	  // should have our cdata now
-	  get_dirac_cdata(cdata,dpriv->schrodec);
-	  done=TRUE;
-	  break;
-	}
-	if (done) break;
-      }
-      if (done) break;
-    }
-
-    cdata->palettes[1]=WEED_PALETTE_END;
-    cdata->current_palette=cdata->palettes[0];
-
-    // reset and seek back to start
-    //fprintf(stderr,"got dirac fps=%.4f %d x %d\n",cdata->fps,cdata->width,cdata->height);
-
-
-    schro_decoder_reset( dpriv->schrodec );
-    seek_byte(cdata,start_pos);
-    ogg_stream_reset(&priv->vstream->stpriv->os);
-
-    // find first keyframe
-    find_first_sync_frame(cdata, priv->vstream->data_start, opriv->total_bytes, &priv->kframe_offset); 
-
-    sprintf(cdata->video_name,"%s","dirac");
-
- }
-
-#endif
-
-
-  sprintf(cdata->container_name,"%s","ogg");
-
-
-  // audio part
-  cdata->asigned=FALSE;
-  cdata->achans=0;
-  cdata->ainterleaf=TRUE;
-  cdata->asamps=0;
-
-  if (priv->astream!=NULL) {
-    sprintf(cdata->audio_name,"%s","vorbis");
-  }
-  else memset(cdata->audio_name,0,1);
-  
-
-
-  // get duration
-
-
-  if (priv->astream!=NULL) {
-    ogg_stream_reset(&priv->astream->stpriv->os);
-    gpos=get_last_granulepos(cdata,priv->astream->stream_id);
-    stream_duration =
-      granulepos_2_time(priv->astream,gpos);
-    priv->astream->duration=stream_duration;
-    priv->astream->stpriv->last_granulepos=gpos;
-    //printf("priv->astream duration is %.4f\n",stream_duration);
-  }
-
-  if (priv->vstream!=NULL) {
-    ogg_stream_reset(&priv->vstream->stpriv->os);
-    gpos=get_last_granulepos(cdata,priv->vstream->stream_id);
-
-    /*  kframe=gpos >> priv->vstream->priv->keyframe_granule_shift;
-	priv->vstream->nframes = kframe + gpos-(kframe<<priv->vstream->priv->keyframe_granule_shift);*/
-
-    priv->vstream->nframes=gpos;
-
-    stream_duration = 
-      granulepos_2_time(priv->vstream,gpos);
-    priv->vstream->duration=stream_duration;
-    priv->vstream->stpriv->last_granulepos=gpos;
-    //printf("priv->vstream duration is %.4f %ld\n",stream_duration,priv->vstream->nframes);
-  }
-
-
-  cdata->nframes=priv->vstream->nframes;
 
   return cdata;
 }
@@ -2200,7 +2460,56 @@ static boolean ogg_theora_read(lives_clip_data_t *cdata, ogg_packet *op, yuv_buf
 
 #endif
 
+#ifdef HAVE_THEORA
 
+static size_t write_black_pixel(unsigned char *idst, int pal, int npixels, int y_black) {
+  unsigned char *dst=idst;
+  register int i;
+
+  for (i=0;i<npixels;i++) {
+    switch (pal) {
+    case WEED_PALETTE_RGBA32:
+    case WEED_PALETTE_BGRA32:
+      dst[0]=dst[1]=dst[2]=0;
+      dst[3]=255;
+      dst+=4;
+      break;
+    case WEED_PALETTE_ARGB32:
+      dst[1]=dst[2]=dst[3]=0;
+      dst[0]=255;
+      dst+=4;
+      break;
+    case WEED_PALETTE_UYVY8888:
+      dst[1]=dst[3]=y_black;
+      dst[0]=dst[2]=128;
+      dst+=4;
+      break;
+    case WEED_PALETTE_YUYV8888:
+      dst[0]=dst[2]=y_black;
+      dst[1]=dst[3]=128;
+      dst+=4;
+      break;
+    case WEED_PALETTE_YUV888:
+      dst[0]=y_black;
+      dst[1]=dst[2]=128;
+      dst+=3;
+      break;
+    case WEED_PALETTE_YUVA8888:
+      dst[0]=y_black;
+      dst[1]=dst[2]=128;
+      dst[3]=255;
+      dst+=4;
+      break;
+    case WEED_PALETTE_YUV411:
+      dst[0]=dst[3]=128;
+      dst[1]=dst[2]=dst[4]=dst[5]=y_black;
+      dst+=6;
+    default: break;
+    }
+  }
+  return idst-dst;
+}
+#endif
 
 
 #ifdef HAVE_DIRAC
@@ -2236,8 +2545,6 @@ static void schroframe_to_pixel_data(SchroFrame *sframe, uint8_t **pixel_data) {
     crow=!crow;
     sched_yield();
   }
-
-
 }
 
 
@@ -2464,13 +2771,12 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int* rowstride
 
 #ifdef HAVE_THEORA
   yuv_buffer yuv;
-  boolean crow=FALSE;
-  void *y,*u,*v;
   register int i;
 #endif
 
 #ifdef HAVE_DIRAC
   dirac_priv_t *dpriv=priv->dpriv;
+  ogg_t *opriv=priv->opriv;
 #endif
 
   int64_t kframe=-1,xkframe;
@@ -2481,16 +2787,61 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int* rowstride
 
   static index_entry *fidx=NULL;
 
-  int mheight;
+#ifdef HAVE_THEORA
 
-  ogg_t *opriv=priv->opriv;
+  register int p;
+
+  unsigned char *dst,*src;
+
+  int y_black=(cdata->YUV_clamping==WEED_YUV_CLAMPING_CLAMPED)?16:0;
+  unsigned char black[4]={0,0,0,255};
+
+  int xheight=(cdata->frame_height>>1)<<1,pal=cdata->current_palette,nplanes=1,dstwidth=cdata->width,psize=1;
+  int btop=cdata->offs_y,bbot=xheight-1-btop;
+  int bleft=cdata->offs_x,bright=cdata->frame_width-cdata->width-bleft;
+
+  if (pixel_data!=NULL) {
+    if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||pal==WEED_PALETTE_YUV444P) {
+      nplanes=3;
+      black[0]=y_black;
+      black[1]=black[2]=128;
+    }
+    else if (pal==WEED_PALETTE_YUVA4444P) {
+      nplanes=4;
+      black[0]=y_black;
+      black[1]=black[2]=128;
+      black[3]=255;
+    }
+    
+    if (pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) psize=3;
+    
+    if (pal==WEED_PALETTE_RGBA32||pal==WEED_PALETTE_BGRA32||pal==WEED_PALETTE_ARGB32||pal==WEED_PALETTE_UYVY8888||
+	pal==WEED_PALETTE_YUYV8888||pal==WEED_PALETTE_YUV888||pal==WEED_PALETTE_YUVA8888) psize=4;
+    
+    if (pal==WEED_PALETTE_YUV411) psize=6;
+    
+    if (pal==WEED_PALETTE_A1) dstwidth>>=3;
+    
+    dstwidth*=psize;
+    
+    if (cdata->frame_height > cdata->height && height == cdata->height) {
+      // host ignores vertical border
+      btop=0;
+      xheight=(cdata->height>>1)<<1;
+      bbot=xheight-1;
+    }
+    
+    if (cdata->frame_width > cdata->width && rowstrides[0] < cdata->frame_width*psize) {
+      // host ignores horizontal border
+      bleft=bright=0;
+    }
+  }
+
+#endif
 
-  if (priv->vstream==NULL) return FALSE;
 
   priv->current_pos=priv->input_position;
 
-  mheight=(opriv->y_height>>1)<<1; // yes indeed, there is a file with a height of 601 pixels...
-
   max_frame_diff=2<<(priv->vstream->stpriv->keyframe_granule_shift-2);
 
   tframe+=priv->kframe_offset;
@@ -2535,15 +2886,19 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int* rowstride
       }
 
       // need to find a new kframe
+      pthread_mutex_lock(&priv->idxc->mutex);
       fidx=get_bounds_for((lives_clip_data_t *)cdata,tframe,&ppos_lower,&ppos_upper);
       if (fidx==NULL) {
 	//printf("pt a\n");
 	int64_t last_ret_frame=priv->last_frame;
+	pthread_mutex_unlock(&priv->idxc->mutex);
 	granulepos=ogg_seek((lives_clip_data_t *)cdata,tframe,ppos_lower,ppos_upper,TRUE);
+	pthread_mutex_lock(&priv->idxc->mutex);
 	priv->last_frame=last_ret_frame;
 	if (granulepos==-1) return FALSE; // should never happen...
       }
       else granulepos=fidx->value;
+      pthread_mutex_unlock(&priv->idxc->mutex);
       //printf("pt a2\n");
 
       if (priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA) {
@@ -2575,28 +2930,30 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int* rowstride
     else {
       if (fidx==NULL||priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA) {
 	if (priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA) {
+	  pthread_mutex_lock(&priv->idxc->mutex);
 	  get_bounds_for((lives_clip_data_t *)cdata,kframe-1,&ppos_lower,&ppos_upper);
+	  pthread_mutex_unlock(&priv->idxc->mutex);
 	  granulepos=ogg_seek((lives_clip_data_t *)cdata,kframe-1,ppos_lower,ppos_upper,FALSE);
 	  //fprintf(stderr,"starting from found gpos %ld\n",granulepos);
 	
 	  xkframe=granulepos >> priv->vstream->stpriv->keyframe_granule_shift;
 
 
+	  pthread_mutex_lock(&priv->idxc->mutex);
 	  get_bounds_for((lives_clip_data_t *)cdata,xkframe-1,&ppos_lower,&ppos_upper);
+	  pthread_mutex_unlock(&priv->idxc->mutex);
 	  granulepos=ogg_seek((lives_clip_data_t *)cdata,xkframe-1,ppos_lower,ppos_upper,FALSE);
 	  //fprintf(stderr,"starting from found gpos %ld\n",granulepos);
 	
 	  xkframe=granulepos >> priv->vstream->stpriv->keyframe_granule_shift;
 
-
-
 	  priv->cframe = xkframe + granulepos-(xkframe<<priv->vstream->stpriv->keyframe_granule_shift); // cframe will be the next frame we decode
 	  //printf("xkframe is %ld %ld\n",xkframe,priv->cframe);
 	}
 	else {
 	  priv->cframe=kframe;
 	  priv->input_position=priv->cpagepos;
-	  printf("SEEK TO %ld\n",priv->cpagepos);
+	  //printf("SEEK TO %ld\n",priv->cpagepos);
 	}
 
 	if (priv->input_position==priv->vstream->data_start) {
@@ -2642,26 +2999,76 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int* rowstride
 
 #ifdef HAVE_THEORA
   if (priv->vstream->stpriv->fourcc_priv==FOURCC_THEORA) {
-    y=yuv.y;
-    u=yuv.u;
-    v=yuv.v;
-    
-    for (i=0;i<mheight;i++) {
-      memcpy(pixel_data[0],y,opriv->y_width);
-      pixel_data[0]+=rowstrides[0];
-      y+=yuv.y_stride;
-      if (yuv.y_height==yuv.uv_height||crow) {
-	memcpy(pixel_data[1],u,opriv->uv_width);
-	memcpy(pixel_data[2],v,opriv->uv_width);
-	pixel_data[1]+=rowstrides[1];
-	pixel_data[2]+=rowstrides[2];
-	u+=yuv.uv_stride;
-	v+=yuv.uv_stride;
+    size_t srcadd;
+
+    for (p=0;p<nplanes;p++) {
+      dst=pixel_data[p];
+
+      switch (p) {
+      case 0:
+	src=yuv.y;
+	srcadd=yuv.y_stride;
+	break;
+      case 1:
+	src=yuv.u;
+	srcadd=yuv.uv_stride;
+	break;
+      case 2:
+	src=yuv.v;
+	srcadd=yuv.uv_stride;
+	break;
+      default:
+	srcadd=0;
+	src=NULL;
+	break;
+      }
+
+      for (i=0;i<xheight;i++) {
+	if (i<btop||i>bbot) {
+	  // top or bottom border, copy black row
+	  if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||
+	      pal==WEED_PALETTE_YUV444P||pal==WEED_PALETTE_YUVA4444P||pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) {
+	    memset(dst,black[p],dstwidth+(bleft+bright)*psize);
+	    dst+=dstwidth+(bleft+bright)*psize;
+	  }
+	  else dst+=write_black_pixel(dst,pal,dstwidth/psize+bleft+bright,y_black);
+	  continue;
+	}
+
+	if (bleft>0) {
+	  if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||pal==WEED_PALETTE_YUV444P||
+	      pal==WEED_PALETTE_YUVA4444P||pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) {
+	    memset(dst,black[p],bleft*psize);
+	    dst+=bleft*psize;
+	  }
+	  else dst+=write_black_pixel(dst,pal,bleft,y_black);
+	}
+
+	memcpy(dst,src,srcadd);
+	dst+=dstwidth;
+
+	if (bright>0) {
+	  if (pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P||pal==WEED_PALETTE_YUV444P||
+	      pal==WEED_PALETTE_YUVA4444P||pal==WEED_PALETTE_RGB24||pal==WEED_PALETTE_BGR24) {
+	    memset(dst,black[p],bright*psize);
+	    dst+=bright*psize;
+	  }
+	  else dst+=write_black_pixel(dst,pal,bright,y_black);
+	}
+
+	src+=srcadd;
+      }
+      if (p==0&&(pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P||pal==WEED_PALETTE_YUV422P)) {
+	dstwidth>>=1;
+	bleft>>=1;
+	bright>>=1;
+      }
+      if (p==0&&(pal==WEED_PALETTE_YUV420P||pal==WEED_PALETTE_YVU420P)) {
+	xheight>>=1;
+	btop>>=1;
+	bbot>>=1;
       }
-      crow=!crow;
-      sched_yield();
     }
-    
     return TRUE;
   }
 #endif
@@ -2675,6 +3082,13 @@ boolean get_frame(const lives_clip_data_t *cdata, int64_t tframe, int* rowstride
 void clip_data_free(lives_clip_data_t *cdata) {
   lives_ogg_priv_t *priv=(lives_ogg_priv_t *)cdata->priv;
 
+  if (cdata->palettes!=NULL) free(cdata->palettes);
+  cdata->palettes=NULL;
+
+  // free index entries
+  if (priv->idxc!=NULL) idxc_release(cdata); 
+  priv->idxc=NULL;
+
   if (cdata->URI!=NULL) {
     detach_stream(cdata);
     free(cdata->URI);
@@ -2684,8 +3098,10 @@ void clip_data_free(lives_clip_data_t *cdata) {
 
   if (priv!=NULL) free(priv);
   
-  if (cdata->palettes!=NULL) free(cdata->palettes);
   free(cdata);
 }
 
 
+void module_unload(void) {
+  idxc_release_all();
+}
