@@ -9,12 +9,12 @@
 
 #ifdef HAVE_SYSTEM_WEED
 #include <weed/weed.h>
+#include <weed/weed-palettes.h>
 #include <weed/weed-effects.h>
-#include <weed/weed-plugin.h>
 #else
 #include "../../libweed/weed.h"
+#include "../../libweed/weed-palettes.h"
 #include "../../libweed/weed-effects.h"
-#include "../../libweed/weed-plugin.h"
 #endif
 
 
@@ -27,16 +27,14 @@ static int package_version=1; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
-#ifdef HAVE_SYSTEM_WEED
-#include <weed/weed-utils.h> // optional
-#include <weed/weed-palettes.h> // optional
-#include <weed/weed-plugin-utils.h> // optional
+#ifdef HAVE_SYSTEM_WEED_PLUGIN_UTILS
+#include <weed/weed-plugin.h> // optional
 #else
-#include "../../libweed/weed-utils.h" // optional
-#include "../../libweed/weed-palettes.h" // optional
-#include "../../libweed/weed-plugin-utils.h" // optional
+#include "../../libweed/weed-plugin.h" // optional
 #endif
 
+#include "weed-utils-code.c" // optional
+#include "weed-plugin-utils.c" // optional
 
 /*
     The implementation of Syna functions
@@ -158,18 +156,21 @@ static int syna_load(_sdata *sdata, const char *tune) {
     FILE    *f;
     long    length;
 
+    int retval;
+
     /* Read the file and call syna_get */
     f=fopen(tune,"rb");
-    if (f==NULL)
-      return(WEED_ERROR_INIT_ERROR);
+    if (f==NULL) return WEED_ERROR_INIT_ERROR;
     fseek(f,0,SEEK_END);
     length=ftell(f);
     fseek(f,0,SEEK_SET);
     sdata->module=weed_malloc(length+1);
-    fread(sdata->module,1,length,f);
+    retval=fread(sdata->module,1,length,f);
     sdata->module[length]=0; /* String ends in zero */
     fclose(f);
 
+    if (retval<length) return WEED_ERROR_INIT_ERROR;
+
     return(syna_get(sdata));
 }
 #endif
@@ -326,7 +327,7 @@ static int syna_get(_sdata *sdata) {
   return WEED_NO_ERROR;
 }
 
-
+#if 0
 // added by Antti Silvast for setting all live the rows
 static void set_live_rows(_sdata *sdata, int * the_rows) {
   register int i;
@@ -336,6 +337,7 @@ static void set_live_rows(_sdata *sdata, int * the_rows) {
     //pi[i]=0;
   }
 }
+#endif
 
 // added by Antti Silvast for setting just one live row
 static void set_live_row(_sdata *sdata, int channel, int the_row) {
