@@ -58,12 +58,10 @@
 #include <weed/weed.h>
 #include <weed/weed-palettes.h>
 #include <weed/weed-effects.h>
-#include <weed/weed-plugin.h>
 #else
 #include "../../../libweed/weed.h"
 #include "../../../libweed/weed-palettes.h"
 #include "../../../libweed/weed-effects.h"
-#include "../../../libweed/weed-plugin.h"
 #endif
 
 
@@ -76,17 +74,15 @@ static int package_version=1; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
-#ifdef HAVE_SYSTEM_WEED
-#include <weed/weed-utils.h> // optional
+#ifdef HAVE_SYSTEM_WEED_PLUGIN_UTILS
+#include <weed/weed-plugin.h> // optional
 #else
-#include "../../../libweed/weed-utils.h" // optional
+#include "../../../libweed/weed-plugin.h" // optional
 #endif
 
-#ifdef HAVE_SYSTEM_WEED_PLUGIN_UTILS
-#include <weed/weed-plugin-utils.h> // optional
-#else
-#include "../../../libweed/weed-plugin-utils.h" // optional
-#endif
+#include "../weed-utils-code.c" // optional
+#include "../weed-plugin-utils.c" // optional
+
 
 /////////////////////////////////////////////////////////////
 
