@@ -7,12 +7,12 @@
 
 #ifdef HAVE_SYSTEM_WEED
 #include <weed/weed.h>
+#include <weed/weed-palettes.h> // optional
 #include <weed/weed-effects.h>
-#include <weed/weed-plugin.h>
 #else
 #include "../../libweed/weed.h"
+#include "../../libweed/weed-palettes.h" // optional
 #include "../../libweed/weed-effects.h"
-#include "../../libweed/weed-plugin.h"
 #endif
 
 
@@ -25,18 +25,15 @@ static int package_version=1; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
-#ifdef HAVE_SYSTEM_WEED
-#include <weed/weed.h>
-#include <weed/weed-utils.h> // optional
-#include <weed/weed-palettes.h> // optional
-#include <weed/weed-plugin-utils.h> // optional
+#ifdef HAVE_SYSTEM_WEED_PLUGIN_UTILS
+#include <weed/weed-plugin.h> // optional
 #else
-#include "../../libweed/weed.h" // optional
-#include "../../libweed/weed-utils.h" // optional
-#include "../../libweed/weed-palettes.h" // optional
-#include "../../libweed/weed-plugin-utils.h" // optional
+#include "../../libweed/weed-plugin.h" // optional
 #endif
 
+#include "weed-utils-code.c" // optional
+#include "weed-plugin-utils.c" // optional
+
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -955,13 +952,13 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	    }
 
 	  }
-	fprintf(stderr,"3checking %s\n",plug1);
 
 	  snprintf(weed_name,PATH_MAX,"LADSPA: %s",laddes->Name);
 
-	  filter_class=weed_filter_class_init(weed_name,laddes->Maker,0,0,&ladspa_init,&ladspa_process,&ladspa_deinit,
+	  filter_class=weed_filter_class_init(weed_name,"LADSPA developers",0,0,&ladspa_init,&ladspa_process,&ladspa_deinit,
 					      in_chantmpls,out_chantmpls,in_params,out_params);
 	
+	  weed_set_string_value(filter_class,"extra_authors",laddes->Maker);
 
 	  weed_set_voidptr_value(filter_class,"plugin_lad_descriptor",laddes);
 
