@@ -31,7 +31,7 @@
 #define NSTOREDFDS 16
 static gchar *storedfnames[NSTOREDFDS];
 static int storedfds[NSTOREDFDS];
-static gboolean storedfdsset=FALSE;
+static boolean storedfdsset=FALSE;
 
 static void audio_reset_stored_fnames(void) {
   int i;
@@ -178,7 +178,8 @@ void sample_move_d16_d16(short *dst, short *src,
 	}
 	else {
 	  if (!swap_sign) *(dst++)=(((*ptr)&0x00FF)<<8)+((*ptr)>>8);
-	  else if (swap_sign==SWAP_S_TO_U) *((uint16_t *)dst++)=(uint16_t)(((((uint16_t)(*ptr+SAMPLE_MAX_16BITI))&0x00FF)<<8)+(((uint16_t)(*ptr+SAMPLE_MAX_16BITI))>>8));
+	  else if (swap_sign==SWAP_S_TO_U) *((uint16_t *)dst++)=(uint16_t)(((((uint16_t)(*ptr+SAMPLE_MAX_16BITI))&0x00FF)<<8)+
+									   (((uint16_t)(*ptr+SAMPLE_MAX_16BITI))>>8));
 	  else *(dst++)=((((int16_t)(*ptr-SAMPLE_MAX_16BITI))&0x00FF)<<8)+(((int16_t)(*ptr-SAMPLE_MAX_16BITI))>>8);
 	}
 
@@ -329,7 +330,7 @@ void sample_move_float_float (float *dst, float *src, uint64_t nsamples, uint64_
 
 
 int64_t sample_move_float_int(void *holding_buff, float **float_buffer, int nsamps, float scale, int chans, int asamps, 
-			      int usigned, gboolean little_endian, gboolean interleaved, float vol) {
+			      int usigned, boolean little_endian, boolean interleaved, float vol) {
   // convert float samples back to int
   // interleaved is for the float buffer; output int is always interleaved
   int64_t frames_out=0l;
@@ -375,7 +376,7 @@ int64_t sample_move_float_int(void *holding_buff, float **float_buffer, int nsam
       }
       offs++;
     }
-    coffs=(gint)(coffs_f+=scale);
+    coffs=(int)(coffs_f+=scale);
   }
   return frames_out;
 }
@@ -675,14 +676,14 @@ static size_t chunk_to_int16_abuf(lives_audio_buf_t *abuf, float **float_buffer,
 
 //#define DEBUG_ARENDER
 
-static gboolean pad_with_silence(int out_fd, off64_t oins_size, int64_t ins_size, int asamps, int aunsigned, gboolean big_endian) {
+static boolean pad_with_silence(int out_fd, off64_t oins_size, int64_t ins_size, int asamps, int aunsigned, boolean big_endian) {
   // fill to ins_pt with zeros (or 0x80.. for unsigned)
   uint8_t *zero_buff;
   size_t sblocksize=SILENCE_BLOCK_SIZE;
-  gint sbytes=ins_size-oins_size;
+  int sbytes=ins_size-oins_size;
   register int i;
 
-  gboolean retval=TRUE;
+  boolean retval=TRUE;
 
 #ifdef DEBUG_ARENDER
   g_print("sbytes is %d\n",sbytes);
@@ -774,7 +775,9 @@ static void audio_process_events_to(weed_timecode_t tc) {
 
 
 
-int64_t render_audio_segment(gint nfiles, gint *from_files, gint to_file, double *avels, double *fromtime, weed_timecode_t tc_start, weed_timecode_t tc_end, double *chvol, double opvol_start, double opvol_end, lives_audio_buf_t *obuf) {
+int64_t render_audio_segment(int nfiles, int *from_files, int to_file, double *avels, double *fromtime, 
+			     weed_timecode_t tc_start, weed_timecode_t tc_end, double *chvol, double opvol_start, 
+			     double opvol_end, lives_audio_buf_t *obuf) {
   // called during multitrack rendering to create the actual audio file
   // (or in-memory buffer for preview playback in multitrack)
 
@@ -810,11 +813,11 @@ int64_t render_audio_segment(gint nfiles, gint *from_files, gint to_file, double
   size_t tbytes;
   uint8_t *in_buff;
 
-  gint out_asamps=to_file>-1?outfile->asampsize/8:0;
-  gint out_achans=to_file>-1?outfile->achans:obuf->out_achans;
-  gint out_arate=to_file>-1?outfile->arate:obuf->arate;
-  gint out_unsigned=to_file>-1?outfile->signed_endian&AFORM_UNSIGNED:0;
-  gint out_bendian=to_file>-1?outfile->signed_endian&AFORM_BIG_ENDIAN:0;
+  int out_asamps=to_file>-1?outfile->asampsize/8:0;
+  int out_achans=to_file>-1?outfile->achans:obuf->out_achans;
+  int out_arate=to_file>-1?outfile->arate:obuf->arate;
+  int out_unsigned=to_file>-1?outfile->signed_endian&AFORM_UNSIGNED:0;
+  int out_bendian=to_file>-1?outfile->signed_endian&AFORM_BIG_ENDIAN:0;
 
   short *holding_buff;
   float *float_buffer[out_achans*nfiles];
@@ -829,7 +832,7 @@ int64_t render_audio_segment(gint nfiles, gint *from_files, gint to_file, double
 
   uint64_t nframes;
 
-  gboolean in_reverse_endian[nfiles],out_reverse_endian=FALSE;
+  boolean in_reverse_endian[nfiles],out_reverse_endian=FALSE;
 
   off64_t seekstart[nfiles];
   gchar *infilename,*outfilename;
@@ -846,14 +849,14 @@ int64_t render_audio_segment(gint nfiles, gint *from_files, gint to_file, double
 
   int track;
 
-  gint in_asamps[nfiles];
-  gint in_achans[nfiles];
-  gint in_arate[nfiles];
-  gint in_unsigned[nfiles];
-  gint in_bendian;
+  int in_asamps[nfiles];
+  int in_achans[nfiles];
+  int in_arate[nfiles];
+  int in_unsigned[nfiles];
+  int in_bendian;
 
-  gboolean is_silent[nfiles];
-  gint first_nonsilent=-1;
+  boolean is_silent[nfiles];
+  int first_nonsilent=-1;
 
   int64_t tsamples=((tc_end-tc_start)/U_SEC*out_arate+.5);
 
@@ -864,7 +867,7 @@ int64_t render_audio_segment(gint nfiles, gint *from_files, gint to_file, double
   weed_plant_t *shortcut=NULL;
 
   size_t max_aud_mem,bytes_to_read,aud_buffer;
-  gint max_segments;
+  int max_segments;
   double zavel,zavel_max=0.;
 
   int64_t tot_frames=0l;
@@ -1087,7 +1090,7 @@ int64_t render_audio_segment(gint nfiles, gint *from_files, gint to_file, double
 
       zavel=avels[track]*(double)in_arate[track]/(double)out_arate;
 
-      tbytes=(gint)((double)xsamples*ABS(zavel)+((double)fastrand()/(double)G_MAXUINT32))*
+      tbytes=(int)((double)xsamples*ABS(zavel)+((double)fastrand()/(double)G_MAXUINT32))*
 	in_asamps[track]*in_achans[track];
 
       in_buff=(uint8_t *)g_malloc(tbytes);
@@ -1256,7 +1259,7 @@ int64_t render_audio_segment(gint nfiles, gint *from_files, gint to_file, double
 }
 
 
-LIVES_INLINE void aud_fade(gint fileno, double startt, double endt, double startv, double endv) {
+LIVES_INLINE void aud_fade(int fileno, double startt, double endt, double startv, double endv) {
   double vel=1.,vol=1.;
 
   mainw->read_failed=mainw->write_failed=FALSE;
@@ -1277,9 +1280,12 @@ LIVES_INLINE void aud_fade(gint fileno, double startt, double endt, double start
 
 
 #ifdef ENABLE_JACK
-void jack_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t rec_type) {
+void jack_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t rec_type) {
   // open audio file for writing
   file *outfile;
+
+  boolean jackd_read_started=(mainw->jackd_read!=NULL);
+
   int retval;
 
   if (fileno==-1) {
@@ -1292,7 +1298,7 @@ void jack_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t r
       
     // start jack "recording"
     jack_open_device_read(mainw->jackd_read);
-    jack_read_driver_activate(mainw->jackd_read);
+    jack_read_driver_activate(mainw->jackd_read,FALSE);
 
     return;
   }
@@ -1319,7 +1325,7 @@ void jack_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t r
     mainw->jackd->playing_file=fileno;
   }
   else {
-    mainw->jackd_read=jack_get_driver(0,FALSE);
+    if (!jackd_read_started) mainw->jackd_read=jack_get_driver(0,FALSE);
     mainw->jackd_read->playing_file=fileno;
     mainw->jackd_read->frames_written=0;
   }
@@ -1330,17 +1336,21 @@ void jack_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t r
 #endif
 
   if (rec_type==RECA_EXTERNAL||rec_type==RECA_GENERATED) {
-    gint asigned;
-    gint aendian;
+    int asigned;
+    int aendian;
     uint64_t fsize=get_file_size(mainw->aud_rec_fd);
     
     if (rec_type==RECA_EXTERNAL) {
       mainw->jackd_read->reverse_endian=FALSE;
       
       // start jack recording
-      jack_open_device_read(mainw->jackd_read);
-      jack_read_driver_activate(mainw->jackd_read);
-      
+
+      // TODO - only if not active
+      if (!jackd_read_started) {
+	jack_open_device_read(mainw->jackd_read);
+	jack_read_driver_activate(mainw->jackd_read,FALSE);
+      }
+
       outfile->arate=outfile->arps=mainw->jackd_read->sample_in_rate;
       outfile->achans=mainw->jackd_read->num_input_channels;
       
@@ -1373,7 +1383,8 @@ void jack_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t r
 
   }
   else {
-    gint out_bendian=outfile->signed_endian&AFORM_BIG_ENDIAN;
+
+    int out_bendian=outfile->signed_endian&AFORM_BIG_ENDIAN;
 
     if ((!out_bendian&&(capable->byte_order==LIVES_BIG_ENDIAN))||
 	(out_bendian&&(capable->byte_order==LIVES_LITTLE_ENDIAN))) 
@@ -1382,7 +1393,7 @@ void jack_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t r
     
     // start jack recording
     jack_open_device_read(mainw->jackd_read);
-    jack_read_driver_activate(mainw->jackd_read);
+    jack_read_driver_activate(mainw->jackd_read,TRUE);
   }
 
   // in grab window mode, just return, we will call rec_audio_end on playback end
@@ -1398,7 +1409,7 @@ void jack_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t r
     do_auto_dialog(_("Recording audio"),1);
   }
   else {
-    gint current_file=mainw->current_file;
+    int current_file=mainw->current_file;
     mainw->current_file=old_file;
     on_playsel_activate(NULL,NULL);
     mainw->current_file=current_file;
@@ -1428,7 +1439,7 @@ void jack_rec_audio_end(boolean close_fd) {
 
 
 #ifdef HAVE_PULSE_AUDIO
-void pulse_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t rec_type) {
+void pulse_rec_audio_to_clip(int fileno, int old_file, lives_rec_audio_type_t rec_type) {
   // open audio file for writing
   file *outfile;
   int retval;
@@ -1479,8 +1490,8 @@ void pulse_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t
 #endif
 
   if (rec_type==RECA_EXTERNAL||rec_type==RECA_GENERATED) {
-    gint asigned;
-    gint aendian;
+    int asigned;
+    int aendian;
     uint64_t fsize=get_file_size(mainw->aud_rec_fd);
 
     if (rec_type==RECA_EXTERNAL) {
@@ -1520,7 +1531,7 @@ void pulse_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t
 
   }
   else {
-    gint out_bendian=outfile->signed_endian&AFORM_BIG_ENDIAN;
+    int out_bendian=outfile->signed_endian&AFORM_BIG_ENDIAN;
     
     if ((!out_bendian&&(capable->byte_order==LIVES_BIG_ENDIAN))||
 	(out_bendian&&(capable->byte_order==LIVES_LITTLE_ENDIAN))) 
@@ -1542,7 +1553,7 @@ void pulse_rec_audio_to_clip(gint fileno, gint old_file, lives_rec_audio_type_t
   mainw->suppress_dprint=TRUE;
   if (rec_type==RECA_NEW_CLIP) do_auto_dialog(_("Recording audio"),1);
   else {
-    gint current_file=mainw->current_file;
+    int current_file=mainw->current_file;
     mainw->current_file=old_file;
     on_playsel_activate(NULL,NULL);
     mainw->current_file=current_file;
@@ -1659,7 +1670,7 @@ static lives_audio_track_state_t *aframe_to_atstate(weed_plant_t *event) {
 
 
 lives_audio_track_state_t *get_audio_and_effects_state_at(weed_plant_t *event_list, weed_plant_t *st_event, 
-							  gboolean get_audstate, gboolean exact) {
+							  boolean get_audstate, boolean exact) {
 
   // if exact is set, we must rewind back to first active stateful effect, 
   // and play forwards from there (not yet implemented - TODO)
@@ -1749,7 +1760,7 @@ lives_audio_track_state_t *get_audio_and_effects_state_at(weed_plant_t *event_li
 
 
 
-void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_plant_t *st_event, gboolean exact) {
+void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_plant_t *st_event, boolean exact) {
   // fill audio buffer with audio samples, using event_list as a guide
   // if st_event!=NULL, that is our start event, and we will calculate the audio state at that
   // point
@@ -1771,7 +1782,7 @@ void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_p
   static int *from_files=NULL;
   static double *aseeks=NULL,*avels=NULL;
 
-  gboolean is_cont=FALSE;
+  boolean is_cont=FALSE;
   if (abuf==NULL) return;
 
   abuf->samples_filled=0; // write fill level of buffer
@@ -1803,7 +1814,7 @@ void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_p
     // the *last* frame in the buffer and then adjust the seeks back to the
     // beginning of the buffer, in case an audio track starts during the
     // buffering period. The current way is fine for a preview, but when we 
-    // implement rendering of partial event lists we will need to do this
+    // implement rendering of *partial* event lists we will need to do this
 
     // a negative seek value would mean that we need to pad silence at the 
     // start of the track buffer
@@ -1928,7 +1939,7 @@ void fill_abuffer_from(lives_audio_buf_t *abuf, weed_plant_t *event_list, weed_p
 
 
 
-void init_jack_audio_buffers (gint achans, gint arate, gboolean exact) {
+void init_jack_audio_buffers (int achans, int arate, boolean exact) {
 #ifdef ENABLE_JACK
 
   int i,chan;
@@ -1950,7 +1961,7 @@ void init_jack_audio_buffers (gint achans, gint arate, gboolean exact) {
 }
 
 
-void init_pulse_audio_buffers (gint achans, gint arate, gboolean exact) {
+void init_pulse_audio_buffers (int achans, int arate, boolean exact) {
 #ifdef HAVE_PULSE_AUDIO
 
   int i;
@@ -2017,7 +2028,7 @@ void free_pulse_audio_buffers(void) {
 
 
 
-gboolean resync_audio(gint frameno) {
+boolean resync_audio(int frameno) {
   // if we are using a realtime audio player, resync to frameno
   // and return TRUE
 
@@ -2453,7 +2464,7 @@ lives_audio_buf_t *audio_cache_get_buffer(void) {
 
 // plugin handling
 
-gboolean get_audio_from_plugin(float *fbuffer, int nchans, int arate, int nsamps) {
+boolean get_audio_from_plugin(float *fbuffer, int nchans, int arate, int nsamps) {
   // get audio from an audio generator; fbuffer is filled with non-interleaved float
 
   weed_timecode_t tc;
@@ -2525,9 +2536,9 @@ gboolean get_audio_from_plugin(float *fbuffer, int nchans, int arate, int nsamps
 
   if (mainw->pconx!=NULL&&!(mainw->preview||mainw->is_rendering)) {
     // chain any data pipelines
-    if (!pthread_mutex_trylock(&mainw->data_mutex)) {
+    if (!pthread_mutex_trylock(&mainw->data_mutex[mainw->agen_key-1])) {
       mainw->agen_needs_reinit=pconx_chain_data(mainw->agen_key-1,rte_key_getmode(mainw->agen_key));
-      pthread_mutex_unlock(&mainw->data_mutex);
+      filter_mutex_unlock(mainw->agen_key-1);
       
       if (mainw->agen_needs_reinit) {
 	// allow main thread to complete the reinit so we do not delay; just return silence
@@ -2800,28 +2811,24 @@ boolean apply_rte_audio(int nframes) {
 ////////////////////////////////////////
 // audio streaming
 
-#ifndef IS_MINGW
-static int astream_pid=0;
-#endif
-
-gboolean start_audio_stream(void) {
-#ifdef IS_MINGW
-  return FALSE;
-#else
+lives_pgid_t astream_pgid=0;
 
+boolean start_audio_stream(void) {
   const gchar *playername="audiostreamer.pl";
   gchar *astream_name=NULL;
   gchar *astream_name_out=NULL;
 
   // playback plugin wants an audio stream - so fork and run the stream
   // player
-  gchar *astname=g_strdup_printf("livesaudio-%d.pcm",getpid());
-  gchar *astname_out=g_strdup_printf("livesaudio-%d.stream",getpid());
+  gchar *astname=g_strdup_printf("livesaudio-%d.pcm",capable->mainpid);
+  gchar *astname_out=g_strdup_printf("livesaudio-%d.stream",capable->mainpid);
+  gchar *astreamer,*com;
 
   int arate=0;
   int afd;
   int alarm_handle;
-  gboolean timeout=FALSE;
+
+  boolean timeout=FALSE;
 
   astream_name=g_build_filename(prefs->tmpdir,astname,NULL);
 
@@ -2847,24 +2854,11 @@ gboolean start_audio_stream(void) {
 #endif
   }
 
+  astreamer=g_build_filename(prefs->lib_dir,PLUGIN_EXEC_DIR,PLUGIN_AUDIO_STREAM,playername,NULL);
+  com=g_strdup_printf("%s play %d \"%s\" \"%s\" %d",astreamer,mainw->vpp->audio_codec,astream_name,astream_name_out,arate);
+  g_free(astreamer);
 
-  astream_pid=fork();
-
-  if (!astream_pid) {
-    // mkfifo and play until killed
-    gchar *astreamer=g_build_filename(prefs->lib_dir,PLUGIN_EXEC_DIR,PLUGIN_AUDIO_STREAM,playername,NULL);
-    gchar *com=g_strdup_printf("%s play %d \"%s\" \"%s\" %d",astreamer,mainw->vpp->audio_codec,astream_name,astream_name_out,arate);
-
-    setsid(); // create new session id
-
-    g_free(astreamer);
-    
-    // block here until killed
-
-    lives_system(com,TRUE);
-
-    _exit(0);                    
-  }
+  astream_pgid=lives_fork(com);
 
   alarm_handle=lives_alarm_set(LIVES_ACONNECT_TIMEOUT);
 
@@ -2901,18 +2895,16 @@ gboolean start_audio_stream(void) {
   g_free(astream_name_out);
 
   return TRUE;
-#endif
 }
 
 
 
 void stop_audio_stream(void) {
-#ifndef IS_MINGW
-  if (astream_pid>0) {
+  if (astream_pgid>0) {
     // if we were streaming audio, kill it
     const gchar *playername="audiostreamer.pl";
-    gchar *astname=g_strdup_printf("livesaudio-%d.pcm",getpid());
-    gchar *astname_out=g_strdup_printf("livesaudio-%d.stream",getpid());
+    gchar *astname=g_strdup_printf("livesaudio-%d.pcm",capable->mainpid);
+    gchar *astname_out=g_strdup_printf("livesaudio-%d.stream",capable->mainpid);
     gchar *astreamer=g_build_filename(prefs->lib_dir,PLUGIN_EXEC_DIR,PLUGIN_AUDIO_STREAM,playername,NULL);
 
     gchar *astream_name=g_build_filename(prefs->tmpdir,astname,NULL);
@@ -2920,8 +2912,6 @@ void stop_audio_stream(void) {
 
     gchar *com;
 
-    pid_t pgid=getpgid(astream_pid);
-
     g_free(astname);
     g_free(astname_out);
 
@@ -2938,7 +2928,7 @@ void stop_audio_stream(void) {
 #endif
     }
 
-    lives_kill(-pgid,LIVES_SIGKILL);
+    lives_killpg(astream_pgid,LIVES_SIGKILL);
     unlink(astream_name);
     g_free(astream_name);
 
@@ -2951,15 +2941,14 @@ void stop_audio_stream(void) {
 
   }
 
-#endif
 }
 
 
 void clear_audio_stream(void) {
   // remove raw and cooked streams
-  gchar *astname=g_strdup_printf("livesaudio-%d.pcm",getpid());
+  gchar *astname=g_strdup_printf("livesaudio-%d.pcm",capable->mainpid);
   gchar *astream_name=g_build_filename(prefs->tmpdir,astname,NULL);
-  gchar *astname_out=g_strdup_printf("livesaudio-%d.stream",getpid());
+  gchar *astname_out=g_strdup_printf("livesaudio-%d.stream",capable->mainpid);
   gchar *astream_name_out=g_build_filename(prefs->tmpdir,astname_out,NULL);
   unlink(astream_name);
   unlink(astream_name_out);
