@@ -38,6 +38,8 @@ static int rte_keys_virtual;
 static int n_screen_areas;
 static int n_clip_boxes;
 
+static int next_screen_area;
+
 static void ce_thumbs_remove_param_boxes(boolean remove_pinned);
 static void ce_thumbs_remove_param_box(int key);
 
@@ -67,15 +69,29 @@ static void ce_thumbs_fx_changed (GtkComboBox *combo, gpointer user_data) {
 #endif
 
 
+void ce_thumbs_set_key_check_state(void) {
+  // set (delayed) keycheck state
+  register int i;
+  for (i=0;i<prefs->rte_keys_virtual;i++) {
+    g_signal_handler_block(key_checks[i],ch_fns[i]);
+    lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(key_checks[i]),GPOINTER_TO_INT(g_object_get_data(G_OBJECT(key_checks[i]),"active")));
+    if (!lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(key_checks[i]))&&pscrolls[i]!=NULL) ce_thumbs_remove_param_box(i);
+    g_signal_handler_unblock(key_checks[i],ch_fns[i]);
+  }
+}
+
+
 void ce_thumbs_set_keych (int key, boolean on) {
   // set key check from other source
   if (key>=rte_keys_virtual) return;
   g_signal_handler_block(key_checks[key],ch_fns[key]);
-  pthread_mutex_lock(&mainw->gtk_mutex);
-  lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(key_checks[key]),on);
-  pthread_mutex_unlock(&mainw->gtk_mutex);
-  if (!on&&pscrolls[key]!=NULL) ce_thumbs_remove_param_box(key);
+  if (!pthread_mutex_trylock(&mainw->gtk_mutex)) {
+    lives_toggle_button_set_active (LIVES_TOGGLE_BUTTON(key_checks[key]),on);
+    if (!on&&pscrolls[key]!=NULL) ce_thumbs_remove_param_box(key);
+    pthread_mutex_unlock(&mainw->gtk_mutex);
+  }
   g_signal_handler_unblock(key_checks[key],ch_fns[key]);
+  g_object_set_data(G_OBJECT(key_checks[key]),"active",GINT_TO_POINTER(on));
 }
 
 
@@ -96,6 +112,8 @@ static void pin_toggled (LiVESToggleButton *t, livespointer pkey) {
   g_object_set_data (G_OBJECT (pscrolls[key]),"pinned",LIVES_INT_TO_POINTER (!state));
 }
 
+#if GTK_CHECK_VERSION(3,2,0)  // required for grid widget
+
 static void clip_area_toggled (LiVESToggleButton *t, livespointer parea) {
   int area=LIVES_POINTER_TO_INT(parea);
   if (lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(rb_clip_areas[area]))) {
@@ -104,6 +122,7 @@ static void clip_area_toggled (LiVESToggleButton *t, livespointer parea) {
   }
 }
 
+#endif
 
 #define SPARE_CLIP_BOXES 100
 
@@ -145,6 +164,8 @@ void start_ce_thumb_mode(void) {
   n_screen_areas=mainw->n_screen_areas;
   n_clip_boxes=g_list_length(mainw->cliplist)+SPARE_CLIP_BOXES;
 
+  next_screen_area=SCREEN_AREA_NONE;
+
   lives_grid_set_row_spacing (LIVES_GRID(tgrid),0);
   lives_grid_set_column_spacing (LIVES_GRID(tgrid),0);
 
@@ -203,6 +224,7 @@ void start_ce_thumb_mode(void) {
     g_free(tmp);
 
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(key_checks[i]),mainw->rte&(GU641<<i));
+    g_object_set_data(G_OBJECT(key_checks[i]),"active",GINT_TO_POINTER(lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(key_checks[i]))));
 
     ch_fns[i]=g_signal_connect_after (GTK_OBJECT (key_checks[i]), "toggled",
 				      G_CALLBACK (rte_on_off_callback_hook),GINT_TO_POINTER (i+1));
@@ -393,12 +415,12 @@ void start_ce_thumb_mode(void) {
   }
 
   if (prefs->open_maximised) {
-    lives_window_maximize (GTK_WINDOW(mainw->LiVES));
+    lives_window_maximize (LIVES_WINDOW(mainw->LiVES));
   }
 
   lives_widget_show_all(top_hbox);
 
-  ce_thumbs_liberate_bg_clip_area(mainw->num_tr_applied>0);
+  ce_thumbs_liberate_clip_area(mainw->num_tr_applied>0?SCREEN_AREA_BACKGROUND:SCREEN_AREA_FOREGROUND);
   ce_thumbs_set_clip_area();
 
   mainw->ce_thumbs=TRUE;
@@ -500,7 +522,7 @@ void ce_thumbs_add_param_box(int key, boolean remove) {
   on_fx_pre_activate(rfx,1,vbox);
 
   // record the key so we know whose parameters to record later
-  weed_set_int_value((weed_plant_t *)rfx->source,"host_hotkey",key);
+  weed_set_int_value((weed_plant_t *)rfx->source,"host_key",key);
 
   g_object_set_data (G_OBJECT (pscrolls[key]),"pinned",LIVES_INT_TO_POINTER (FALSE));
   g_object_set_data (G_OBJECT (pscrolls[key]),"update",LIVES_INT_TO_POINTER (FALSE));
@@ -653,6 +675,11 @@ void ce_thumbs_set_fx_area(int area) {
 }
 
 
+void ce_thumbs_update_current_clip(void) {
+  mainw->ce_upd_clip=TRUE;
+}
+
+
 void ce_thumbs_highlight_current_clip(void) {
   // unprelight all clip boxes, prelight current clip (fg or bg)
   boolean match=FALSE;
@@ -685,6 +712,20 @@ void ce_thumbs_highlight_current_clip(void) {
 }
 
 
-void ce_thumbs_liberate_bg_clip_area(boolean liberate) {
-  lives_widget_set_sensitive(rb_clip_areas[SCREEN_AREA_BACKGROUND],liberate);
+void ce_thumbs_liberate_clip_area(int area) {
+  lives_widget_set_sensitive(rb_clip_areas[area],TRUE);
+  ce_thumbs_set_clip_area();
 }
+
+
+void ce_thumbs_liberate_clip_area_register(int area) {
+  next_screen_area=area;
+}
+
+
+void ce_thumbs_apply_liberation(void) {
+  if (next_screen_area!=SCREEN_AREA_NONE)
+    ce_thumbs_liberate_clip_area(next_screen_area);
+  next_screen_area=SCREEN_AREA_NONE;
+}
+
