@@ -16,6 +16,7 @@ void ce_thumbs_set_mode_combo (int key, int mode);
 
 void ce_thumbs_add_param_box(int key, boolean remove);
 
+void ce_thumbs_set_key_check_state(void);
 
 void ce_thumbs_register_rfx_change(int key, int mode);
 void ce_thumbs_apply_rfx_changes(void);
@@ -30,8 +31,11 @@ void ce_thumbs_reset_combo(int key);
 void ce_thumbs_set_clip_area(void);
 void ce_thumbs_set_fx_area(int area);
 
+void ce_thumbs_update_current_clip(void);
 void ce_thumbs_highlight_current_clip(void);
 
-void ce_thumbs_liberate_bg_clip_area(boolean liberate);
+void ce_thumbs_liberate_clip_area(boolean liberate);
+void ce_thumbs_liberate_clip_area_register(boolean liberate);
+void ce_thumbs_apply_liberation(void);
 
 #endif // HAS_LIVES_CE_THUMBS_H
