@@ -115,6 +115,7 @@ int num_out_params(weed_plant_t *);
 weed_plant_t *weed_inst_in_param (weed_plant_t *inst, int param_num, boolean skip_hidden, boolean skip_internal);
 weed_plant_t *weed_inst_out_param (weed_plant_t *inst, int param_num);
 weed_plant_t *weed_filter_in_paramtmpl (weed_plant_t *filter, int param_num, boolean skip_internal);
+weed_plant_t *weed_filter_out_paramtmpl (weed_plant_t *filter, int param_num);
 boolean is_hidden_param(weed_plant_t *, int i);
 int get_nth_simple_param(weed_plant_t *, int pnum);
 int count_simple_params(weed_plant_t *);
@@ -130,6 +131,9 @@ boolean weed_parameter_has_variable_elements_strict(weed_plant_t *inst, weed_pla
 boolean interpolate_param(weed_plant_t *inst, int i, void *pchain, weed_timecode_t tc);
 boolean interpolate_params(weed_plant_t *inst, void **pchains, weed_timecode_t tc);
 
+void filter_mutex_lock(int key);
+void filter_mutex_unlock(int key);
+
 boolean weed_plant_serialise(int fd, weed_plant_t *plant, unsigned char **mem);
 weed_plant_t *weed_plant_deserialise(int fd, unsigned char **mem);
 
