@@ -560,7 +560,7 @@ boolean do_effect(lives_rfx_t *rfx, boolean is_preview) {
       if (!(rfx->props&RFX_PROPS_BATCHG)) {
 	// gen to new file
 	cfile->is_loaded=TRUE;
-	add_to_winmenu();
+	add_to_clipmenu();
 	if (!save_clip_values(new_file)) {
 	  close_current_file(current_file);
 	  return FALSE;
@@ -766,7 +766,7 @@ boolean on_realfx_activate_inner(int type, lives_rfx_t *rfx) {
       lives_widget_context_update();
       gdk_window_raise(lives_widget_get_xwindow(resaudw->dialog));
 
-      if (lives_dialog_run(GTK_DIALOG(resaudw->dialog))!=GTK_RESPONSE_OK) return FALSE;
+      if (lives_dialog_run(LIVES_DIALOG(resaudw->dialog))!=GTK_RESPONSE_OK) return FALSE;
       if (mainw->error) {
 	mainw->error=FALSE;
 	return FALSE;
@@ -965,7 +965,7 @@ void deinterlace_frame(weed_plant_t *layer, weed_timecode_t tc) {
   weed_set_int_value(init_event,"out_tracks",0);
  
  deint1:
- 
+
   weed_apply_instance(deint_instance,init_event,layers,0,0,tc);
   
   if (weed_plant_has_leaf(deint_instance,"host_next_instance")) next_inst=weed_get_plantptr_value(deint_instance,"host_next_instance",&error);
@@ -995,7 +995,6 @@ void deinterlace_frame(weed_plant_t *layer, weed_timecode_t tc) {
 
 weed_plant_t *get_blend_layer(weed_timecode_t tc) {
   file *blend_file;
-  weed_plant_t *layer;
   static weed_timecode_t blend_tc=0;
   weed_timecode_t ntc=tc;
 
@@ -1014,14 +1013,13 @@ weed_plant_t *get_blend_layer(weed_timecode_t tc) {
 
   blend_tc=ntc;
 
-  layer=weed_plant_new(WEED_PLANT_CHANNEL);
-  weed_set_int_value(layer,"clip",mainw->blend_file);
-  weed_set_int_value(layer,"frame",blend_file->frameno);
-  if (!pull_frame(layer,get_image_ext_for_type(blend_file->img_type),tc)) {
-    weed_plant_free(layer);
-    layer=NULL;
-  }
-  return layer;
+  mainw->blend_layer=weed_plant_new(WEED_PLANT_CHANNEL);
+  weed_set_int_value(mainw->blend_layer,"clip",mainw->blend_file);
+  weed_set_int_value(mainw->blend_layer,"frame",blend_file->frameno);
+
+  pull_frame_threaded(mainw->blend_layer,get_image_ext_for_type(blend_file->img_type),tc);
+
+  return mainw->blend_layer;
 }
 
 
@@ -1057,7 +1055,9 @@ boolean rte_on_off_callback (GtkAccelGroup *group, GObject *obj, guint keyval, G
       // WARNING - if we start playing because a generator was started, we block here
       if (!(weed_init_effect(key-1))) {
 	// ran out of instance slots, no effect assigned, or some other error
+	pthread_mutex_lock(&mainw->event_list_mutex);
 	if (mainw->rte&new_rte) mainw->rte^=new_rte;
+	pthread_mutex_unlock(&mainw->event_list_mutex);
 	if (rte_window!=NULL) rtew_set_keych(key-1,FALSE);
 	if (mainw->ce_thumbs) ce_thumbs_set_keych(key-1,FALSE);
 	mainw->osc_block=FALSE;
@@ -1079,7 +1079,9 @@ boolean rte_on_off_callback (GtkAccelGroup *group, GObject *obj, guint keyval, G
     else {
       // effect is OFF
       weed_deinit_effect(key-1);
+      pthread_mutex_lock(&mainw->event_list_mutex);
       if (mainw->rte&new_rte) mainw->rte^=new_rte;
+      pthread_mutex_unlock(&mainw->event_list_mutex);
       if (rte_window!=NULL) rtew_set_keych(key-1,FALSE);
       if (mainw->ce_thumbs) ce_thumbs_set_keych(key-1,FALSE);
     }
@@ -1149,6 +1151,7 @@ boolean grabkeys_callback_hook (GtkToggleButton *button, gpointer user_data) {
 
 
 boolean rtemode_callback (GtkAccelGroup *group, GObject *obj, guint keyval, GdkModifierType mod, gpointer user_data) {
+  // "m" mode key
   if (mainw->rte_keys==-1) return TRUE;
   rte_key_setmode(0,-1);
   mainw->blend_factor=weed_get_blend_factor(mainw->rte_keys);
@@ -1183,8 +1186,10 @@ boolean swap_fg_bg_callback (GtkAccelGroup *group, GObject *obj, guint keyval, G
   mainw->blend_file=old_file;
 
   rte_swap_fg_bg();
+
   if (mainw->ce_thumbs&&(mainw->active_sa_clips==SCREEN_AREA_BACKGROUND||mainw->active_sa_clips==SCREEN_AREA_FOREGROUND)) 
     ce_thumbs_highlight_current_clip();
+
   return TRUE;
 
   // **TODO - for weed, invert all transition parameters for any active effects
