@@ -20,7 +20,7 @@ Alexandre Pereira Bueno - alpebu@yahoo.com.br
 James Scott Jr <skoona@users.sourceforge.net>
 */
 
-// additional code G. Finch (salsaman@gmail.com) 2010 - 2012
+// additional code G. Finch (salsaman@gmail.com) 2010 - 2013
 
 
 #include <stdio.h>
@@ -39,31 +39,41 @@ James Scott Jr <skoona@users.sourceforge.net>
 /* Forward declarations */
 static void giw_vslider_class_init               (GiwVSliderClass    *klass);
 static void giw_vslider_init                     (GiwVSlider         *vslider);
-static void giw_vslider_destroy                  (GtkObject        *object);
 static void giw_vslider_realize                  (GtkWidget        *widget);
 static void giw_vslider_size_request             (GtkWidget      *widget,
 					       GtkRequisition *requisition);
-static void giw_vslider_size_allocate            (GtkWidget     *widget,
-					       GtkAllocation *allocation);
+#if GTK_CHECK_VERSION(3,0,0)
+static void giw_vslider_get_preferred_width (GtkWidget *widget,
+					     gint      *minimal_width,
+					     gint      *natural_width);
+static void giw_vslider_get_preferred_height (GtkWidget *widget,
+					      gint      *minimal_height,
+					      gint      *natural_height);
+static void giw_vslider_dispose                  (GObject        *object);
+static gboolean giw_vslider_draw                (GtkWidget *widget, cairo_t *cairo);
+static void giw_vslider_style_updated             (GtkWidget *widget);
+#else
+static void giw_vslider_destroy                  (GtkObject        *object);
 static gint giw_vslider_expose                   (GtkWidget        *widget,
 						GdkEventExpose   *event);
-static gint giw_vslider_button_press             (GtkWidget        *widget,
+#endif
+static void giw_vslider_size_allocate            (GtkWidget     *widget,
+					       GtkAllocation *allocation);
+static gboolean giw_vslider_button_press             (GtkWidget        *widget,
 						GdkEventButton   *event);
-static gint giw_vslider_button_release           (GtkWidget        *widget,
+static gboolean giw_vslider_button_release           (GtkWidget        *widget,
 						GdkEventButton   *event);
-static gint giw_vslider_motion_notify            (GtkWidget        *widget,
-						GdkEventMotion   *event);
+static gboolean giw_vslider_motion_notify            (GtkWidget        *widget,
+						      GdkEventMotion   *event);
 static void giw_vslider_adjustment_changed       (GtkAdjustment    *adjustment,
 						gpointer          data);
 static void giw_vslider_adjustment_value_changed (GtkAdjustment    *adjustment,
 						gpointer          data);
 static void giw_vslider_style_set	              (GtkWidget      *widget,
-			                        GtkStyle       *previous_style);
+						       GtkStyle       *previous_style);
 
 /* Local data and functions */
 
-static GtkWidgetClass *parent_class = NULL;
-
 // A function that calculates distances and sizes for a later drawing..
 void vslider_calculate_sizes(GiwVSlider *vslider); 
 
@@ -82,6 +92,14 @@ void vslider_free_legends(GiwVSlider *vslider);
 // A function that calculates width and height of the legend's the layout
 void vslider_calculate_legends_sizes(GiwVSlider *vslider); 
 
+
+#if GTK_CHECK_VERSION(3,0,0)
+G_DEFINE_TYPE (GiwVSlider, giw_vslider, GTK_TYPE_WIDGET)
+#define parent_class giw_vslider_parent_class
+#else
+static GtkWidgetClass *parent_class = NULL;
+
+
 GType
 giw_vslider_get_type ()
 {
@@ -89,64 +107,56 @@ giw_vslider_get_type ()
 
   if (!vslider_type)
     {
-#if GTK_VERSION_3
-      static const GTypeInfo vslider_info =
-      {
-	sizeof (GiwVSliderClass),
-	(GBaseInitFunc)NULL,
-	(GBaseFinalizeFunc)NULL,
-	(GClassInitFunc) giw_vslider_class_init,
-	(GClassFinalizeFunc)NULL,
-	(gconstpointer)NULL,
-	sizeof (GiwVSlider),
-	0, // n_preallocs
-	(GInstanceInitFunc) giw_vslider_init
-	//(const GTypeValueTable *)NULL
-      };
-
-      vslider_type = g_type_register_static (gtk_widget_get_type (), "GiwVSlider", &vslider_info, 0);
-
-#else
       static const GtkTypeInfo vslider_info =
-      {
-	"GiwVSlider",
-	sizeof (GiwVSlider),
-	sizeof (GiwVSliderClass),
-	(GtkClassInitFunc) giw_vslider_class_init,
-	(GtkObjectInitFunc) giw_vslider_init,
-	/*(GtkArgSetFunc)*/ NULL,
-	/*(GtkArgGetFunc)*/ NULL,
-	(GtkClassInitFunc) NULL,
-      };
-
+	{
+	  "GiwVSlider",
+	  sizeof (GiwVSlider),
+	  sizeof (GiwVSliderClass),
+	  (GtkClassInitFunc) giw_vslider_class_init,
+	  (GtkObjectInitFunc) giw_vslider_init,
+	  /*(GtkArgSetFunc)*/ NULL,
+	  /*(GtkArgGetFunc)*/ NULL,
+	  (GtkClassInitFunc) NULL,
+	};
+      
       vslider_type = gtk_type_unique (gtk_widget_get_type (), &vslider_info);
-
-#endif
     }
 
   return vslider_type;
 }
 
+#endif
+
 static void
 giw_vslider_class_init (GiwVSliderClass *xclass)
 {
-  GtkObjectClass *object_class;
+#if GTK_CHECK_VERSION(3,0,0)
+  GObjectClass *object_class = G_OBJECT_CLASS(xclass);
+#else
+  GtkObjectClass *object_class = (GtkObjectClass*) xclass;
+#endif
   GtkWidgetClass *widget_class;
 
-  object_class = (GtkObjectClass*) xclass;
   widget_class = (GtkWidgetClass*) xclass;
 
-#if GTK_VERSION_3
-  // parent_class is set in g_type_register_static()
+#if GTK_CHECK_VERSION(3,0,0)
+  object_class->dispose = giw_vslider_dispose;
 #else
   parent_class = (GtkWidgetClass *)gtk_type_class (gtk_widget_get_type ());
+  object_class->destroy = giw_vslider_destroy;
 #endif
 
-  object_class->destroy = giw_vslider_destroy;
 
   widget_class->realize = giw_vslider_realize;
+#if GTK_CHECK_VERSION(3,0,0)
+  widget_class->get_preferred_width = giw_vslider_get_preferred_width;
+  widget_class->get_preferred_height = giw_vslider_get_preferred_height;
+  widget_class->draw = giw_vslider_draw;
+  widget_class->style_updated = giw_vslider_style_updated;
+#else
   widget_class->expose_event = giw_vslider_expose;
   widget_class->size_request = giw_vslider_size_request;
+#endif
   widget_class->size_allocate = giw_vslider_size_allocate;
   widget_class->button_press_event = giw_vslider_button_press;
   widget_class->button_release_event = giw_vslider_button_release;
@@ -170,6 +180,11 @@ giw_vslider_init (GiwVSlider *vslider)
   // Conditions for a unpressed button
   vslider->button_state=GTK_STATE_NORMAL;
   vslider->button_shadow=GTK_SHADOW_OUT;
+
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_set_has_window(GTK_WIDGET(vslider),TRUE);
+#endif
+
 }
 
 GtkWidget*
@@ -179,8 +194,8 @@ giw_vslider_new (GtkAdjustment *adjustment)
 
   g_return_val_if_fail (adjustment != NULL, NULL);
   
-#if GTK_VERSION_3
-  vslider = g_object_new (GIW_TYPE_VSLIDER, NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+  vslider = (GiwVSlider *)g_object_new (GIW_TYPE_VSLIDER, NULL);
 #else
   vslider = (GiwVSlider *)gtk_type_new (giw_vslider_get_type ());
 #endif
@@ -197,8 +212,8 @@ giw_vslider_new_with_adjustment (gdouble value,
 {
   GiwVSlider *vslider;
   
-#if GTK_VERSION_3
-  vslider = g_object_new (GIW_TYPE_VSLIDER, NULL);
+#if GTK_CHECK_VERSION(3,0,0)
+  vslider = (GiwVSlider *)g_object_new (GIW_TYPE_VSLIDER, NULL);
 #else
   vslider = (GiwVSlider *)gtk_type_new (giw_vslider_get_type ());
 #endif
@@ -208,9 +223,11 @@ giw_vslider_new_with_adjustment (gdouble value,
   return GTK_WIDGET (vslider);
 }
 
-static void
-giw_vslider_destroy (GtkObject *object)
-{
+#if GTK_CHECK_VERSION(3,0,0)
+static void giw_vslider_dispose (GObject *object) {
+#else
+static void giw_vslider_destroy (GtkObject *object) {
+#endif
   GiwVSlider *vslider;
   gint loop;
 
@@ -231,8 +248,12 @@ giw_vslider_destroy (GtkObject *object)
     vslider->legends=NULL;
   }
     
+#if GTK_CHECK_VERSION(3,0,0)
+  G_OBJECT_CLASS (giw_vslider_parent_class)->dispose (object);
+#else
   if (GTK_OBJECT_CLASS (parent_class)->destroy)
     (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+#endif
 }
 
 static void
@@ -241,6 +262,10 @@ giw_vslider_realize (GtkWidget *widget)
   GiwVSlider *vslider;
   GdkWindowAttr attributes;
   gint attributes_mask;
+
+#if GTK_CHECK_VERSION(3,0,0)
+  GtkStyleContext *stylecon;
+#endif
  
   g_return_if_fail (widget != NULL);
   g_return_if_fail (GIW_IS_VSLIDER (widget));
@@ -253,33 +278,51 @@ giw_vslider_realize (GtkWidget *widget)
 
   vslider = GIW_VSLIDER (widget);
 
-  // Creating the widget->window
-  attributes.x = widget->allocation.x;
-  attributes.y = widget->allocation.y;
-  attributes.width = widget->allocation.width;
-  attributes.height = widget->allocation.height;
+
+  attributes.x = lives_widget_get_allocation_x(widget);
+  attributes.y = lives_widget_get_allocation_y(widget);
+  attributes.width = lives_widget_get_allocation_width(widget);
+  attributes.height = lives_widget_get_allocation_height(widget);
   attributes.wclass = GDK_INPUT_OUTPUT;
   attributes.window_type = GDK_WINDOW_CHILD;
   attributes.event_mask = gtk_widget_get_events (widget) | 
-      GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK | 
-      GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK;
+    GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK | 
+    GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK;
+
+
+  attributes_mask = GDK_WA_X | GDK_WA_Y;
+
+#if !GTK_CHECK_VERSION(3,0,0)
+  attributes_mask |= GDK_WA_COLORMAP | GDK_WA_VISUAL;
   attributes.visual = gtk_widget_get_visual (widget);
   attributes.colormap = gtk_widget_get_colormap (widget);
+#endif
 
-  attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_set_window(widget,gdk_window_new (lives_widget_get_xwindow(lives_widget_get_parent(widget)), &attributes, attributes_mask));
+#else
   widget->window = gdk_window_new (widget->parent->window, &attributes, attributes_mask);
+#endif
 
-  // Creating the widget->style
-  widget->style = gtk_style_attach (widget->style, widget->window);
+#if GTK_CHECK_VERSION(3,0,0)
+  stylecon=gtk_style_context_new();
+  gtk_style_context_set_path(stylecon,gtk_widget_get_path(widget));
+  gtk_style_context_set_state(stylecon,GTK_STATE_FLAG_ACTIVE);
+  gtk_style_context_set_background(stylecon,lives_widget_get_xwindow(lives_widget_get_parent(widget)));
+#else
+  widget->style = gtk_style_attach (widget->style, lives_widget_get_xwindow(widget));
+  gtk_style_set_background (widget->style, lives_widget_get_xwindow(widget), GTK_STATE_ACTIVE);
+#endif
 
-  gdk_window_set_user_data (widget->window, widget);
+  gdk_window_set_user_data (lives_widget_get_xwindow(widget), widget);
 
-  gtk_style_set_background (widget->style, widget->window, GTK_STATE_ACTIVE);
   
   // Creating the legends
   vslider_build_legends(vslider);
 }
 
+
+
 static void 
 giw_vslider_size_request (GtkWidget      *widget,
 		       GtkRequisition *requisition)
@@ -288,6 +331,35 @@ giw_vslider_size_request (GtkWidget      *widget,
   requisition->height = VSLIDER_DEFAULT_HEIGHT;
 }
 
+#if GTK_CHECK_VERSION(3,0,0)
+
+static void
+giw_vslider_get_preferred_width (GtkWidget *widget,
+    gint      *minimal_width,
+    gint      *natural_width)
+{
+  GtkRequisition requisition;
+
+  giw_vslider_size_request (widget, &requisition);
+
+  *minimal_width = *natural_width = requisition.width;
+}
+
+static void
+giw_vslider_get_preferred_height (GtkWidget *widget,
+    gint      *minimal_height,
+    gint      *natural_height)
+{
+  GtkRequisition requisition;
+
+  giw_vslider_size_request (widget, &requisition);
+
+  *minimal_height = *natural_height = requisition.height;
+}
+
+#endif
+
+
 static void
 giw_vslider_size_allocate (GtkWidget     *widget,
 			GtkAllocation *allocation)
@@ -298,13 +370,17 @@ giw_vslider_size_allocate (GtkWidget     *widget,
   g_return_if_fail (GIW_IS_VSLIDER (widget));
   g_return_if_fail (allocation != NULL);
 
+#if GTK_CHECK_VERSION(2,18,0)
+  gtk_widget_set_allocation(widget,allocation);
+#else
   widget->allocation = *allocation;
+#endif
+
   vslider = GIW_VSLIDER (widget);
 
-  if (GTK_WIDGET_REALIZED (widget))
+  if (lives_widget_is_realized (widget))
     {
-
-      gdk_window_move_resize (widget->window,
+      gdk_window_move_resize (lives_widget_get_xwindow(widget),
 			      allocation->x, allocation->y,
 			      allocation->width, allocation->height);
 
@@ -314,26 +390,135 @@ giw_vslider_size_allocate (GtkWidget     *widget,
   vslider_calculate_sizes(vslider);
 }
 
+#if GTK_CHECK_VERSION(3,0,0)
+ static gboolean giw_vslider_draw (GtkWidget *widget, cairo_t *cairo) {
+   GdkRGBA color;
+#else
 static gint
 giw_vslider_expose (GtkWidget      *widget,
 		 GdkEventExpose *event)
 {
+#endif
+
   GiwVSlider *vslider;
   gint loop, loop2;
   GdkRectangle rect;
-      
-  g_return_val_if_fail (widget != NULL, FALSE);
-  g_return_val_if_fail (GIW_IS_VSLIDER (widget), FALSE);
+
+#if !GTK_CHECK_VERSION(3,0,0)
+
   g_return_val_if_fail (event != NULL, FALSE);
 
   if (event->count > 0)
     return FALSE;
+#endif
+      
+  g_return_val_if_fail (widget != NULL, FALSE);
+  g_return_val_if_fail (GIW_IS_VSLIDER (widget), FALSE);
   
   vslider = GIW_VSLIDER (widget);
 
-  rect.x=0;rect.y=0;rect.width=widget->allocation.width;rect.height=widget->allocation.height;
+  rect.x=0;rect.y=0;
+  rect.width=lives_widget_get_allocation_width(widget);
+  rect.height=lives_widget_get_allocation_height(widget);
+
+
+#if GTK_CHECK_VERSION(3,0,0)
+  gtk_render_background(gtk_widget_get_style_context(widget),
+			cairo,
+			0,
+			0,
+			rect.width,
+			rect.height);
   
-  // Drawing backgorund
+  cairo_set_line_width(cairo,1.);
+
+  // Drawing all the ticks and legends
+  for (loop=0; loop<vslider->major_ticks; loop++){
+    // Legends
+    if (vslider->legend_digits!=0)
+      gtk_render_layout (gtk_widget_get_style_context(widget),
+			 cairo,
+			 0,
+			 vslider->y+(gint)(vslider->major_dy*(gdouble)loop)-(vslider->legend_height/2),
+			 vslider->legends[loop]);
+
+    gtk_style_context_get_color (gtk_widget_get_style_context (widget), gtk_widget_get_state_flags(widget), &color);
+    cairo_set_source_rgba (cairo, color.red, color.green, color.blue, color.alpha);
+
+    // Major ticks
+    cairo_move_to(cairo,
+		  vslider->legend_width-5, 
+		  vslider->y+(gint)(vslider->major_dy*(gdouble)loop));
+
+
+    cairo_line_to(cairo,
+		  vslider->legend_width,
+		  vslider->y+(gint)(vslider->major_dy*(gdouble)loop));
+
+    cairo_stroke(cairo);
+
+    // Minor ticks
+    for (loop2=1; loop2<vslider->minor_ticks+1; loop2++)
+      if (loop!=vslider->major_ticks-1) { // If it's not the last one
+        cairo_move_to(cairo,
+		      vslider->legend_width-3, 
+		      vslider->y+(gint)(vslider->major_dy*(gdouble)loop)+vslider->minor_dy*(gdouble)loop2);
+    
+	cairo_line_to(cairo,
+		      vslider->legend_width,
+		      vslider->y+(gint)(vslider->major_dy*(gdouble)loop)+vslider->minor_dy*(gdouble)loop2);
+
+	cairo_stroke(cairo);
+      }
+  }
+
+  //Drawing the back hole
+  cairo_set_source_rgba (cairo, 0.,0.,0.,1.);
+  cairo_rectangle (cairo,
+		   vslider->x+vslider->width/2-2,
+		   vslider->y,
+		   4,
+		   vslider->height);
+
+  cairo_fill(cairo);
+
+  gtk_style_context_get_background_color (gtk_widget_get_style_context (widget), gtk_widget_get_state_flags(widget), &color);
+  cairo_set_source_rgba (cairo, color.red, color.green, color.blue, color.alpha);
+
+  cairo_rectangle (cairo,
+		   vslider->x+vslider->width/2-2,
+		   vslider->y,
+		   4,
+		   vslider->height);
+
+  cairo_stroke(cairo);
+
+  gtk_style_context_get_color (gtk_widget_get_style_context (widget), gtk_widget_get_state_flags(widget), &color);
+  cairo_set_source_rgba (cairo, color.red, color.green, color.blue, color.alpha);
+
+  cairo_rectangle (cairo,
+		   vslider->button_x,
+		   vslider->button_y,
+		   vslider->button_w,
+		   vslider->button_h);
+
+  cairo_fill(cairo);
+
+
+  // The phanton button
+  if ((vslider->mouse_policy == GIW_VSLIDER_MOUSE_DELAYED) && (vslider->button !=0 ))
+    gtk_render_slider (gtk_widget_get_style_context(widget),
+		       cairo,
+		       vslider->pbutton_x,
+		       vslider->pbutton_y,
+		       vslider->pbutton_w,
+		       vslider->pbutton_h,
+		       GTK_ORIENTATION_VERTICAL);
+
+#else
+
+
+  // Drawing background
   gtk_paint_flat_box (widget->style,
 			widget->window,
 			GTK_STATE_NORMAL,
@@ -430,13 +615,15 @@ giw_vslider_expose (GtkWidget      *widget,
 			vslider->pbutton_w,
 			vslider->pbutton_h,
 			GTK_ORIENTATION_VERTICAL);
+#endif
  
   return(0);
 }
 
-static gint 
+
+static gboolean
 giw_vslider_button_press (GtkWidget        *widget,
-			GdkEventButton   *event)
+			  GdkEventButton   *event)
 {
   GiwVSlider *vslider;
  
@@ -449,7 +636,8 @@ giw_vslider_button_press (GtkWidget        *widget,
   if (vslider->mouse_policy==GIW_VSLIDER_MOUSE_DISABLED) return(FALSE);
   
   // Checking if the pointer is inside the button
-  if (event->x > vslider->button_x && event->x < vslider->button_x+ vslider->button_w && event->y > vslider->button_y && event->y < vslider->button_y+vslider->button_h){
+  if (event->x > vslider->button_x && event->x < vslider->button_x+ vslider->button_w && event->y > 
+      vslider->button_y && event->y < vslider->button_y+vslider->button_h){
     if (vslider->button==0){
       vslider->button=event->button;
       vslider->button_state=GTK_STATE_ACTIVE;
@@ -462,9 +650,9 @@ giw_vslider_button_press (GtkWidget        *widget,
   return(TRUE);
 }
 
-static gint 
+static gboolean 
 giw_vslider_button_release (GtkWidget        *widget,
-			GdkEventButton   *event)
+			    GdkEventButton   *event)
 {
   GiwVSlider *vslider;
   
@@ -488,7 +676,8 @@ giw_vslider_button_release (GtkWidget        *widget,
     vslider->button=FALSE;
     
     // If the mouse stills inside the button, state is prelight, else state is normal
-    if (event->x > vslider->button_x && event->x < vslider->button_x+ vslider->button_w && event->y >     vslider->button_y && event->y < vslider->button_y+vslider->button_h)
+    if (event->x > vslider->button_x && event->x < vslider->button_x+ vslider->button_w && event->y > 
+	vslider->button_y && event->y < vslider->button_y+vslider->button_h)
       vslider->button_state=GTK_STATE_PRELIGHT;
     else
       vslider->button_state=GTK_STATE_NORMAL;
@@ -501,9 +690,9 @@ giw_vslider_button_release (GtkWidget        *widget,
   return(TRUE);
 }
 
-static gint 
+static gboolean 
 giw_vslider_motion_notify (GtkWidget        *widget,
-			GdkEventMotion   *event)
+			   GdkEventMotion   *event)
 {
   GiwVSlider *vslider;
   gint y;
@@ -523,20 +712,23 @@ giw_vslider_motion_notify (GtkWidget        *widget,
   
   // If the mouse policy is to update automatically, change the value now if it's valid
   if (vslider->button!=0 && vslider->mouse_policy==GIW_VSLIDER_MOUSE_AUTOMATICALLY){
-    new_value=vslider->adjustment->lower+((gdouble)(vslider->height-y))/((gdouble)vslider->height)*(vslider->adjustment->upper-vslider->adjustment->lower);
+    new_value=lives_adjustment_get_lower(vslider->adjustment)+((gdouble)(vslider->height-y))/
+      ((gdouble)vslider->height)*(lives_adjustment_get_upper(vslider->adjustment)-lives_adjustment_get_lower(vslider->adjustment));
+
     // If it's a valid value, update it!
-    if ( (new_value <= vslider->adjustment->upper) && 
-         (new_value >= vslider->adjustment->lower) )
+    if ( (new_value <= lives_adjustment_get_upper(vslider->adjustment)) && 
+         (new_value >= lives_adjustment_get_lower(vslider->adjustment)) )
       giw_vslider_set_value(vslider, new_value);
   }
   
   // If the mouse policy is to update delayed, calculate the false value
   if (vslider->button!=0 && vslider->mouse_policy==GIW_VSLIDER_MOUSE_DELAYED){
-    new_value=vslider->adjustment->lower+((gdouble)(vslider->height-y))/((gdouble)vslider->height)*(vslider->adjustment->upper-vslider->adjustment->lower);
+    new_value=lives_adjustment_get_lower(vslider->adjustment)+((gdouble)(vslider->height-y))/
+      ((gdouble)vslider->height)*(lives_adjustment_get_upper(vslider->adjustment)-lives_adjustment_get_lower(vslider->adjustment));
   
     // If it's a valid value, update the false value
-    if ( (new_value <= vslider->adjustment->upper) && 
-         (new_value >= vslider->adjustment->lower) ){
+    if ( (new_value <= lives_adjustment_get_upper(vslider->adjustment)) && 
+         (new_value >= lives_adjustment_get_lower(vslider->adjustment)) ) {
       vslider->phanton_value=new_value;
       vslider_calculate_phanton_button(vslider);
       gtk_widget_queue_draw(GTK_WIDGET(vslider));
@@ -545,7 +737,8 @@ giw_vslider_motion_notify (GtkWidget        *widget,
   
   // If the button is not pressed and the pointer is inside the button, set prelight, if the pointer is out  of the button, set normal
   if (vslider->button==0){
-    if (event->x > vslider->button_x && event->x < vslider->button_x+ vslider->button_w && event->y > vslider->button_y && event->y < vslider->button_y+vslider->button_h)
+    if (event->x > vslider->button_x && event->x < vslider->button_x+ vslider->button_w && event->y > 
+	vslider->button_y && event->y < vslider->button_y+vslider->button_h)
       vslider->button_state=GTK_STATE_PRELIGHT;
     else
       vslider->button_state=GTK_STATE_NORMAL;
@@ -571,6 +764,15 @@ giw_vslider_style_set (GtkWidget *widget,
   vslider_calculate_legends_sizes(vslider);
 }
 
+#if GTK_CHECK_VERSION(3,0,0)
+static void
+giw_vslider_style_updated (GtkWidget *widget)
+{
+
+}
+
+#endif
+
 void
 giw_vslider_set_value (GiwVSlider *vslider,
 			gdouble value)
@@ -578,8 +780,8 @@ giw_vslider_set_value (GiwVSlider *vslider,
   g_return_if_fail (vslider != NULL); 
   g_return_if_fail (GIW_IS_VSLIDER (vslider));
   
-  if (vslider->adjustment->value!=value){
-    vslider->adjustment->value=value;
+  if (gtk_adjustment_get_value(vslider->adjustment)!=value){
+    gtk_adjustment_set_value(vslider->adjustment,value);
     
     gtk_adjustment_value_changed(vslider->adjustment);
   }
@@ -592,7 +794,7 @@ giw_vslider_get_value (GiwVSlider *vslider)
    g_return_val_if_fail (GIW_IS_VSLIDER (vslider), 0.0);
    g_return_val_if_fail (vslider->adjustment != NULL, 0.0);
  
-   return(vslider->adjustment->value);
+   return (gtk_adjustment_get_value(vslider->adjustment));
 }
 
 GtkAdjustment*
@@ -614,7 +816,12 @@ giw_vslider_set_adjustment (GiwVSlider *vslider,
 
   // Freeing the last one
   if (vslider->adjustment){
+#if GTK_CHECK_VERSION(3,0,0)
+    g_signal_handler_disconnect((gpointer)(vslider->adjustment),vslider->chsig);
+    g_signal_handler_disconnect((gpointer)(vslider->adjustment),vslider->vchsig);
+#else
     gtk_signal_disconnect_by_data (GTK_OBJECT (vslider->adjustment), (gpointer) vslider);
+#endif
     g_object_unref (G_OBJECT (vslider->adjustment));
     vslider->adjustment=NULL;
   }
@@ -622,12 +829,12 @@ giw_vslider_set_adjustment (GiwVSlider *vslider,
   vslider->adjustment = adjustment;
   g_object_ref (GTK_OBJECT (vslider->adjustment));
   
-  g_signal_connect (GTK_OBJECT (adjustment), "changed",
-		      (GCallback) giw_vslider_adjustment_changed,
-		      (gpointer) vslider);
-  g_signal_connect (GTK_OBJECT (adjustment), "value_changed",
-		      (GCallback) giw_vslider_adjustment_value_changed,
-		      (gpointer) vslider);
+  vslider->chsig = g_signal_connect (GTK_OBJECT (adjustment), "changed",
+				     (GCallback) giw_vslider_adjustment_changed,
+				     (gpointer) vslider);
+  vslider->vchsig = g_signal_connect (GTK_OBJECT (adjustment), "value_changed",
+				      (GCallback) giw_vslider_adjustment_value_changed,
+				      (gpointer) vslider);
 
   gtk_adjustment_value_changed(vslider->adjustment);
     
@@ -743,14 +950,14 @@ vslider_calculate_sizes(GiwVSlider *vslider)
   widget=GTK_WIDGET(vslider);
           
   // Calculating the sizes and distances...
-  vslider->width=widget->allocation.width-vslider->legend_width;
-  vslider->height=widget->allocation.height-vslider->legend_height;
+  vslider->width=lives_widget_get_allocation_width(widget)-vslider->legend_width;
+  vslider->height=lives_widget_get_allocation_height(widget)-vslider->legend_height;
   vslider->x=vslider->legend_width;
   vslider->y=vslider->legend_height/2;
 
   // If the legends are too small, or inexistant, it has to be some space left fot the button (when it's on he edge)
   if (vslider->y < vslider->button_h/2){
-    vslider->height = widget->allocation.height-vslider->button_h;
+    vslider->height = lives_widget_get_allocation_height(widget)-vslider->button_h;
     vslider->y = vslider->button_h/2;
   }
 
@@ -771,7 +978,9 @@ vslider_calculate_button (GiwVSlider *vslider)
 
   // Getting button's positon and dimensions
   vslider->button_x=vslider->x+5;
-  vslider->button_y=vslider->y+vslider->height-vslider->height*((vslider->adjustment->value-vslider->adjustment->lower)/(vslider->adjustment->upper-vslider->adjustment->lower))-5;
+  vslider->button_y=vslider->y+vslider->height-vslider->height*
+    ((gtk_adjustment_get_value(vslider->adjustment)-lives_adjustment_get_lower(vslider->adjustment))/
+     (lives_adjustment_get_upper(vslider->adjustment)-lives_adjustment_get_lower(vslider->adjustment)))-5;
   vslider->button_w=vslider->width-10;
   vslider->button_h=10;
 } 
@@ -783,7 +992,9 @@ vslider_calculate_phanton_button(GiwVSlider *vslider)
 
   // Getting phanton button's positon and dimensions
   vslider->pbutton_x=vslider->x+5;
-  vslider->pbutton_y=vslider->y+vslider->height-vslider->height*((vslider->phanton_value-vslider->adjustment->lower)/(vslider->adjustment->upper-vslider->adjustment->lower))-5;
+  vslider->pbutton_y=vslider->y+vslider->height-vslider->height*
+    ((vslider->phanton_value-lives_adjustment_get_lower(vslider->adjustment))/
+     (lives_adjustment_get_upper(vslider->adjustment)-lives_adjustment_get_lower(vslider->adjustment)))-5;
   vslider->pbutton_w=vslider->width-10;
   vslider->pbutton_h=10;
 }
@@ -807,9 +1018,19 @@ vslider_build_legends(GiwVSlider *vslider)
     vslider->legends=g_new(PangoLayout*, vslider->major_ticks);
     str=g_new(gchar, vslider->legend_digits+1); // +1 for the '/0'
     for (loop=0; loop<vslider->major_ticks; loop++){
-      snprintf(str,vslider->legend_digits+1,"%f",vslider->adjustment->lower+(vslider->major_ticks-1-loop)*(vslider->adjustment->upper-vslider->adjustment->lower)/(vslider->major_ticks-1)); // Creating the legends string
+      snprintf(str,vslider->legend_digits+1,"%f",lives_adjustment_get_lower(vslider->adjustment)+
+	       (vslider->major_ticks-1-loop)*
+	       (lives_adjustment_get_upper(vslider->adjustment)-lives_adjustment_get_lower(vslider->adjustment))/
+	       (vslider->major_ticks-1)); // Creating the legends string
       vslider->legends[loop]=gtk_widget_create_pango_layout (widget, str); 
+
+#if GTK_CHECK_VERSION(3,0,0)
+      pango_layout_set_font_description (vslider->legends[loop], 
+					 gtk_style_context_get_font(gtk_widget_get_style_context(widget),
+								    gtk_widget_get_state_flags(widget)));
+#else
       pango_layout_set_font_description(vslider->legends[loop], widget->style->font_desc); // Setting te correct font  
+#endif
     }
     g_free(str);
   
@@ -849,7 +1070,13 @@ vslider_calculate_legends_sizes(GiwVSlider *vslider)
   widget=GTK_WIDGET(vslider);
 
   if (vslider->legends!=NULL){
+#if GTK_CHECK_VERSION(3,0,0)
+    pango_layout_set_font_description (vslider->legends[0], 
+				       gtk_style_context_get_font(gtk_widget_get_style_context(widget),
+								  gtk_widget_get_state_flags(widget)));
+#else
     pango_layout_set_font_description (vslider->legends[0], widget->style->font_desc);  
+#endif
     pango_layout_get_size(vslider->legends[0], &(vslider->legend_width), &(vslider->legend_height));
     vslider->legend_width/=PANGO_SCALE;
     vslider->legend_height/=PANGO_SCALE;
