@@ -10,7 +10,7 @@
 #include "ldvinterface.h"
 
 
-struct _dvgrabw *create_camwindow (s_cam *cam, gint type)
+struct _dvgrabw *create_camwindow (s_cam *cam, int type)
 {
   GtkWidget *hbuttonbox1;
   GtkWidget *hbuttonbox2;
@@ -35,8 +35,8 @@ struct _dvgrabw *create_camwindow (s_cam *cam, gint type)
   lives_container_set_border_width (LIVES_CONTAINER (dvgrabw->dialog), widget_opts.border_width*2);
 
   if (prefs->show_gui) {
-    if (mainw->multitrack==NULL) gtk_window_set_transient_for(GTK_WINDOW(dvgrabw->dialog),GTK_WINDOW(mainw->LiVES));
-    else gtk_window_set_transient_for(GTK_WINDOW(dvgrabw->dialog),GTK_WINDOW(mainw->multitrack->window));
+    if (mainw->multitrack==NULL) lives_window_set_transient_for(LIVES_WINDOW(dvgrabw->dialog),GTK_WINDOW(mainw->LiVES));
+    else lives_window_set_transient_for(LIVES_WINDOW(dvgrabw->dialog),GTK_WINDOW(mainw->multitrack->window));
   }
 
   vbox=lives_dialog_get_content_area(LIVES_DIALOG(dvgrabw->dialog));
@@ -85,7 +85,7 @@ struct _dvgrabw *create_camwindow (s_cam *cam, gint type)
   dvgrabw->status_entry=gtk_entry_new();
 
   lives_box_pack_start(LIVES_BOX(vbox),dvgrabw->status_entry,FALSE,FALSE,widget_opts.packing_height);
-  lives_entry_set_text(GTK_ENTRY(dvgrabw->status_entry),_("Status: Ready"));
+  lives_entry_set_text(LIVES_ENTRY(dvgrabw->status_entry),_("Status: Ready"));
   gtk_editable_set_editable (GTK_EDITABLE(dvgrabw->status_entry),FALSE);
 
   add_hsep_to_box(LIVES_BOX(vbox));
@@ -95,44 +95,44 @@ struct _dvgrabw *create_camwindow (s_cam *cam, gint type)
   lives_box_pack_start(LIVES_BOX(vbox),hbuttonbox1,FALSE,FALSE,widget_opts.packing_height);
 
 #if GTK_CHECK_VERSION(2,6,0)
-  button3 = gtk_button_new_from_stock (GTK_STOCK_MEDIA_REWIND);
+  button3 = lives_button_new_from_stock (GTK_STOCK_MEDIA_REWIND);
 #else
-  button3 = gtk_button_new_from_stock (GTK_STOCK_GO_BACK);
+  button3 = lives_button_new_from_stock (GTK_STOCK_GO_BACK);
 #endif
 
   lives_container_add (LIVES_CONTAINER (hbuttonbox1), button3);
   lives_widget_set_can_focus (button3,TRUE);
 
 #if GTK_CHECK_VERSION(2,6,0)
-  button4 = gtk_button_new_from_stock (GTK_STOCK_MEDIA_FORWARD);
+  button4 = lives_button_new_from_stock (GTK_STOCK_MEDIA_FORWARD);
 #else
-  button4 = gtk_button_new_from_stock (GTK_STOCK_GO_FORWARD);
+  button4 = lives_button_new_from_stock (GTK_STOCK_GO_FORWARD);
 #endif
   lives_container_add (LIVES_CONTAINER (hbuttonbox1), button4);
   lives_widget_set_can_focus (button4,TRUE);
 
 #if GTK_CHECK_VERSION(2,6,0)
-  dvgrabw->stop = gtk_button_new_from_stock (GTK_STOCK_MEDIA_STOP);
+  dvgrabw->stop = lives_button_new_from_stock (GTK_STOCK_MEDIA_STOP);
 #else
-  dvgrabw->stop = gtk_button_new_from_stock (GTK_STOCK_STOP);
+  dvgrabw->stop = lives_button_new_from_stock (GTK_STOCK_STOP);
 #endif
   lives_container_add (LIVES_CONTAINER (hbuttonbox1), dvgrabw->stop);
   lives_widget_set_can_focus_and_default (dvgrabw->stop);
   lives_widget_set_sensitive(dvgrabw->stop,FALSE);
 
 #if GTK_CHECK_VERSION(2,6,0)
-  dvgrabw->play = gtk_button_new_from_stock (GTK_STOCK_MEDIA_PLAY);
+  dvgrabw->play = lives_button_new_from_stock (GTK_STOCK_MEDIA_PLAY);
 #else
-  dvgrabw->play = gtk_button_new_from_stock (GTK_STOCK_GO_FORWARD);
+  dvgrabw->play = lives_button_new_from_stock (GTK_STOCK_GO_FORWARD);
 #endif
   lives_container_add (LIVES_CONTAINER (hbuttonbox1), dvgrabw->play);
   lives_widget_set_can_focus_and_default (dvgrabw->play);
   gtk_button_set_use_stock(GTK_BUTTON(dvgrabw->play),TRUE);
 
 #if GTK_CHECK_VERSION(2,6,0)
-  dvgrabw->grab = gtk_button_new_from_stock (GTK_STOCK_MEDIA_RECORD);
+  dvgrabw->grab = lives_button_new_from_stock (GTK_STOCK_MEDIA_RECORD);
 #else
-  dvgrabw->grab = gtk_button_new_from_stock (GTK_STOCK_NO);
+  dvgrabw->grab = lives_button_new_from_stock (GTK_STOCK_NO);
 #endif
   lives_container_add (LIVES_CONTAINER (hbuttonbox1), dvgrabw->grab);
   lives_widget_set_can_focus_and_default (dvgrabw->grab);
@@ -152,7 +152,7 @@ struct _dvgrabw *create_camwindow (s_cam *cam, gint type)
   hbuttonbox2 = lives_hbutton_box_new ();
   lives_box_pack_start(LIVES_BOX(vbox),hbuttonbox2,FALSE,FALSE,widget_opts.packing_height);
 
-  dvgrabw->quit = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
+  dvgrabw->quit = lives_button_new_from_stock (GTK_STOCK_CLOSE);
   lives_container_add (LIVES_CONTAINER (hbuttonbox2), dvgrabw->quit);
   lives_widget_set_can_focus_and_default (dvgrabw->quit);
 
