@@ -23,6 +23,17 @@
 #include <sys/stat.h>
 #include <errno.h>
 
+
+typedef struct y4data {
+  const gchar *filename;
+  lives_yuv4m_t *yuv4mpeg;
+
+  int fd;
+  int i;
+
+} y4data;
+
+
 static int yuvout,hsize_out,vsize_out;
 
 
@@ -46,16 +57,18 @@ static lives_yuv4m_t *lives_yuv4mpeg_alloc (void) {
 
 
 static void *y4open_thread (void *arg) {
-  char *filename=(char *)arg;
-  int fd=open (filename,O_RDONLY);
-  pthread_exit(GINT_TO_POINTER(fd));
+  y4data *thread_data=(y4data *)arg;
+  int fd=open(thread_data->filename,O_RDONLY);
+  thread_data->fd=fd;
+  pthread_exit(NULL);
 }
 
 
 static void *y4header_thread (void *arg) {
-  lives_yuv4m_t *yuv4mpeg=(lives_yuv4m_t *)arg;
-  int i = y4m_read_stream_header (yuv4mpeg->fd, &(yuv4mpeg->streaminfo));
-  pthread_exit(GINT_TO_POINTER(i));
+  y4data *thread_data=(y4data *)arg;
+  lives_yuv4m_t *yuv4mpeg=thread_data->yuv4mpeg;
+  thread_data->i = y4m_read_stream_header (yuv4mpeg->fd, &(yuv4mpeg->streaminfo));
+  pthread_exit(NULL);
 }
 
 
@@ -73,16 +86,18 @@ static void fill_read(int fd, char *buf, size_t count) {
 
 
 static void *y4frame_thread (void *arg) {
-  lives_yuv4m_t *yuv4mpeg=(lives_yuv4m_t *)arg;
+  y4data *thread_data=(y4data *)arg;
+  lives_yuv4m_t *yuv4mpeg=thread_data->yuv4mpeg;
   char buff[5],bchar;
-  int i=Y4M_OK;
+
+  thread_data->i=Y4M_OK;
 
   // read 5 bytes FRAME
   fill_read(yuv4mpeg->fd,buff,5);
 
   if (strncmp(buff,"FRAME",5)) {
-    i=Y4M_ERR_MAGIC;
-    pthread_exit(GINT_TO_POINTER(i));
+    thread_data->i=Y4M_ERR_MAGIC;
+    pthread_exit(NULL);
   }
 
   do {
@@ -94,58 +109,66 @@ static void *y4frame_thread (void *arg) {
   fill_read(yuv4mpeg->fd,(char *)yuv4mpeg->pixel_data[1],yuv4mpeg->hsize*yuv4mpeg->vsize/4);
   fill_read(yuv4mpeg->fd,(char *)yuv4mpeg->pixel_data[2],yuv4mpeg->hsize*yuv4mpeg->vsize/4);
 
-  pthread_exit(GINT_TO_POINTER(i));
+  pthread_exit(NULL);
 }
 
 
 
-#define YUV4_O_TIME 2000000 // micro-seconds to wait to open fifo
-#define YUV4_H_TIME 5000000 // micro-seconds to wait to get stream header
+#define YUV4_O_TIME 200000000 // ticks to wait to open fifo
+#define YUV4_H_TIME 500000000 // ticks to wait to get stream header
 
 
-static gboolean lives_yuv_stream_start_read (file *sfile) {
-  int i;
-
-  int ohsize=sfile->hsize;
-  int ovsize=sfile->vsize;
-  gdouble ofps=sfile->fps;
+static boolean lives_yuv_stream_start_read (file *sfile) {
+  double ofps=sfile->fps;
 
   lives_yuv4m_t *yuv4mpeg=(lives_yuv4m_t *)sfile->ext_src;
 
+  pthread_t y4thread;
+
   gchar *filename=yuv4mpeg->filename,*tmp;
 
-  pthread_t y4thread;
-  struct timeval otv;
-  int64_t ntime=0,stime;
+  int alarm_handle=0;
+
+  int ohsize=sfile->hsize;
+  int ovsize=sfile->vsize;
+
+  y4data thread_data;
+
+  register int i;
 
-  void *retval;
 
   if (filename==NULL) return FALSE;
 
   if (yuv4mpeg->fd==-1) {
     // create a thread to open the fifo
-    pthread_create(&y4thread,NULL,y4open_thread,(void *)filename);
-    gettimeofday(&otv,NULL);
-    stime=otv.tv_sec*1000000+otv.tv_usec;
-    
 
-    while (ntime<YUV4_O_TIME&&!pthread_kill(y4thread,0)) {
+    thread_data.filename=filename;
+
+    pthread_create(&y4thread,NULL,y4open_thread,(void *)&thread_data);
+
+    alarm_handle=lives_alarm_set(YUV4_O_TIME);
+
+    d_print("");
+    d_print(_("Waiting for yuv4mpeg frames..."));
+
+    while (!lives_alarm_get(alarm_handle)&&!pthread_kill(y4thread,0)) {
       // wait for thread to complete or timeout
       g_usleep(prefs->sleep_time);
       lives_widget_context_update();
-      
-      gettimeofday(&otv, NULL);
-      ntime=(otv.tv_sec*1000000+otv.tv_usec-stime);
     }
     
-    if (ntime>=YUV4_O_TIME) {
+    if (lives_alarm_get(alarm_handle)) {
       // timeout - kill thread and wait for it to terminate
       pthread_cancel(y4thread);
-      pthread_join(y4thread,&retval);
+      pthread_join(y4thread,NULL);
+      lives_alarm_clear(alarm_handle);
+
+      d_print_failed();
       d_print(_("Unable to open the incoming video stream\n"));
 
-      yuv4mpeg->fd=GPOINTER_TO_INT(retval);
-      if (yuv4mpeg->fd!=-1) {
+      yuv4mpeg->fd=thread_data.fd;
+
+      if (yuv4mpeg->fd>=0) {
 	close(yuv4mpeg->fd);
 	yuv4mpeg->fd=-1;
       }
@@ -153,41 +176,40 @@ static gboolean lives_yuv_stream_start_read (file *sfile) {
       return FALSE;
     }
 
-    pthread_join(y4thread,&retval);
+    pthread_join(y4thread,NULL);
+    lives_alarm_clear(alarm_handle);
 
-    yuv4mpeg->fd=GPOINTER_TO_INT(retval);
+    yuv4mpeg->fd=thread_data.fd;
 
-    if (yuv4mpeg->fd==-1) {
+    if (yuv4mpeg->fd<0) {
       return FALSE;
     }
   }
 
   // create a thread to open the stream header
-  pthread_create(&y4thread,NULL,y4header_thread,yuv4mpeg);
-  gettimeofday(&otv,NULL);
-  stime=otv.tv_sec*1000000+otv.tv_usec;
+  thread_data.yuv4mpeg=yuv4mpeg;
+  pthread_create(&y4thread,NULL,y4header_thread,&thread_data);
+  alarm_handle=lives_alarm_set(YUV4_H_TIME);
 
-  while (ntime<YUV4_H_TIME&&!pthread_kill(y4thread,0)) {
+  while (!lives_alarm_get(alarm_handle)&&!pthread_kill(y4thread,0)) {
     // wait for thread to complete or timeout
     g_usleep(prefs->sleep_time);
     lives_widget_context_update();
-
-    gettimeofday(&otv, NULL);
-    ntime=(otv.tv_sec*1000000+otv.tv_usec-stime);
-    
   }
 
-  if (ntime>=YUV4_H_TIME) {
+  if (lives_alarm_get(alarm_handle)) {
     // timeout - kill thread and wait for it to terminate
     pthread_cancel(y4thread);
     pthread_join(y4thread,NULL);
-    d_print(_("Unable to read the incoming video stream\n"));
+    lives_alarm_clear(alarm_handle);
+    d_print(_("Unable to read the stream header\n"));
     return FALSE;
   }
 
-  pthread_join(y4thread,&retval);
+  pthread_join(y4thread,NULL);
+  lives_alarm_clear(alarm_handle);
 
-  i=GPOINTER_TO_INT(retval);
+  i=thread_data.i;
 
   if (i != Y4M_OK) {
     gchar *tmp;
@@ -196,6 +218,8 @@ static gboolean lives_yuv_stream_start_read (file *sfile) {
     return FALSE;
   }
 
+  d_print(_("got header\n"));
+
   sfile->hsize = yuv4mpeg->hsize = y4m_si_get_width (&(yuv4mpeg->streaminfo));
   sfile->vsize = yuv4mpeg->vsize = y4m_si_get_height (&(yuv4mpeg->streaminfo));
 
@@ -244,16 +268,19 @@ void lives_yuv_stream_stop_read (lives_yuv4m_t *yuv4mpeg) {
 
 }
 
-#define YUV4_F_TIME 2000000 // micro-seconds to wait to get stream header
+#define YUV4_F_TIME 200000000 // ticks to wait to get stream header
 
 
 void weed_layer_set_from_yuv4m (weed_plant_t *layer, file *sfile) {
   lives_yuv4m_t *yuv4mpeg=(lives_yuv4m_t *)(sfile->ext_src);
+
+  y4data thread_data;
+
   int error;
 
   pthread_t y4thread;
-  struct timeval otv;
-  int64_t ntime=0,stime;
+
+  int alarm_handle;
 
   if (!yuv4mpeg->ready) lives_yuv_stream_start_read(sfile);
 
@@ -262,7 +289,7 @@ void weed_layer_set_from_yuv4m (weed_plant_t *layer, file *sfile) {
   weed_set_int_value(layer,"current_palette",WEED_PALETTE_YUV420P);
   weed_set_int_value(layer,"YUV_subspace",WEED_YUV_SUBSPACE_YCBCR);
 
-  create_empty_pixel_data(layer,FALSE,TRUE);
+  create_empty_pixel_data(layer,TRUE,TRUE);
 
   if (!yuv4mpeg->ready) {
     return;
@@ -271,24 +298,26 @@ void weed_layer_set_from_yuv4m (weed_plant_t *layer, file *sfile) {
   yuv4mpeg->pixel_data=weed_get_voidptr_array(layer,"pixel_data",&error);
 
   // create a thread to open the stream header
-  pthread_create(&y4thread,NULL,y4frame_thread,yuv4mpeg);
-  gettimeofday(&otv,NULL);
-  stime=otv.tv_sec*1000000+otv.tv_usec;
 
-  while (ntime<YUV4_F_TIME&&!pthread_kill(y4thread,0)) {
+  thread_data.yuv4mpeg=yuv4mpeg;
+  pthread_create(&y4thread,NULL,y4frame_thread,&thread_data);
+
+  alarm_handle=lives_alarm_set(YUV4_F_TIME);
+
+  while (!lives_alarm_get(alarm_handle)&&!pthread_kill(y4thread,0)) {
     // wait for thread to complete or timeout
     g_usleep(prefs->sleep_time);
-    gettimeofday(&otv, NULL);
-    ntime=(otv.tv_sec*1000000+otv.tv_usec-stime);
   }
 
-  if (ntime>=YUV4_F_TIME) {
+  if (lives_alarm_get(alarm_handle)) {
+    // timeout - kill thread and wait for it to terminate
     // timeout - kill thread and wait for it to terminate
     pthread_cancel(y4thread);
     d_print(_("Unable to read the incoming video frame\n"));
   }
 
   pthread_join(y4thread,NULL);
+  lives_alarm_clear(alarm_handle);
 
   weed_free(yuv4mpeg->pixel_data);
   yuv4mpeg->pixel_data=NULL;
@@ -301,9 +330,9 @@ void weed_layer_set_from_yuv4m (weed_plant_t *layer, file *sfile) {
 
 
 
-static gboolean open_yuv4m_inner(const gchar *filename, const gchar *fname, gint new_file, gint type, gint cardno) {
+static boolean open_yuv4m_inner(const gchar *filename, const gchar *fname, int new_file, int type, int cardno) {
   // create a virtual clip
-  gint old_file=mainw->current_file;
+  int old_file=mainw->current_file;
 
   lives_yuv4m_t *yuv4mpeg;
 
@@ -331,7 +360,7 @@ static gboolean open_yuv4m_inner(const gchar *filename, const gchar *fname, gint
 
   cfile->is_loaded=TRUE;
 
-  add_to_winmenu();
+  add_to_clipmenu();
 
   switch_to_file((mainw->current_file=old_file),new_file);
 
@@ -346,7 +375,7 @@ void on_open_yuv4m_activate (GtkMenuItem *menuitem, gpointer user_data) {
   // open a general yuvmpeg stream
   // start "playing" but open frames in yuv4mpeg format on stdin
 
-  gint old_file=mainw->current_file,new_file=mainw->first_free_file;
+  int old_file=mainw->current_file,new_file=mainw->first_free_file;
   gchar *tmp;
   gchar *filename;
   gchar *fname;
@@ -400,7 +429,8 @@ void on_open_yuv4m_activate (GtkMenuItem *menuitem, gpointer user_data) {
     d_print (_ ("none\n"));
   }
   else {
-    d_print ((tmp=g_strdup_printf(P_("%d Hz %d channel %d bps\n","%d Hz %d channels %d bps\n",cfile->achans),cfile->arate,cfile->achans,cfile->asampsize)));
+    d_print ((tmp=g_strdup_printf(P_("%d Hz %d channel %d bps\n","%d Hz %d channels %d bps\n",cfile->achans),
+				  cfile->arate,cfile->achans,cfile->asampsize)));
     g_free(tmp);
   }
 
@@ -457,8 +487,7 @@ void on_open_yuv4m_activate (GtkMenuItem *menuitem, gpointer user_data) {
 // write functions - not used currently
 
 
-gboolean 
-lives_yuv_stream_start_write (lives_yuv4m_t * yuv4mpeg, const gchar *filename, gint hsize, gint vsize, gdouble fps) {
+boolean lives_yuv_stream_start_write (lives_yuv4m_t * yuv4mpeg, const gchar *filename, int hsize, int vsize, double fps) {
   int i;
 
   if (mainw->fixed_fpsd>-1.&&mainw->fixed_fpsd!=fps) {
@@ -493,13 +522,12 @@ lives_yuv_stream_start_write (lives_yuv4m_t * yuv4mpeg, const gchar *filename, g
 }
 
 
-gboolean 
-lives_yuv_stream_write_frame (lives_yuv4m_t *yuv4mpeg, void *pixel_data) {
+boolean lives_yuv_stream_write_frame (lives_yuv4m_t *yuv4mpeg, void *pixel_data) {
   // pixel_data is planar yuv420 data
   int i;
 
   guchar *planes[3];
-  uint8_t *pixels=(guchar *)pixel_data;
+  uint8_t *pixels=(uint8_t *)pixel_data;
 
   planes[0]=&(pixels[0]);
   planes[1]=&(pixels[hsize_out*vsize_out]);
@@ -512,8 +540,7 @@ lives_yuv_stream_write_frame (lives_yuv4m_t *yuv4mpeg, void *pixel_data) {
 }
 
 
-void 
-lives_yuv_stream_stop_write (lives_yuv4m_t *yuv4mpeg) {
+void lives_yuv_stream_stop_write (lives_yuv4m_t *yuv4mpeg) {
   y4m_fini_stream_info(&(yuv4mpeg->streaminfo));
   y4m_fini_frame_info(&(yuv4mpeg->frameinfo));
   close (yuvout);
@@ -552,18 +579,15 @@ lives_yuv_stream_stop_write (lives_yuv4m_t *yuv4mpeg) {
 
 
 
-void
-on_live_tvcard_activate                      (GtkMenuItem     *menuitem,
-					      gpointer         user_data)
-{
-  gint cardno=0;
+void on_live_tvcard_activate (GtkMenuItem *menuitem, gpointer user_data) {
+  int cardno=0;
 
-  gint new_file=mainw->first_free_file;
+  int new_file=mainw->first_free_file;
 
-  gint response;
+  int response;
 
   gchar *com,*tmp;
-  gchar *fifofile=g_strdup_printf("%s/tvpic.%d",prefs->tmpdir,getpid());
+  gchar *fifofile=g_strdup_printf("%s/tvpic.%d",prefs->tmpdir,capable->mainpid);
 
   gchar *chanstr;
   gchar *devstr;
@@ -581,7 +605,7 @@ on_live_tvcard_activate                      (GtkMenuItem     *menuitem,
   tvcardw=(lives_tvcardw_t *)g_object_get_data(G_OBJECT(card_dialog),"tvcard_data");
 
 
-  response=lives_dialog_run(GTK_DIALOG(card_dialog));
+  response=lives_dialog_run(LIVES_DIALOG(card_dialog));
   if (response==GTK_RESPONSE_CANCEL) {
     lives_widget_destroy(card_dialog);
     g_free(fifofile);
@@ -589,8 +613,8 @@ on_live_tvcard_activate                      (GtkMenuItem     *menuitem,
     return;
   }
 
-  cardno=(gint)mainw->fx1_val;
-  chanstr=g_strdup_printf("%d",(gint)mainw->fx2_val);
+  cardno=(int)mainw->fx1_val;
+  chanstr=g_strdup_printf("%d",(int)mainw->fx2_val);
 
   if (g_list_find(mainw->videodevs,GINT_TO_POINTER(cardno))) {
     lives_widget_destroy(card_dialog);
@@ -639,15 +663,15 @@ on_live_tvcard_activate                      (GtkMenuItem     *menuitem,
 			devstr,fifofile);
   }
   else {
-    gdouble fps=0.;
+    double fps=0.;
     gchar *driver=NULL,*outfmt=NULL;
-    gint width=0,height=0;
-    gint input=lives_spin_button_get_value_as_int(GTK_SPIN_BUTTON(tvcardw->spinbuttoni));
+    int width=0,height=0;
+    int input=lives_spin_button_get_value_as_int(LIVES_SPIN_BUTTON(tvcardw->spinbuttoni));
     
     if (!lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(tvcardw->radiobuttond))) {
-      width=lives_spin_button_get_value_as_int(GTK_SPIN_BUTTON(tvcardw->spinbuttonw));
-      height=lives_spin_button_get_value_as_int(GTK_SPIN_BUTTON(tvcardw->spinbuttonh));
-      fps=lives_spin_button_get_value(GTK_SPIN_BUTTON(tvcardw->spinbuttonf));
+      width=lives_spin_button_get_value_as_int(LIVES_SPIN_BUTTON(tvcardw->spinbuttonw));
+      height=lives_spin_button_get_value_as_int(LIVES_SPIN_BUTTON(tvcardw->spinbuttonh));
+      fps=lives_spin_button_get_value(LIVES_SPIN_BUTTON(tvcardw->spinbuttonf));
     }
 
     driver=lives_combo_get_active_text(LIVES_COMBO(tvcardw->combod));
@@ -698,20 +722,17 @@ on_live_tvcard_activate                      (GtkMenuItem     *menuitem,
 
 
 
-void
-on_live_fw_activate                      (GtkMenuItem     *menuitem,
-					  gpointer         user_data)
-{
+void on_live_fw_activate (GtkMenuItem *menuitem, gpointer user_data) {
 
   gchar *com,*tmp;
-  gint cardno;
-  gint cache=1024;
+  int cardno;
+  int cache=1024;
 
-  gint new_file=mainw->first_free_file;
+  int new_file=mainw->first_free_file;
 
-  gint response;
+  int response;
 
-  gchar *fifofile=g_strdup_printf("%s/firew.%d",prefs->tmpdir,getpid());
+  gchar *fifofile=g_strdup_printf("%s/firew.%d",prefs->tmpdir,capable->mainpid);
   gchar *fname;
 
   GtkWidget *card_dialog;
@@ -719,14 +740,14 @@ on_live_fw_activate                      (GtkMenuItem     *menuitem,
   mainw->open_deint=FALSE;
 
   card_dialog=create_cdtrack_dialog(5,NULL);
-  response=lives_dialog_run(GTK_DIALOG(card_dialog));
+  response=lives_dialog_run(LIVES_DIALOG(card_dialog));
   if (response==GTK_RESPONSE_CANCEL) {
     lives_widget_destroy(card_dialog);
     g_free(fifofile);
     return;
   }
 
-  cardno=(gint)mainw->fx1_val;
+  cardno=(int)mainw->fx1_val;
 
   lives_widget_destroy(card_dialog);
 
