@@ -225,14 +225,14 @@ typedef int lives_pgid_t;
 #endif
 #endif
 
-#define DEF_FILE_PERMS S_IRUSR|S_IWUSR
+#define DEF_FILE_PERMS S_IRUSR|S_IWUSR // must be at least S_IRUSR|S_IWUSR
 #define DEF_FILE_UMASK (S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)^( DEF_FILE_PERMS )
 
 /// LiVES will show a warning if this (MBytes) is exceeded on load
 /// (can be overridden in prefs)
 #define WARN_FILE_SIZE 500
 
-/// maximum fps we will allow (gdouble)
+/// maximum fps we will allow (double)
 #define FPS_MAX 200.
 
 #define MAX_FRAME_WIDTH 100000.
@@ -284,8 +284,8 @@ typedef  void *(*fn_ptr) (void *ptr);
 /// this struct is used only when physically resampling frames on the disk
 /// we create an array of these and write them to the disk
 typedef struct {
-  gint value;
-  gint64 reltime;
+  int value;
+  int64_t reltime;
 } event;
 
 typedef struct {
@@ -299,7 +299,7 @@ typedef struct {
   GtkWidget *preview_button;
   GtkWidget *cancel_button;
   GtkWidget *scrolledwindow;
-  guint frames_done;
+  uint32_t frames_done;
 } xprocess;
 
 
@@ -477,20 +477,20 @@ typedef enum {
 /// corresponds to one clip in the GUI
 typedef struct {
   // basic info (saved during backup)
-  gint bpp;
-  gdouble fps;
-  gint hsize; ///< in pixels (NOT macropixels !)
-  gint vsize;
-  gint arps; ///< audio sample rate
-  guint signed_endian; ///< bitfield
+  int bpp;
+  double fps;
+  int hsize; ///< in pixels (NOT macropixels !)
+  int vsize;
+  int arps; ///< audio sample rate
+  uint32_t signed_endian; ///< bitfield
 
-  gint arate; ///< audio playback rate
-  guint64 unique_id;    ///< this and the handle can be used to uniquely id a file
-  gint achans;
-  gint asampsize;
+  int arate; ///< audio playback rate
+  uint64_t unique_id;    ///< this and the handle can be used to uniquely id a file
+  int achans;
+  int asampsize;
 
   /////////////////
-  gint frames;
+  int frames;
   gchar title[256];
   gchar author[256];
   gchar comment[256];
@@ -500,39 +500,40 @@ typedef struct {
   lives_interlace_t interlace; ///< interlace type (if known - none, topfirst, bottomfirst or : see plugins.h)
 
   // extended info (not saved)
-  gint header_version;
+  int header_version;
 
 #define LIVES_CLIP_HEADER_VERSION 100
 
-  gint rowstride;
+  int rowstride;
 
   /// the processing window
   xprocess *proc_ptr;
 
   gchar handle[256];
-  gint ohsize;
-  gint ovsize;
+  int ohsize;
+  int ovsize;
   int64_t f_size;
   int64_t afilesize;
-  gint old_frames; ///< for deordering, etc.
+  int old_frames; ///< for deordering, etc.
   gchar file_name[PATH_MAX]; ///< input file
   gchar info_file[PATH_MAX];
   gchar name[256];  ///< the display name
   gchar save_file_name[PATH_MAX];
   gchar type[40];
-  gint start;
-  gint end;
-  gint insert_start;
-  gint insert_end;
-  gint progress_start;
-  gint progress_end;
+  int start;
+  int end;
+  int insert_start;
+  int insert_end;
+  int progress_start;
+  int progress_end;
   boolean changed;
   GtkWidget *menuentry;
+  gulong menuentry_func;
   boolean orig_file_name;
   boolean was_renamed;
   boolean is_untitled;
-  gdouble pb_fps;
-  gdouble freeze_fps;
+  double pb_fps;
+  double freeze_fps;
   boolean play_paused;
   
   //opening/restoring status
@@ -549,16 +550,16 @@ typedef struct {
   /// don't show the 'keep' button - e.g. for operations which resize frames
   boolean nokeep;
 
-  // various times; total time is calculated as the gint64est of video, laudio and raudio
-  gdouble total_time;
-  gdouble video_time;
-  gdouble laudio_time;
-  gdouble raudio_time;
-  gdouble pointer_time;
+  // various times; total time is calculated as the longest of video, laudio and raudio
+  double total_time;
+  double video_time;
+  double laudio_time;
+  double raudio_time;
+  double pointer_time;
 
   // current and last played index frames for internal player
-  gint frameno;
-  gint last_frameno;
+  int frameno;
+  int last_frameno;
 
 
 
@@ -579,30 +580,30 @@ typedef struct {
   ///undo
   lives_undo_t undo_action;
 
-  gint undo_start;
-  gint undo_end;
+  int undo_start;
+  int undo_end;
   gchar undo_text[32];
   gchar redo_text[32];
   boolean undoable;
   boolean redoable;
 
   // used for storing undo values
-  gint undo1_int;
-  gint undo2_int;
-  gint undo3_int;
-  gint undo4_int;
-  guint undo1_uint;
-  gdouble undo1_dbl;
-  gdouble undo2_dbl;
+  int undo1_int;
+  int undo2_int;
+  int undo3_int;
+  int undo4_int;
+  uint32_t undo1_uint;
+  double undo1_dbl;
+  double undo2_dbl;
   boolean undo1_boolean;
   boolean undo2_boolean;
   boolean undo3_boolean;
 
-  gint undo_arate; ///< audio playback rate
-  guint undo_signed_endian;
-  gint undo_achans;
-  gint undo_asampsize;
-  gint undo_arps; ///< audio sample rate
+  int undo_arate; ///< audio playback rate
+  uint32_t undo_signed_endian;
+  int undo_achans;
+  int undo_asampsize;
+  int undo_arps; ///< audio sample rate
 
   lives_clip_type_t clip_type;
 
@@ -616,7 +617,7 @@ typedef struct {
 
   int *frame_index_back; ///< for undo
 
-  gint fx_frame_pump; ///< rfx frame pump for virtual clips (CLIP_TYPE_FILE)
+  int fx_frame_pump; ///< rfx frame pump for virtual clips (CLIP_TYPE_FILE)
 
 #define FX_FRAME_PUMP_VAL 200 ///< how many frames to prime the pump for realtime effects and resampler
 
@@ -636,15 +637,15 @@ typedef struct {
   lives_image_type_t img_type;
 
   /// layout map for the current layout
-  gint stored_layout_frame;
-  gint stored_layout_idx;
-  gdouble stored_layout_audio;
-  gdouble stored_layout_fps;
+  int stored_layout_frame;
+  int stored_layout_idx;
+  double stored_layout_audio;
+  double stored_layout_fps;
 
   lives_subtitles_t *subt;
 
   gchar *op_dir;
-  guint64 op_ds_warn_level; ///< current disk space warning level for any output directory
+  uint64_t op_ds_warn_level; ///< current disk space warning level for any output directory
 
   boolean no_proc_sys_errors; ///< skip system error dialogs in processing
   boolean no_proc_read_errors; ///< skip read error dialogs in processing
@@ -702,9 +703,9 @@ typedef struct {
   boolean has_encoder_plugins;
 
   boolean has_python;
-  guint64 python_version;
+  uint64_t python_version;
 
-  gshort cpu_bits;
+  short cpu_bits;
   
 
   gchar *myname_full;
@@ -712,9 +713,9 @@ typedef struct {
 
   boolean has_stderr;
 
-  gint nmonitors;
+  int nmonitors;
 
-  gint ncpus;
+  int ncpus;
 
 
 #define LIVES_LITTLE_ENDIAN G_LITTLE_ENDIAN
@@ -722,6 +723,8 @@ typedef struct {
 
   int byte_order;
 
+  pid_t mainpid;
+
 } capability;
 
 
@@ -805,7 +808,8 @@ typedef enum {
   CLIP_DETAILS_CLIPNAME,
   CLIP_DETAILS_HEADER_VERSION,
   CLIP_DETAILS_KEYWORDS,
-  CLIP_DETAILS_INTERLACE
+  CLIP_DETAILS_INTERLACE,
+  CLIP_DETAILS_DECODER_NAME
 } lives_clip_details_t;
 
 
@@ -813,8 +817,8 @@ typedef enum {
 
 // interface.c
 xprocess* create_processing (const gchar *text);
-void add_to_winmenu(void);
-void remove_from_winmenu(void);
+void add_to_clipmenu(void);
+void remove_from_clipmenu(void);
 void make_play_window(void);
 void resize_play_window (void);
 void kill_play_window (void);
@@ -824,7 +828,7 @@ void add_to_playframe (void);
 GtkWidget* create_cdtrack_dialog (int type, gpointer user_data);
 GtkTextView *create_output_textview(void);
 gchar *choose_file(gchar *dir, gchar *fname, gchar **filt, lives_file_chooser_action_t act, const char *title, GtkWidget *extra);
-void choose_file_with_preview (gchar *dir, const gchar *title, int preview_type);
+GtkWidget *choose_file_with_preview (gchar *dir, const gchar *title, int preview_type);
 void add_suffix_check(GtkBox *box, const gchar *ext);
 
 
@@ -833,7 +837,11 @@ boolean do_progress_dialog(boolean visible, boolean cancellable, const gchar *te
 boolean do_warning_dialog(const gchar *text);
 boolean do_warning_dialog_with_check(const gchar *text, int warn_mask_number);
 boolean do_warning_dialog_with_check_transient(const gchar *text, int warn_mask_number, GtkWindow *transient);
-boolean do_yesno_dialog(const gchar *text) WARN_UNUSED;
+boolean do_yesno_dialog(const gchar *text);
+boolean do_yesno_dialog_with_check (const gchar *text, int warn_mask_number);
+boolean do_yesno_dialog_with_check_transient(const gchar *text, int warn_mask_number, GtkWindow *transient);
+boolean do_yesno_dialog_with_check(const gchar *text, int warn_mask_number);
+boolean do_yesno_dialog_with_check_transient(const gchar *text, int warn_mask_number, GtkWindow *transient);
 int do_abort_cancel_retry_dialog(const gchar *text, GtkWindow *transient) WARN_UNUSED;
 void do_error_dialog(const gchar *text);
 void do_info_dialog(const gchar *text);
@@ -858,8 +866,8 @@ void handle_backend_errors(void);
 boolean check_backend_return(file *sfile);
 
 /** warn about disk space */
-gchar *ds_critical_msg(const gchar *dir, guint64 dsval);
-gchar *ds_warning_msg(const gchar *dir, guint64 dsval, guint64 cwarn, guint64 nwarn);
+gchar *ds_critical_msg(const gchar *dir, uint64_t dsval);
+gchar *ds_warning_msg(const gchar *dir, uint64_t dsval, uint64_t cwarn, uint64_t nwarn);
 boolean check_storage_space(file *sfile, boolean is_processing);
 
 gchar *get_upd_msg(void);
@@ -872,7 +880,7 @@ void do_memory_error_dialog (void);
 void too_many_files(void);
 void tempdir_warning (void);
 void do_audio_import_error(void);
-void do_mt_backup_space_error(lives_mt *, gint memreq_mb);
+void do_mt_backup_space_error(lives_mt *, int memreq_mb);
 
 boolean do_clipboard_fps_warning(void);
 void perf_mem_warning(void);
@@ -914,7 +922,7 @@ void do_nojack_rec_error(void);
 void do_vpp_palette_error (void);
 void do_vpp_fps_error (void);
 void do_decoder_palette_error (void);
-void do_rmem_max_error (gint size);
+void do_rmem_max_error (int size);
 boolean do_original_lost_warning(const gchar *fname);
 void do_no_decoder_error(const gchar *fname);
 void do_jack_noopen_warn(void);
@@ -967,6 +975,7 @@ void do_text_window (const gchar *title, const gchar *text);
 boolean read_file_details(const gchar *file_name, boolean only_check_for_audio);
 boolean add_file_info(const gchar *check_handle, boolean aud_only);
 boolean save_file_comments (int fileno);
+boolean reload_clip(int fileno);
 void reget_afilesize (int fileno);
 void deduce_file(const gchar *filename, double start_time, int end);
 void open_file (const gchar *filename);
@@ -990,7 +999,7 @@ const gchar *get_deinterlace_string(void);
 
 // saveplay.c backup
 void backup_file(int clip, int start, int end, const gchar *filename);
-gint save_event_frames(void);
+int save_event_frames(void);
 boolean write_headers (file *file);
 
 // saveplay.c restore
@@ -998,7 +1007,7 @@ void restore_file(const gchar *filename);
 boolean read_headers(const gchar *file_name);
 
 // saveplay.c sets
-void open_set_file (const gchar *set_name, gint clipnum);
+void open_set_file (const gchar *set_name, int clipnum);
 
 
 // saveplay.c scrap file
@@ -1019,17 +1028,19 @@ void defer_sigint(int signum);
 boolean startup_message_fatal(const gchar *msg);
 boolean startup_message_nonfatal(const gchar *msg);
 boolean startup_message_info(const gchar *msg);
-boolean startup_message_nonfatal_dismissable(const gchar *msg, gint warning_mask);
+boolean startup_message_nonfatal_dismissable(const gchar *msg, int warning_mask);
 capability *get_capabilities(void);
 void get_monitors(void);
 void set_ce_frame_from_pixbuf(GtkImage *image, GdkPixbuf *pixbuf, lives_painter_t *);
-void load_start_image(gint frame);
-void load_end_image(gint frame);
+void load_start_image(int frame);
+void load_end_image(int frame);
 void load_preview_image(boolean update_always);
 
 boolean pull_frame(weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc);
+void pull_frame_threaded (weed_plant_t *layer, const char *img_ext, weed_timecode_t tc);
+void check_layer_ready(weed_plant_t *layer);
 boolean pull_frame_at_size (weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc, 
-			     int width, int height, int target_palette);
+			    int width, int height, int target_palette);
 LiVESPixbuf *pull_lives_pixbuf_at_size(int clip, int frame, const char *image_ext, weed_timecode_t tc, 
 				       int width, int height, LiVESInterpType interp);
 LiVESPixbuf *pull_lives_pixbuf(int clip, int frame, const char *image_ext, weed_timecode_t tc);
@@ -1037,19 +1048,23 @@ LiVESPixbuf *pull_lives_pixbuf(int clip, int frame, const char *image_ext, weed_
 GError * lives_pixbuf_save(GdkPixbuf *pixbuf, gchar *fname, lives_image_type_t imgtype, 
 			   int quality, boolean do_chmod, GError **gerrorptr);
 
-void load_frame_image(gint frame);
+void init_track_decoders(void);
+void free_track_decoders(void);
+
+
+void load_frame_image(int frame);
 void sensitize(void);
 void desensitize(void);
 void procw_desensitize(void);
-void close_current_file (gint file_to_switch_to);  ///< close current file, and try to switch to file_to_switch_to
+void close_current_file (int file_to_switch_to);  ///< close current file, and try to switch to file_to_switch_to
 void get_next_free_file(void);
-void switch_to_file(gint old_file, gint new_file);
-void do_quick_switch (gint new_file);
-void switch_audio_clip(gint new_file, boolean activate);
-void resize (gdouble scale);
+void switch_to_file(int old_file, int new_file);
+void do_quick_switch (int new_file);
+void switch_audio_clip(int new_file, boolean activate);
+void resize (double scale);
 void do_start_messages(void);
 void set_palette_colours (void);
-void set_main_title(const gchar *filename, gint or_untitled_number);
+void set_main_title(const gchar *filename, int or_untitled_number);
 void set_record (void);
 
 //gui.c
@@ -1077,10 +1092,19 @@ boolean expose_eim (GtkWidget *widget, lives_painter_t *cr, gpointer user_data);
 // system calls in utils.c
 int lives_system(const char *com, boolean allow_error);
 lives_pid_t lives_fork(const char *com);
+int lives_open_buffered_rdonly(const char *pathname);
+int lives_creat_buffered(const char *pathname, int mode);
+int lives_close_buffered(int fd);
+void lives_close_all_file_buffers(void);
+off_t lives_lseek_buffered_rdonly(int fd, off_t offset);
 ssize_t lives_write(int fd, const void *buf, size_t count, boolean allow_fail);
+ssize_t lives_write_buffered(int fd, const void *buf, size_t count, boolean allow_fail);
 ssize_t lives_write_le(int fd, const void *buf, size_t count, boolean allow_fail);
+ssize_t lives_write_le_buffered(int fd, const void *buf, size_t count, boolean allow_fail);
 ssize_t lives_read(int fd, void *buf, size_t count, boolean allow_less);
+ssize_t lives_read_buffered(int fd, void *buf, size_t count, boolean allow_less);
 ssize_t lives_read_le(int fd, void *buf, size_t count, boolean allow_less);
+ssize_t lives_read_le_buffered(int fd, void *buf, size_t count, boolean allow_less);
 int lives_chdir(const char *path, boolean allow_fail);
 int lives_fputs(const char *s, FILE *stream);
 char *lives_fgets(char *s, int size, FILE *stream);
@@ -1136,12 +1160,11 @@ void get_location(const char *exe, char *val, int maxlen);
 void set_menu_text(GtkWidget *menu, const char *text, boolean use_mnemonic);
 void get_menu_text(GtkWidget *menu, char *text);
 void get_menu_text_long(GtkWidget *menuitem, char *text);
-void reset_clip_menu (void);
+void reset_clipmenu (void);
 void get_play_times(void);
 void get_total_time (file *file);
 uint32_t get_signed_endian (boolean is_signed, boolean little_endian);
 void fullscreen_internal(void);
-void colour_equal(GdkColor *c1, const GdkColor *c2);
 void switch_to_int_player(void);
 void switch_to_mplayer(void);
 void switch_aud_to_sox(boolean set_pref);
@@ -1175,28 +1198,28 @@ void calc_maxspect(int rwidth, int rheight, int *cwidth, int *cheight);
 char *remove_trailing_zeroes(double val);
 
 void remove_layout_files(GList *lmap);
-gboolean add_lmap_error(lives_lmap_error_t lerror, const char *name, gpointer user_data, 
-			int clipno, int frameno, double atime, gboolean affects_current);
+boolean add_lmap_error(lives_lmap_error_t lerror, const char *name, gpointer user_data, 
+			int clipno, int frameno, double atime, boolean affects_current);
 void clear_lmap_errors(void);
-gboolean prompt_remove_layout_files(void);
-gboolean is_legal_set_name(const char *set_name, gboolean allow_dupes);
-char *repl_tmpdir(const char *entry, gboolean fwd);
+boolean prompt_remove_layout_files(void);
+boolean is_legal_set_name(const char *set_name, boolean allow_dupes);
+char *repl_tmpdir(const char *entry, boolean fwd);
 char *clip_detail_to_string(lives_clip_details_t what, size_t *maxlenp);
-gboolean get_clip_value(int which, lives_clip_details_t, void *retval, size_t maxlen);
+boolean get_clip_value(int which, lives_clip_details_t, void *retval, size_t maxlen);
 void save_clip_value(int which, lives_clip_details_t, void *val);
-gboolean check_frame_count(int idx);
+boolean check_frame_count(int idx);
 void get_frame_count(int idx);
 void get_frames_sizes(int fileno, int frame_to_test);
 int count_resampled_frames (int in_frames, double orig_fps, double resampled_fps);
 boolean int_array_contains_value(int *array, int num_elems, int value);
-gboolean check_for_lock_file(const char *set_name, int type);
+boolean check_for_lock_file(const char *set_name, int type);
 void g_list_free_strings(GList *list);
 
-gboolean create_event_space(int length_in_eventsb);
+boolean create_event_space(int length_in_eventsb);
 void add_to_recent(const char *filename, double start, int frames, const char *file_open_params);
 int verhash (char *version);
-void set_undoable (const char *what, gboolean sensitive);
-void set_redoable (const char *what, gboolean sensitive);
+void set_undoable (const char *what, boolean sensitive);
+void set_redoable (const char *what, boolean sensitive);
 void zero_spinbuttons (void);
 void draw_little_bars (double ptrtime);
 void set_sel_label (GtkWidget *label);
@@ -1209,12 +1232,12 @@ void find_when_to_stop (void);
 int calc_new_playback_position(int fileno, uint64_t otc, uint64_t *ntc);
 void calc_aframeno(int fileno);
 void minimise_aspect_delta (double allowed_aspect,int hblock,int vblock,int hsize,int vsize,int *width,int *height);
-LiVESInterpType get_interp_value(gshort quality);
+LiVESInterpType get_interp_value(short quality);
 
-GList *g_list_move_to_first(GList *list, GList *item) WARN_UNUSED;
+GList *lives_list_move_to_first(GList *list, GList *item) WARN_UNUSED;
 GList *g_list_delete_string(GList *, char *string) WARN_UNUSED;
 GList *g_list_copy_strings(GList *list);
-gboolean string_lists_differ(GList *, GList *);
+boolean string_lists_differ(GList *, GList *);
 
 
 GList *get_set_list(const char *dir);
@@ -1236,13 +1259,13 @@ lives_cancel_t check_for_bad_ffmpeg(void);
 
 // plugins.c
 GList *get_external_window_hints(lives_rfx_t *rfx);
-gboolean check_encoder_restrictions (boolean get_extension, boolean user_audio, boolean save_all);
+boolean check_encoder_restrictions (boolean get_extension, boolean user_audio, boolean save_all);
 
 //callbacks.c
 void lives_exit (void);
 void count_opening_frames(void);
 void on_fileread_clicked (GtkFileChooser *, gpointer widget);
-gboolean dirchange_callback (GtkAccelGroup *, GObject *, uint32_t, GdkModifierType, gpointer user_data);
+boolean dirchange_callback (GtkAccelGroup *, GObject *, uint32_t, GdkModifierType, gpointer user_data);
 void on_effects_paused (GtkButton *, gpointer user_data);
 void on_cancel_keep_button_clicked (GtkButton *, gpointer user_data);
 void on_cleardisk_activate (GtkWidget *, gpointer user_data);
@@ -1277,7 +1300,7 @@ LiVESPixbuf *make_thumb (lives_mt *, int file, int width, int height, int frame,
 LiVESPixbuf *mt_framedraw(lives_mt *, LiVESPixbuf *);
 
 // rte_window.c
-void refresh_rte_window (void);
+GtkWidget *refresh_rte_window (void);
 
 // effects-weed.c
 void * lives_malloc(size_t size);
@@ -1291,19 +1314,19 @@ void lives_free_normal(void *ptr);
 void lives_free_with_check(gpointer ptr); ///< checks if ptr is mainw->do_not_free, otherwise calls lives_free_normal()
 
 // pangotext.c
-gboolean subtitles_init(file *sfile, char * fname, lives_subtitle_type_t);
+boolean subtitles_init(file *sfile, char * fname, lives_subtitle_type_t);
 void subtitles_free(file *sfile);
-gboolean get_srt_text(file *sfile, double xtime);
-gboolean get_sub_text(file *sfile, double xtime);
-gboolean save_sub_subtitles(file *sfile, double start_time, double end_time, double offset_time, const char *filename);
-gboolean save_srt_subtitles(file *sfile, double start_time, double end_time, double offset_time, const char *filename);
+boolean get_srt_text(file *sfile, double xtime);
+boolean get_sub_text(file *sfile, double xtime);
+boolean save_sub_subtitles(file *sfile, double start_time, double end_time, double offset_time, const char *filename);
+boolean save_srt_subtitles(file *sfile, double start_time, double end_time, double offset_time, const char *filename);
 
 // osc.c
 #ifdef ENABLE_OSC
-gboolean lives_osc_init(guint osc_udp_port);
-gint lives_osc_poll(gpointer data);
+boolean lives_osc_init(uint32_t osc_udp_port);
+int lives_osc_poll(gpointer data);
 void lives_osc_end(void);
-gboolean lives_osc_notify(int msgtype, const char *msgstring);
+boolean lives_osc_notify(int msgtype, const char *msgstring);
 void lives_osc_notify_success (const gchar *msg);
 void lives_osc_notify_failure (void);
 void lives_osc_notify_cancel (void);
@@ -1338,6 +1361,8 @@ void on_open_fw_activate (GtkMenuItem *menuitem, gpointer format);
 
 gchar *dummychar;
 
+void break_me(void);
+
 #define LIVES_NO_DEBUG
 #ifndef LIVES_DEBUG
 #ifndef LIVES_NO_DEBUG
@@ -1365,7 +1390,7 @@ gchar *dummychar;
 
 #ifndef LIVES_ERROR
 #ifndef LIVES_NO_ERROR
-#define LIVES_ERROR(x)      fprintf(stderr, "LiVES error: %s\n", x)
+#define LIVES_ERROR(x)      {fprintf(stderr, "LiVES error: %s\n", x); break_me();}
 #else // LIVES_NO_ERROR
 #define LIVES_ERROR(x)      dummychar = x
 #endif // LIVES_NO_ERROR
