@@ -709,6 +709,7 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, gint row, om
 
   if (palette->style&STYLE_1) {
     lives_widget_set_base_color(mnode->treev2, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars);
+    lives_widget_set_text_color(mnode->treev2, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars_fore);
   }
 
   renderer = gtk_cell_renderer_text_new ();
@@ -743,7 +744,7 @@ static void omc_macro_row_add_params(lives_omc_match_node_t *mnode, gint row, om
 
   lives_widget_show (mnode->treev2);
   
-  lives_table_attach (GTK_TABLE (omclw->table), mnode->treev2, 3, 4, row, row+1,
+  lives_table_attach (LIVES_TABLE (omclw->table), mnode->treev2, 3, 4, row, row+1,
 		    (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
 		    (GtkAttachOptions) (0), 0, 0);
   
@@ -959,7 +960,7 @@ static GtkWidget *create_omc_macro_combo(lives_omc_match_node_t *mnode, gint row
   }
 
   if (mnode->macro!=-1) {
-    lives_combo_set_active_index (GTK_COMBO_BOX(combo),mnode->macro);
+    lives_combo_set_active_index (LIVES_COMBO(combo),mnode->macro);
   }
 
   g_signal_connect_after (G_OBJECT (combo), "changed", G_CALLBACK (on_omc_combo_entry_changed), mnode);
@@ -991,9 +992,10 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
    gint chan;
 
    omclw->tbl_rows++;
-   gtk_table_resize(GTK_TABLE(omclw->table),omclw->tbl_rows,6);
+   lives_table_resize(LIVES_TABLE(omclw->table),omclw->tbl_rows,6);
 			
-   mnode->gtkstore = gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+   mnode->gtkstore = gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_STRING, 
+					 G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
    gtk_tree_store_append (mnode->gtkstore, &iter1, NULL);  /* Acquire an iterator */
    gtk_tree_store_set (mnode->gtkstore, &iter1, TITLE_COLUMN, (_("Vars.")), -1);
@@ -1081,13 +1083,14 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
    if (labelt!=NULL) g_free(labelt);
      
    omclw->tbl_currow++;
-   lives_table_attach (GTK_TABLE (omclw->table), label, 0, 1, omclw->tbl_currow, omclw->tbl_currow+1,
+   lives_table_attach (LIVES_TABLE (omclw->table), label, 0, 1, omclw->tbl_currow, omclw->tbl_currow+1,
 		     (GtkAttachOptions) (0),
 		     (GtkAttachOptions) (0), 0, 0);
 
    // properties
   if (palette->style&STYLE_1) {
     lives_widget_set_base_color(mnode->treev1, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars);
+    lives_widget_set_text_color(mnode->treev1, LIVES_WIDGET_STATE_NORMAL, &palette->menu_and_bars_fore);
   }
 
    renderer = gtk_cell_renderer_text_new ();
@@ -1179,7 +1182,7 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
 
    lives_widget_show (mnode->treev1);
   
-   lives_table_attach (GTK_TABLE (omclw->table), mnode->treev1, 1, 2, omclw->tbl_currow, omclw->tbl_currow+1,
+   lives_table_attach (LIVES_TABLE (omclw->table), mnode->treev1, 1, 2, omclw->tbl_currow, omclw->tbl_currow+1,
 		     (GtkAttachOptions) (0),
 		     (GtkAttachOptions) (0), 0, 0);
 
@@ -1187,7 +1190,7 @@ static void omc_learner_add_row(gint type, gint detail, lives_omc_match_node_t *
 
    lives_widget_show (combo);
   
-   lives_table_attach (GTK_TABLE (omclw->table), combo, 2, 3, omclw->tbl_currow, omclw->tbl_currow+1,
+   lives_table_attach (LIVES_TABLE (omclw->table), combo, 2, 3, omclw->tbl_currow, omclw->tbl_currow+1,
 		     (GtkAttachOptions) 0,
 		     (GtkAttachOptions) (0), 0, 0);
 
@@ -1312,11 +1315,11 @@ static omclearn_w *create_omclearn_dialog(void) {
   
   omclw->dialog = lives_standard_dialog_new (_("LiVES: OMC learner"),FALSE);
   
-  omclw->top_vbox = lives_dialog_get_content_area(GTK_DIALOG(omclw->dialog));
+  omclw->top_vbox = lives_dialog_get_content_area(LIVES_DIALOG(omclw->dialog));
 
-  omclw->table = gtk_table_new (omclw->tbl_rows, 4, FALSE);
+  omclw->table = lives_table_new (omclw->tbl_rows, 4, FALSE);
 
-  gtk_table_set_col_spacings(GTK_TABLE(omclw->table),widget_opts.packing_width*2);
+  lives_table_set_col_spacings(LIVES_TABLE(omclw->table),widget_opts.packing_width*2);
 
   scrolledwindow = lives_standard_scrolled_window_new (winsize_h, winsize_v, omclw->table);
 
@@ -1355,7 +1358,7 @@ static omclearn_w *create_omclearn_dialog(void) {
   
   lives_widget_set_can_focus_and_default (ok_button);
 
-  gtk_widget_grab_default (ok_button);
+  lives_widget_grab_default (ok_button);
 
 #if !GTK_CHECK_VERSION(3,0,0)
   gtk_button_box_set_child_size (GTK_BUTTON_BOX (hbuttonbox), DEF_BUTTON_WIDTH, -1);
@@ -1376,12 +1379,12 @@ static omclearn_w *create_omclearn_dialog(void) {
 						    -lives_widget_get_allocation_width(omclw->dialog))/2;
     gint ycen=mainw->mgeom[prefs->gui_monitor-1].y+(mainw->mgeom[prefs->gui_monitor-1].height
 						    -lives_widget_get_allocation_height(omclw->dialog))/2;
-    gtk_window_set_screen(GTK_WINDOW(omclw->dialog),mainw->mgeom[prefs->gui_monitor-1].screen);
-    lives_window_move(GTK_WINDOW(omclw->dialog),xcen,ycen);
+    lives_window_set_screen(LIVES_WINDOW(omclw->dialog),mainw->mgeom[prefs->gui_monitor-1].screen);
+    lives_window_move(LIVES_WINDOW(omclw->dialog),xcen,ycen);
   }
   
   if (prefs->open_maximised) {
-    lives_window_maximize (GTK_WINDOW(omclw->dialog));
+    lives_window_maximize (LIVES_WINDOW(omclw->dialog));
   }
 
   if (prefs->show_gui)
@@ -2573,12 +2576,14 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
   if (bytes<strlen(OMC_FILE_VSTRING)) {
     do_midi_load_error(load_file);
     g_free (load_file);
+    close(fd);
     return;
   }
 
   if (strncmp(tstring,OMC_FILE_VSTRING,strlen(OMC_FILE_VSTRING))) {
     do_midi_version_error(load_file);
     g_free (load_file);
+    close(fd);
     return;
   }
 
@@ -2586,6 +2591,7 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
   if (bytes<4) {
     do_midi_load_error(load_file);
     g_free (load_file);
+    close(fd);
     return;
   }
 
@@ -2600,6 +2606,7 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
     if (bytes<4) {
       do_midi_load_error(load_file);
       g_free (load_file);
+      close(fd);
       return;
     }
     
@@ -2609,6 +2616,7 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
     if (bytes<srchlen) {
       do_midi_load_error(load_file);
       g_free (load_file);
+      close(fd);
       return;
     }
 
@@ -2619,6 +2627,7 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
       do_midi_load_error(load_file);
       g_free (load_file);
       g_free(srch);
+      close(fd);
       return;
     }
     
@@ -2627,6 +2636,7 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
       do_midi_load_error(load_file);
       g_free (load_file);
       g_free(srch);
+      close(fd);
       return;
     }
     
@@ -2668,18 +2678,21 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
       if (bytes<4) {
 	do_midi_load_error(load_file);
 	g_free (load_file);
+	close(fd);
 	return;
       }
       bytes=lives_read_le(fd,&mnode->scale[j],8,TRUE);
       if (bytes<8) {
 	do_midi_load_error(load_file);
 	g_free (load_file);
+	close(fd);
 	return;
       }
       bytes=lives_read_le(fd,&mnode->offs1[j],4,TRUE);
       if (bytes<4) {
 	do_midi_load_error(load_file);
 	g_free (load_file);
+	close(fd);
 	return;
       }
       
@@ -2687,11 +2700,14 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
       if (bytes<4) {
 	do_midi_load_error(load_file);
 	g_free (load_file);
+	close(fd);
 	return;
       }
       bytes=lives_read_le(fd,&mnode->max[j],4,TRUE);
       if (bytes<4) {
 	do_midi_load_error(load_file);
+	g_free (load_file);
+	close(fd);
 	return;
       }
       
@@ -2699,12 +2715,14 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
       if (bytes<4) {
 	do_midi_load_error(load_file);
 	g_free (load_file);
+	close(fd);
 	return;
       }
       bytes=lives_read_le(fd,&mnode->matchi[j],4,TRUE);
       if (bytes<4) {
 	do_midi_load_error(load_file);
 	g_free (load_file);
+	close(fd);
 	return;
       }
     }
@@ -2720,18 +2738,21 @@ void on_midi_load_activate (GtkMenuItem *menuitem, gpointer user_data) {
       if (bytes<4) {
 	do_midi_load_error(load_file);
 	g_free (load_file);
+	close(fd);
 	return;
       }
       bytes=lives_read_le(fd,&mnode->fvali[j],4,TRUE);
       if (bytes<4) {
 	do_midi_load_error(load_file);
 	g_free (load_file);
+	close(fd);
 	return;
       }
       bytes=read(fd,&mnode->fvald[j],8);
       if (bytes<8) {
 	do_midi_load_error(load_file);
 	g_free (load_file);
+	close(fd);
 	return;
       }
     }
