@@ -204,6 +204,10 @@ typedef struct {
   int nclips; ///< number of clips (titles) in container
   gchar container_name[512]; ///< name of container, e.g. "ogg" or NULL
 
+  char title[256];
+  char author[256];
+  char comment[256];
+
   /// plugin should init this to 0 if URI changes
   int current_clip; ///< current clip number in container (starts at 0, MUST be <= nclips) [rw host]
 
@@ -222,6 +226,8 @@ typedef struct {
 
   float par; ///< pixel aspect ratio
 
+  float video_start_time;
+
   float fps;
 
   int *palettes;
@@ -244,7 +250,13 @@ typedef struct {
 
   int seek_flag;
 
-#define SYNC_HINT_AUDIO_TRIM_START 1
+#define SYNC_HINT_AUDIO_TRIM_START (1<<0)
+#define SYNC_HINT_AUDIO_PAD_START (1<<1)
+#define SYNC_HINT_AUDIO_TRIM_END (1<<2)
+#define SYNC_HINT_AUDIO_PAD_END (1<<3)
+
+#define SYNC_HINT_VIDEO_PAD_START (1<<4)
+#define SYNC_HINT_VIDEO_PAD_END (1<<5)
 
   int sync_hint;
 
@@ -269,7 +281,10 @@ typedef struct {
   /// we can also set cdata->current_palette (must be in list cdata->palettes[])
   ///
   /// if URI changes, current_clip and current_palette are reset by plugin
-  lives_clip_data_t *(*get_clip_data)(char *URI, lives_clip_data_t *cdata);
+  ///
+  /// to get a clone of cdata, pass in NULL URI and cdata
+  ///
+  lives_clip_data_t *(*get_clip_data)(char *URI, const lives_clip_data_t *cdata);
 
   /// frame starts at 0 in these functions; height is height of primary plane
   boolean (*get_frame)(const lives_clip_data_t *, int64_t frame, int *rowstrides, int height, void **pixel_data);
@@ -279,6 +294,7 @@ typedef struct {
 
   // optional
   const char *(*module_check_init)(void);
+  boolean (*set_palette)(lives_clip_data_t *);
   int64_t (*rip_audio) (const lives_clip_data_t *, const char *fname, int64_t stframe, int64_t nframes, 
 			unsigned char **abuff);
   void (*rip_audio_cleanup) (const lives_clip_data_t *cdata);
@@ -298,8 +314,7 @@ typedef struct {
 
 
 
-
-const lives_clip_data_t *get_decoder_cdata(file *, GList *disabled);
+const lives_clip_data_t *get_decoder_cdata(int fileno, GList *disabled, const lives_clip_data_t *fake_cdata);
 void close_decoder_plugin (lives_decoder_t *);
 lives_decoder_sys_t *open_decoder_plugin(const gchar *plname);
 void get_mime_type(gchar *text, int maxlen, const lives_clip_data_t *);
@@ -307,6 +322,7 @@ void unload_decoder_plugins(void);
 
 boolean decplugin_supports_palette (const lives_decoder_t *dplug, int palette);
 
+lives_decoder_t *clone_decoder(int fileno);
 
 
 // RFX plugins
