@@ -15,7 +15,7 @@
 
 
 
-static boolean prompt_existing_dir(gchar *dirname, guint64 freespace, boolean wrtable) {
+static boolean prompt_existing_dir(gchar *dirname, uint64_t freespace, boolean wrtable) {
   gchar *msg;
   boolean res=FALSE;
 
@@ -41,7 +41,7 @@ static boolean prompt_existing_dir(gchar *dirname, guint64 freespace, boolean wr
 
 
 
-static boolean prompt_new_dir(gchar *dirname, guint64 freespace, boolean wrtable) {
+static boolean prompt_new_dir(gchar *dirname, uint64_t freespace, boolean wrtable) {
   boolean res=FALSE;
   gchar *msg;
   if (wrtable) {
@@ -63,12 +63,13 @@ static boolean prompt_new_dir(gchar *dirname, guint64 freespace, boolean wrtable
 
 
 boolean do_tempdir_query(void) {
+  _entryw *tdentry;
+  uint64_t freesp;
+
   int response;
   boolean ok=FALSE;
-  _entryw *tdentry;
-  gchar *dirname;
-  guint64 freesp;
 
+  gchar *dirname;
 #ifndef IS_MINGW
   gchar *com;
 #endif
@@ -78,12 +79,12 @@ boolean do_tempdir_query(void) {
   tdentry=create_rename_dialog(6);
 
   while (!ok) {
-    response=lives_dialog_run(GTK_DIALOG(tdentry->dialog));
+    response=lives_dialog_run(LIVES_DIALOG(tdentry->dialog));
 
     if (response==GTK_RESPONSE_CANCEL) {
       return FALSE;
     }
-    dirname=g_strdup(lives_entry_get_text(GTK_ENTRY(tdentry->entry)));
+    dirname=g_strdup(lives_entry_get_text(LIVES_ENTRY(tdentry->entry)));
 
     if (strcmp(dirname+strlen(dirname)-1,G_DIR_SEPARATOR_S)) {
       gchar *tmp=g_strdup_printf("%s%s",dirname,G_DIR_SEPARATOR_S);
@@ -162,9 +163,9 @@ boolean do_tempdir_query(void) {
   set_pref("session_tempdir",prefs->tmpdir);
 
 #ifndef IS_MINGW
-  g_snprintf(mainw->first_info_file,PATH_MAX,"%s"G_DIR_SEPARATOR_S".info.%d",prefs->tmpdir,getpid());
+  g_snprintf(mainw->first_info_file,PATH_MAX,"%s"G_DIR_SEPARATOR_S".info.%d",prefs->tmpdir,capable->mainpid);
 #else
-  g_snprintf(mainw->first_info_file,PATH_MAX,"%s"G_DIR_SEPARATOR_S"info.%d",prefs->tmpdir,getpid());
+  g_snprintf(mainw->first_info_file,PATH_MAX,"%s"G_DIR_SEPARATOR_S"info.%d",prefs->tmpdir,capable->mainpid);
 #endif
 
   g_free(dirname);
@@ -176,7 +177,7 @@ boolean do_tempdir_query(void) {
 
 
 static void on_init_aplayer_toggled (GtkToggleButton *tbutton, gpointer user_data) {
-  gint audp=GPOINTER_TO_INT(user_data);
+  int audp=GPOINTER_TO_INT(user_data);
 
   if (!lives_toggle_button_get_active(tbutton)) return;
 
@@ -213,7 +214,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
   gchar *txt0,*txt1,*txt2,*txt3,*txt4,*txt5,*txt6,*txt7,*msg;
 
-  gint response;
+  int response;
 
   if (startup_phase==2) {
     txt0=g_strdup(_("LiVES FAILED TO START YOUR SELECTED AUDIO PLAYER !\n\n"));
@@ -277,9 +278,9 @@ boolean do_audio_choice_dialog(short startup_phase) {
   dialog = lives_standard_dialog_new (_("LiVES: - Choose an audio player"),FALSE);
 
   accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
-  gtk_window_add_accel_group (GTK_WINDOW (dialog), accel_group);
+  lives_window_add_accel_group (LIVES_WINDOW (dialog), accel_group);
 
-  dialog_vbox = lives_dialog_get_content_area(GTK_DIALOG(dialog));
+  dialog_vbox = lives_dialog_get_content_area(LIVES_DIALOG(dialog));
   
   label=lives_standard_label_new(msg);
   lives_container_add (LIVES_CONTAINER (dialog_vbox), label);
@@ -371,19 +372,19 @@ boolean do_audio_choice_dialog(short startup_phase) {
   }
 
 
-  cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
+  cancelbutton = lives_button_new_from_stock ("gtk-cancel");
   lives_widget_show (cancelbutton);
-  lives_dialog_add_action_widget (GTK_DIALOG (dialog), cancelbutton, GTK_RESPONSE_CANCEL);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), cancelbutton, GTK_RESPONSE_CANCEL);
 
   lives_widget_add_accelerator (cancelbutton, "activate", accel_group,
                               LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
 
-  okbutton = gtk_button_new_from_stock ("gtk-go-forward");
+  okbutton = lives_button_new_from_stock ("gtk-go-forward");
   lives_button_set_label(GTK_BUTTON(okbutton),_("_Next"));
   lives_widget_show (okbutton);
-  lives_dialog_add_action_widget (GTK_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (okbutton);
-  gtk_widget_grab_default(okbutton);
+  lives_widget_grab_default(okbutton);
   lives_widget_grab_focus(okbutton);
 
 
@@ -394,7 +395,7 @@ boolean do_audio_choice_dialog(short startup_phase) {
 
   lives_widget_show_all(dialog);
 
-  response=lives_dialog_run(GTK_DIALOG(dialog));
+  response=lives_dialog_run(LIVES_DIALOG(dialog));
 
   lives_widget_destroy(dialog);
 
@@ -410,10 +411,10 @@ boolean do_audio_choice_dialog(short startup_phase) {
 }
 
 
-static void add_test(GtkWidget *table, gint row, gchar *ttext, boolean noskip) {
+static void add_test(GtkWidget *table, int row, gchar *ttext, boolean noskip) {
   GtkWidget *label=lives_standard_label_new(ttext);
 
-  lives_table_attach (GTK_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+  lives_table_attach (LIVES_TABLE (table), label, 0, 1, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
   lives_widget_show(label);
 
   if (!noskip) {
@@ -421,10 +422,10 @@ static void add_test(GtkWidget *table, gint row, gchar *ttext, boolean noskip) {
     // TRANSLATORS - as in "skipped test"
     label=lives_standard_label_new(_("Skipped"));
 
-    lives_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+    lives_table_attach (LIVES_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
     lives_widget_show(label);
 
-    lives_table_attach (GTK_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
+    lives_table_attach (LIVES_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
     lives_widget_show(image);
   }
 
@@ -432,15 +433,15 @@ static void add_test(GtkWidget *table, gint row, gchar *ttext, boolean noskip) {
 }
 
 
-static boolean pass_test(GtkWidget *table, gint row) {
+static boolean pass_test(GtkWidget *table, int row) {
   // TRANSLATORS - as in "passed test"
   GtkWidget *label=lives_standard_label_new(_("Passed"));
   GtkWidget *image=lives_image_new_from_stock(GTK_STOCK_APPLY,LIVES_ICON_SIZE_LARGE_TOOLBAR);
 
-  lives_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+  lives_table_attach (LIVES_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
   lives_widget_show(label);
 
-  lives_table_attach (GTK_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
+  lives_table_attach (LIVES_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
   lives_widget_show(image);
 
   lives_widget_context_update();
@@ -448,22 +449,22 @@ static boolean pass_test(GtkWidget *table, gint row) {
 }
 
 
-static boolean fail_test(GtkWidget *table, gint row, gchar *ftext) {
+static boolean fail_test(GtkWidget *table, int row, gchar *ftext) {
   GtkWidget *label;
   GtkWidget *image=lives_image_new_from_stock(GTK_STOCK_CANCEL,LIVES_ICON_SIZE_LARGE_TOOLBAR);
 
   label=lives_standard_label_new(ftext);
 
-  lives_table_attach (GTK_TABLE (table), label, 3, 4, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+  lives_table_attach (LIVES_TABLE (table), label, 3, 4, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
   lives_widget_show(label);
   
   // TRANSLATORS - as in "failed test"
   label=lives_standard_label_new(_("Failed"));
 
-  lives_table_attach (GTK_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
+  lives_table_attach (LIVES_TABLE (table), label, 1, 2, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 10, 10);
   lives_widget_show(label);
 
-  lives_table_attach (GTK_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
+  lives_table_attach (LIVES_TABLE (table), image, 2, 3, row, row+1, (GtkAttachOptions)0, (GtkAttachOptions)0, 0, 10);
   lives_widget_show(image);
 
   lives_widget_context_update();
@@ -492,15 +493,16 @@ boolean do_startup_tests(boolean tshoot) {
   gchar *com,*rname,*afile,*tmp;
   gchar *image_ext=g_strdup(prefs->image_ext);
   gchar *title;
-  guchar *abuff;
+
+  uint8_t *abuff;
 
   size_t fsize;
 
   boolean success,success2,success3,success4;
   boolean imgext_switched=FALSE;
 
-  gint response,res;
-  gint current_file=mainw->current_file;
+  int response,res;
+  int current_file=mainw->current_file;
 
   int out_fd,info_fd;
 
@@ -526,38 +528,38 @@ boolean do_startup_tests(boolean tshoot) {
   dialog = lives_standard_dialog_new (title,FALSE);
 
   accel_group = GTK_ACCEL_GROUP(lives_accel_group_new ());
-  gtk_window_add_accel_group (GTK_WINDOW (dialog), accel_group);
+  lives_window_add_accel_group (LIVES_WINDOW (dialog), accel_group);
 
   g_free(title);
 
-  dialog_vbox = lives_dialog_get_content_area(GTK_DIALOG(dialog));
+  dialog_vbox = lives_dialog_get_content_area(LIVES_DIALOG(dialog));
 
   label=lives_standard_label_new(_("LiVES will now run some basic configuration tests\n"));
   lives_container_add (LIVES_CONTAINER (dialog_vbox), label);
 
-  cancelbutton = gtk_button_new_from_stock ("gtk-cancel");
+  cancelbutton = lives_button_new_from_stock ("gtk-cancel");
   lives_widget_show (cancelbutton);
-  lives_dialog_add_action_widget (GTK_DIALOG (dialog), cancelbutton, GTK_RESPONSE_CANCEL);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), cancelbutton, GTK_RESPONSE_CANCEL);
 
   lives_widget_add_accelerator (cancelbutton, "activate", accel_group,
                               LIVES_KEY_Escape, (GdkModifierType)0, (GtkAccelFlags)0);
 
   if (!tshoot) {
-    okbutton = gtk_button_new_from_stock ("gtk-go-forward");
+    okbutton = lives_button_new_from_stock ("gtk-go-forward");
     lives_button_set_label(GTK_BUTTON(okbutton),_("_Next"));
   }
-  else okbutton = gtk_button_new_from_stock ("gtk-ok");
+  else okbutton = lives_button_new_from_stock ("gtk-ok");
   lives_widget_show (okbutton);
-  lives_dialog_add_action_widget (GTK_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (okbutton);
-  gtk_widget_grab_default(okbutton);
+  lives_widget_grab_default(okbutton);
   lives_widget_grab_focus(okbutton);
 
 
   lives_widget_set_sensitive(okbutton,FALSE);
 
 
-  table = gtk_table_new (10, 4, FALSE);
+  table = lives_table_new (10, 4, FALSE);
   lives_container_add (LIVES_CONTAINER (dialog_vbox), table);
 
   lives_widget_show_all(dialog);
@@ -600,7 +602,7 @@ boolean do_startup_tests(boolean tshoot) {
     else mainw->write_failed=FALSE;
 
     if (!mainw->write_failed) {
-      abuff=(guchar *)lives_calloc(44100,4);
+      abuff=(uint8_t *)lives_calloc(44100,4);
       if (!abuff) {
 	tmp=g_strdup(_("Unable to allocate 176400 bytes memory."));
 	fail_test(table,1,tmp);
@@ -867,7 +869,7 @@ boolean do_startup_tests(boolean tshoot) {
     lives_widget_show(label);
   }
 
-  response=lives_dialog_run(GTK_DIALOG(dialog));
+  response=lives_dialog_run(LIVES_DIALOG(dialog));
 
   lives_widget_destroy(dialog);
   mainw->suppress_dprint=FALSE;
@@ -910,7 +912,7 @@ void do_startup_interface_query(void) {
 
   dialog = lives_standard_dialog_new (_("LiVES: - Choose the startup interface"),FALSE);
 
-  dialog_vbox = lives_dialog_get_content_area(GTK_DIALOG(dialog));
+  dialog_vbox = lives_dialog_get_content_area(LIVES_DIALOG(dialog));
   
   label=lives_standard_label_new(msg);
   lives_container_add (LIVES_CONTAINER (dialog_vbox), label);
@@ -938,19 +940,19 @@ void do_startup_interface_query(void) {
     lives_toggle_button_set_active(LIVES_TOGGLE_BUTTON(radiobutton1),TRUE);
   }
 
-  okbutton = gtk_button_new_from_stock ("gtk-go-forward");
+  okbutton = lives_button_new_from_stock ("gtk-go-forward");
   lives_button_set_label(GTK_BUTTON(okbutton),_("_Finish"));
 
   lives_widget_show (okbutton);
-  lives_dialog_add_action_widget (GTK_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
+  lives_dialog_add_action_widget (LIVES_DIALOG (dialog), okbutton, GTK_RESPONSE_OK);
   lives_widget_set_can_focus_and_default (okbutton);
-  gtk_widget_grab_default(okbutton);
+  lives_widget_grab_default(okbutton);
   lives_widget_grab_focus(okbutton);
 
 
   lives_widget_show_all(dialog);
 
-  lives_dialog_run(GTK_DIALOG(dialog));
+  lives_dialog_run(LIVES_DIALOG(dialog));
 
 
   if (lives_toggle_button_get_active(LIVES_TOGGLE_BUTTON(radiobutton1))) 
@@ -966,7 +968,6 @@ void do_startup_interface_query(void) {
 
 
 
-void on_troubleshoot_activate                     (GtkMenuItem     *menuitem,
-						   gpointer         user_data) {
+void on_troubleshoot_activate (GtkMenuItem *menuitem, gpointer user_data) {
   do_startup_tests(TRUE);
 }
