@@ -47,8 +47,10 @@ typedef cairo_operator_t lives_painter_operator_t;
 #define LIVES_PAINTER_OPERATOR_DEST_OUT CAIRO_OPERATOR_DEST_OUT
 #if CAIRO_VERSION < CAIRO_VERSION_ENCODE(1, 10, 0)
 #define LIVES_PAINTER_OPERATOR_DIFFERENCE CAIRO_OPERATOR_OVER
+#define LIVES_PAINTER_OPERATOR_OVERLAY CAIRO_OPERATOR_OVER
 #else
 #define LIVES_PAINTER_OPERATOR_DIFFERENCE CAIRO_OPERATOR_DIFFERENCE
+#define LIVES_PAINTER_OPERATOR_OVERLAY CAIRO_OPERATOR_OVERLAY
 #endif
 
 typedef cairo_fill_rule_t lives_painter_fill_rule_t;
@@ -62,6 +64,12 @@ typedef cairo_fill_rule_t lives_painter_fill_rule_t;
 
 #ifdef GUI_GTK
 
+// needs testing with gtk+ 3,10,0+
+//#if GTK_CHECK_VERSION(3,10,0)
+//#define LIVES_TABLE_IS_GRID 1
+//#endif
+
+
 #ifndef G_ENCODE_VERSION
 #define G_ENCODE_VERSION(major,minor) ((major) << 16 | (minor) << 8)
 #endif
@@ -97,6 +105,7 @@ typedef GdkDeviceManager                  LiVESXDeviceManager;
 #else
 #define LIVES_WIDGET_EVENT_EXPOSE_EVENT "expose_event"
 #endif
+
 typedef GtkWidget                         LiVESWidget;
 typedef GtkWindow                         LiVESWindow;
 typedef GtkContainer                      LiVESContainer;
@@ -111,6 +120,8 @@ typedef GtkTextView                       LiVESTextView;
 typedef GtkEntry                          LiVESEntry;
 typedef GtkRadioButton                    LiVESRadioButton;
 typedef GtkSpinButton                     LiVESSpinButton;
+typedef GtkColorButton                    LiVESColorButton;
+typedef GtkToolButton                     LiVESToolButton;
 typedef GtkLabel                          LiVESLabel;
 typedef GtkImage                          LiVESImage;
 typedef GtkFileChooser                    LiVESFileChooser;
@@ -119,11 +130,13 @@ typedef GtkMenu                           LiVESMenu;
 typedef GtkMenuItem                       LiVESMenuItem;
 typedef GtkCheckMenuItem                  LiVESCheckMenuItem;
 typedef GtkImageMenuItem                  LiVESImageMenuItem;
+typedef GtkRadioMenuItem                  LiVESRadioMenuItem;
 typedef GtkTreeView                       LiVESTreeView;
 typedef GtkTreeModel                      LiVESTreeModel;
 typedef GtkTreeIter                       LiVESTreeIter;
-typedef GtkTable                          LiVESTable;
 typedef GtkScrolledWindow                 LiVESScrolledWindow;
+typedef GtkToolbar                        LiVESToolbar;
+typedef GtkToolItem                       LiVESToolItem;
 
 #if GTK_CHECK_VERSION(2,14,0)
 typedef GtkScaleButton                    LiVESScaleButton;
@@ -137,6 +150,12 @@ typedef GtkGrid                           LiVESGrid;
 typedef GtkWidget                         LiVESGrid;
 #endif
 
+#ifdef LIVES_TABLE_IS_GRID
+typedef GtkGrid                           LiVESTable;
+#else
+typedef GtkTable                          LiVESTable;
+#endif
+
 typedef GClosure                          LiVESWidgetClosure;
 
 
@@ -173,6 +192,8 @@ typedef GtkStateType LiVESWidgetState;
 #define LIVES_WIDGET_STATE_BACKDROP       GTK_STATE_INSENSITIVE+3
 #endif
 
+
+// TODO - change enums for #defines to allow c++ compilation
 typedef enum {
   LIVES_EXPAND=GTK_EXPAND,
   LIVES_SHRINK=GTK_SHRINK,
@@ -242,6 +263,9 @@ typedef enum {
 
 #define LIVES_ACCEL_VISIBLE GTK_ACCEL_VISIBLE
   
+#define lives_toolbar_style_t GtkToolbarStyle
+#define LIVES_TOOLBAR_ICONS GTK_TOOLBAR_ICONS
+#define LIVES_TOOLBAR_TEXT  GTK_TOOLBAR_TEXT
 
 
 #if GTK_CHECK_VERSION(3,0,0)
@@ -297,14 +321,19 @@ typedef gpointer                          livespointer;
 #define LIVES_FILES_CHOOSER(widget) GTK_FILE_CHOOSER(widget)
 #define LIVES_RADIO_BUTTON(widget) GTK_RADIO_BUTTON(widget)
 #define LIVES_SPIN_BUTTON(widget) GTK_SPIN_BUTTON(widget)
-#define LIVES_TABLE(widget) GTK_TABLE(widget)
+#define LIVES_COLOR_BUTTON(widget) GTK_COLOR_BUTTON(widget)
+#define LIVES_TOOL_BUTTON(widget) GTK_TOOL_BUTTON(widget)
+
 #define LIVES_MENU(widget) GTK_MENU(widget)
 #define LIVES_MENU_ITEM(widget) GTK_MENU_ITEM(widget)
 #define LIVES_IMAGE(widget) GTK_IMAGE(widget)
 #define LIVES_IMAGE_MENU_ITEM(widget) GTK_IMAGE_MENU_ITEM(widget)
 #define LIVES_CHECK_MENU_ITEM(widget) GTK_CHECK_MENU_ITEM(widget)
+#define LIVES_RADIO_MENU_ITEM(widget) GTK_RADIO_MENU_ITEM(widget)
 #define LIVES_FILE_CHOOSER(widget) GTK_FILE_CHOOSER(widget)
 #define LIVES_SCROLLED_WINDOW(widget) GTK_SCROLLED_WINDOW(widget)
+#define LIVES_TOOLBAR(widget) GTK_TOOLBAR(widget)
+#define LIVES_TOOL_ITEM(widget) GTK_TOOL_ITEM(widget)
 
 #if GTK_CHECK_VERSION(2,14,0)
 #define LIVES_SCALE_BUTTON(widget) GTK_SCALE_BUTTON(widget)
@@ -329,20 +358,32 @@ typedef gpointer                          livespointer;
 #define LIVES_GRID(widget) GTK_WIDGET(widget)
 #endif
 
+
+#if LIVES_TABLE_IS_GRID
+#define LIVES_TABLE(widget) GTK_GRID(widget)
+#else
+#define LIVES_TABLE(widget) GTK_TABLE(widget)
+#endif
+
 #define LIVES_RANGE(widget) GTK_RANGE(widget)
 
 #define LIVES_XEVENT(event) GDK_EVENT(event)
 
 #define LIVES_IS_WIDGET(widget) GTK_IS_WIDGET(widget)
 #define LIVES_IS_WINDOW(widget) GTK_IS_WINDOW(widget)
+#define LIVES_IS_CONTAINER(widget) GTK_IS_CONTAINER(widget)
+
 #if GTK_CHECK_VERSION(3,0,0)
 #define LIVES_IS_HBOX(widget) (GTK_IS_BOX(widget)&&gtk_orientable_get_orientation(GTK_ORIENTABLE(widget))==GTK_ORIENTATION_HORIZONTAL)
 #define LIVES_IS_VBOX(widget) (GTK_IS_BOX(widget)&&gtk_orientable_get_orientation(GTK_ORIENTABLE(widget))==GTK_ORIENTATION_HORIZONTAL)
+#define LIVES_IS_SCROLLABLE(widget) GTK_IS_SCROLLABLE(widget)
 #else
 #define LIVES_IS_HBOX(widget) GTK_IS_HBOX(widget)
 #define LIVES_IS_VBOX(widget) GTK_IS_VBOX(widget)
 #endif
+
 #define LIVES_IS_COMBO(widget) GTK_IS_COMBO_BOX(widget)
+#define LIVES_IS_LABEL(widget) GTK_IS_LABEL(widget)
 #define LIVES_IS_BUTTON(widget) GTK_IS_BUTTON(widget)
 #define LIVES_IS_IMAGE(widget) GTK_IS_IMAGE(widget)
 #define LIVES_IS_ENTRY(widget) GTK_IS_ENTRY(widget)
@@ -361,6 +402,12 @@ typedef GLogLevelFlags LiVESLogLevelFlags;
 #define LIVES_LOG_LEVEL_CRITICAL G_LOG_LEVEL_CRITICAL
 #define LIVES_LOG_FATAL_MASK G_LOG_FATAL_MASK
 
+
+// stock images for buttons etc.
+#define LIVES_STOCK_ADD GTK_STOCK_ADD
+#define LIVES_STOCK_REMOVE GTK_STOCK_REMOVE
+
+
 typedef GdkModifierType LiVESModifierType;
 
 #define LIVES_CONTROL_MASK GDK_CONTROL_MASK
@@ -641,6 +688,8 @@ LiVESPixbuf *lives_pixbuf_new_from_file_at_scale(const char *filename, int width
 LiVESPixbuf *lives_pixbuf_scale_simple(const LiVESPixbuf *src, int dest_width, int dest_height, 
 				       LiVESInterpType interp_type);
 
+boolean lives_pixbuf_saturate_and_pixelate(const LiVESPixbuf *src, LiVESPixbuf *dest, float saturation, boolean pixilate);
+
 // basic widget fns
 
 void lives_widget_set_sensitive(LiVESWidget *, boolean state);
@@ -660,20 +709,20 @@ void lives_widget_reparent(LiVESWidget *, LiVESWidget *new_parent);
 
 void lives_widget_set_app_paintable(LiVESWidget *widget, boolean paintable);
 
-void lives_widget_grab_default(LiVESWidget *);
-
 LiVESWidget *lives_event_box_new(void);
 LiVESWidget *lives_label_new(const char *text);
 LiVESWidget *lives_label_new_with_mnemonic(const char *text);
 LiVESWidget *lives_button_new(void);
 LiVESWidget *lives_button_new_from_stock(const char *stock_id);
 LiVESWidget *lives_button_new_with_label(const char *label);
+LiVESWidget *lives_button_new_with_mnemonic(const char *label);
+
+boolean lives_button_set_label(LiVESButton *, const char *label);
+
 LiVESWidget *lives_check_button_new(void);
 LiVESWidget *lives_check_button_new_with_label(const char *label);
 LiVESWidget *lives_spin_button_new(LiVESAdjustment *, double climb_rate, uint32_t digits);
 
-LiVESWidget *lives_window_new(lives_window_type_t wintype);
-
 int lives_dialog_run(LiVESDialog *);
 
 void lives_widget_set_bg_color(LiVESWidget *, LiVESWidgetState state, const LiVESWidgetColor *);
@@ -702,14 +751,35 @@ LiVESWidget *lives_dialog_get_action_area(LiVESDialog *);
 
 void lives_dialog_add_action_widget(LiVESDialog *, LiVESWidget *, int response_id);
 
-void lives_window_set_title(LiVESWindow *, const char *title);
-void lives_window_move(LiVESWindow *, int x, int y);
-void lives_window_resize(LiVESWindow *, int width, int height);
-void lives_window_present(LiVESWindow *);
-void lives_window_fullscreen(LiVESWindow *);
-void lives_window_unfullscreen(LiVESWindow *);
-void lives_window_maximize(LiVESWindow *);
-void lives_window_unmaximize(LiVESWindow *);
+LiVESWidget *lives_window_new(lives_window_type_t wintype);
+boolean lives_window_set_title(LiVESWindow *, const char *title);
+const char *lives_window_get_title(LiVESWindow *);
+boolean lives_window_set_transient_for(LiVESWindow *, LiVESWindow *parent);
+
+boolean lives_window_set_modal(LiVESWindow *, boolean modal);
+boolean lives_window_set_deletable(LiVESWindow *, boolean deletable);
+boolean lives_window_set_resizable(LiVESWindow *, boolean resizable);
+boolean lives_window_set_keep_below(LiVESWindow *, boolean keep_below);
+boolean lives_window_set_decorated(LiVESWindow *, boolean decorated);
+
+boolean lives_window_set_default_size(LiVESWindow *, int width, int height);
+
+boolean lives_window_set_screen(LiVESWindow *, LiVESXScreen *);
+
+boolean lives_window_move(LiVESWindow *, int x, int y);
+boolean lives_window_get_position(LiVESWindow *, int *x, int *y);
+boolean lives_window_resize(LiVESWindow *, int width, int height);
+boolean lives_window_present(LiVESWindow *);
+boolean lives_window_fullscreen(LiVESWindow *);
+boolean lives_window_unfullscreen(LiVESWindow *);
+boolean lives_window_maximize(LiVESWindow *);
+boolean lives_window_unmaximize(LiVESWindow *);
+boolean lives_window_set_hide_titlebar_when_maximized(LiVESWindow *, boolean setting);
+
+boolean lives_window_add_accel_group(LiVESWindow *, LiVESAccelGroup *group);
+boolean lives_window_remove_accel_group(LiVESWindow *, LiVESAccelGroup *group);
+
+boolean lives_window_has_toplevel_focus(LiVESWindow *);
 
 LiVESAdjustment *lives_adjustment_new(double value, double lower, double upper, 
 						   double step_increment, double page_increment, double page_size);
@@ -769,40 +839,48 @@ boolean lives_toggle_button_get_active(LiVESToggleButton *);
 void lives_toggle_button_set_active(LiVESToggleButton *, boolean active);
 
 
-LiVESWidget *lives_button_new_with_mnemonic(const char *label);
-
-void lives_button_set_label(LiVESButton *, const char *label);
-
-
 void lives_tooltips_set (LiVESWidget *, const char *tip_text);
 
 LiVESSList *lives_radio_button_get_group(LiVESRadioButton *);
+LiVESSList *lives_radio_menu_item_get_group(LiVESRadioMenuItem *);
 
 LiVESWidget *lives_widget_get_parent(LiVESWidget *);
 LiVESWidget *lives_widget_get_toplevel(LiVESWidget *);
 
 LiVESXWindow *lives_widget_get_xwindow(LiVESWidget *);
 
-void lives_widget_set_can_focus(LiVESWidget *, boolean state);
-void lives_widget_set_can_default(LiVESWidget *, boolean state);
+boolean lives_widget_set_can_focus(LiVESWidget *, boolean state);
+boolean lives_widget_set_can_default(LiVESWidget *, boolean state);
+boolean lives_widget_set_can_focus_and_default(LiVESWidget *);
 
-void lives_container_remove(LiVESContainer *, LiVESWidget *);
-void lives_container_add(LiVESContainer *, LiVESWidget *);
-void lives_container_set_border_width(LiVESContainer *, uint32_t width);
+boolean lives_container_remove(LiVESContainer *, LiVESWidget *);
+boolean lives_container_add(LiVESContainer *, LiVESWidget *);
+boolean lives_container_set_border_width(LiVESContainer *, uint32_t width);
 
 double lives_spin_button_get_value(LiVESSpinButton *);
 int lives_spin_button_get_value_as_int(LiVESSpinButton *);
 
 LiVESAdjustment *lives_spin_button_get_adjustment(LiVESSpinButton *);
 
-void lives_spin_button_set_value(LiVESSpinButton *, double value);
-void lives_spin_button_set_range(LiVESSpinButton *, double min, double max);
+boolean lives_spin_button_set_value(LiVESSpinButton *, double value);
+boolean lives_spin_button_set_range(LiVESSpinButton *, double min, double max);
 
-void lives_spin_button_set_wrap(LiVESSpinButton *, boolean wrap);
+boolean lives_spin_button_set_wrap(LiVESSpinButton *, boolean wrap);
 
-void lives_spin_button_set_digits(LiVESSpinButton *, uint32_t digits);
+boolean lives_spin_button_set_digits(LiVESSpinButton *, uint32_t digits);
 
-void lives_spin_button_update(LiVESSpinButton *);
+boolean lives_spin_button_update(LiVESSpinButton *);
+
+LiVESWidget *lives_color_button_new_with_color(const LiVESWidgetColor *);
+boolean lives_color_button_get_color(LiVESColorButton *, LiVESWidgetColor *);
+boolean lives_color_button_set_color(LiVESColorButton *, const LiVESWidgetColor *);
+boolean lives_color_button_set_title(LiVESColorButton *, const char *title);
+boolean lives_color_button_set_use_alpha(LiVESColorButton *, boolean use_alpha);
+
+LiVESToolItem *lives_tool_button_new(LiVESWidget *icon_widget, const char *label);
+boolean lives_tool_button_set_icon_widget(LiVESToolButton *, LiVESWidget *icon);
+boolean lives_tool_button_set_label_widget(LiVESToolButton *, LiVESWidget *label);
+boolean lives_tool_button_set_use_underline(LiVESToolButton *, boolean use_underline);
 
 double lives_ruler_get_value(LiVESRuler *);
 double lives_ruler_set_value(LiVESRuler *, double value);
@@ -811,6 +889,13 @@ void lives_ruler_set_range(LiVESRuler *, double lower, double upper, double posi
 double lives_ruler_set_upper(LiVESRuler *, double value);
 double lives_ruler_set_lower(LiVESRuler *, double value);
 
+LiVESWidget *lives_toolbar_new(void);
+boolean lives_toolbar_insert(LiVESToolbar *, LiVESToolItem *, int pos);
+boolean lives_toolbar_set_show_arrow(LiVESToolbar *, boolean show);
+lives_icon_size_t lives_toolbar_get_icon_size(LiVESToolbar *);
+boolean lives_toolbar_set_icon_size(LiVESToolbar *, lives_icon_size_t icon_size);
+boolean lives_toolbar_set_style(LiVESToolbar *, lives_toolbar_style_t style);
+
 int lives_widget_get_allocation_x(LiVESWidget *);
 int lives_widget_get_allocation_y(LiVESWidget *);
 int lives_widget_get_allocation_width(LiVESWidget *);
@@ -840,18 +925,31 @@ const char *lives_label_get_text(LiVESLabel *);
 void lives_label_set_text(LiVESLabel *, const char *text);
 void lives_label_set_text_with_mnemonic(LiVESLabel *, const char *text);
 
-void lives_entry_set_editable(LiVESEntry *, boolean editable);
+boolean lives_entry_set_editable(LiVESEntry *, boolean editable);
 const char *lives_entry_get_text(LiVESEntry *);
-void lives_entry_set_text(LiVESEntry *, const char *text);
+boolean lives_entry_set_text(LiVESEntry *, const char *text);
+boolean lives_entry_set_width_chars(LiVESEntry *, int nchars);
 
 double lives_scale_button_get_value(LiVESScaleButton *);
 
+LiVESWidget *lives_table_new(uint32_t rows, uint32_t cols, boolean homogeneous);
+boolean lives_table_set_row_spacings(LiVESTable *, uint32_t spacing);
+boolean lives_table_set_col_spacings(LiVESTable *, uint32_t spacing);
+boolean lives_table_resize(LiVESTable *, uint32_t rows, uint32_t cols);
+void lives_table_attach(LiVESTable *, LiVESWidget *child, uint32_t left, uint32_t right, 
+			uint32_t top, uint32_t bottom, lives_attach_options_t xoptions, lives_attach_options_t yoptions,
+			uint32_t xpad, uint32_t ypad);
+
+
 LiVESWidget *lives_grid_new(void);
 boolean lives_grid_set_row_spacing(LiVESGrid *, uint32_t spacing);
 boolean lives_grid_set_column_spacing(LiVESGrid *, uint32_t spacing);
 boolean lives_grid_attach_next_to(LiVESGrid *, LiVESWidget *child, LiVESWidget *sibling, 
 				  lives_position_t side, int width, int height);
 
+boolean lives_grid_insert_row(LiVESGrid *, int posn);
+boolean lives_grid_remove_row(LiVESGrid *, int posn);
+
 LiVESWidget *lives_menu_new(void);
 
 void lives_menu_popup(LiVESMenu *, LiVESXEventButton *);
@@ -861,6 +959,7 @@ LiVESWidget *lives_menu_item_new_with_mnemonic(const char *label);
 LiVESWidget *lives_menu_item_new_with_label(const char *label);
 LiVESWidget *lives_check_menu_item_new_with_mnemonic(const char *label);
 LiVESWidget *lives_check_menu_item_new_with_label(const char *label);
+LiVESWidget *lives_radio_menu_item_new_with_label(LiVESSList *group, const char *label);
 LiVESWidget *lives_image_menu_item_new_with_label(const char *label);
 LiVESWidget *lives_image_menu_item_new_with_mnemonic(const char *label);
 LiVESWidget *lives_image_menu_item_new_from_stock(const char *stock_id, LiVESAccelGroup *accel_group);
@@ -870,20 +969,18 @@ void lives_image_menu_item_set_image(LiVESImageMenuItem *, LiVESWidget *image);
 void lives_menu_item_set_submenu(LiVESMenuItem *, LiVESWidget *);
 
 void lives_check_menu_item_set_active(LiVESCheckMenuItem *, boolean state);
+boolean lives_check_menu_item_get_active(LiVESCheckMenuItem *);
 
 void lives_menu_set_title(LiVESMenu *, const char *title);
 
 char *lives_file_chooser_get_filename(LiVESFileChooser *);
 LiVESSList *lives_file_chooser_get_filenames(LiVESFileChooser *);
 
-void lives_widget_grab_focus(LiVESWidget *);
+boolean lives_widget_grab_focus(LiVESWidget *);
+boolean lives_widget_grab_default(LiVESWidget *);
 
 void lives_widget_set_tooltip_text(LiVESWidget *, const char *text);
 
-void lives_table_attach(LiVESTable *, LiVESWidget *child, uint32_t left, uint32_t right, 
-			uint32_t top, uint32_t bottom, lives_attach_options_t xoptions, lives_attach_options_t yoptions,
-			uint32_t xpad, uint32_t ypad);
-
 
 LiVESAccelGroup *lives_accel_group_new(void);
 void lives_accel_group_connect(LiVESAccelGroup *, uint32_t key, LiVESModifierType mod, LiVESAccelFlags flags, LiVESWidgetClosure *closure);
@@ -912,6 +1009,10 @@ boolean lives_widget_set_hexpand(LiVESWidget *, boolean state);
 boolean lives_widget_set_vexpand(LiVESWidget *, boolean state);
 boolean lives_image_menu_item_set_always_show_image(LiVESImageMenuItem *, boolean show);
 boolean lives_scale_button_set_orientation(LiVESScaleButton *, LiVESOrientation orientation);
+boolean lives_window_set_auto_startup_notification(boolean set);
+
+
+
 
 // compound functions (composed of basic functions)
 
@@ -945,6 +1046,7 @@ LiVESWidget *lives_volume_button_new(LiVESOrientation orientation, LiVESAdjustme
 LiVESWidget *lives_standard_file_button_new(boolean is_dir, const char *def_dir);
 
 
+
 // util functions
 
 void lives_widget_apply_theme(LiVESWidget *, LiVESWidgetState state);
@@ -952,6 +1054,7 @@ void lives_widget_apply_theme(LiVESWidget *, LiVESWidgetState state);
 void lives_cursor_unref(LiVESXCursor *cursor);
 
 void lives_widget_context_update(void);
+void lives_widget_context_update_one(void);
 
 void lives_widget_get_fg_color(LiVESWidget *, LiVESWidgetColor *);
 void lives_widget_get_bg_color(LiVESWidget *, LiVESWidgetColor *);
@@ -988,9 +1091,6 @@ void hide_cursor(LiVESXWindow *);
 
 void get_border_size (LiVESWidget *win, int *bx, int *by);
 
-void lives_widget_set_can_focus(LiVESWidget *, boolean state);
-void lives_widget_set_can_focus_and_default(LiVESWidget *);
-
 void lives_general_button_clicked (LiVESButton *, livespointer data_to_free);
 
 LiVESWidget *add_hsep_to_box (LiVESBox *);
@@ -1017,6 +1117,7 @@ typedef enum {
   /// non-standard cursors
   LIVES_CURSOR_BLOCK,
   LIVES_CURSOR_AUDIO_BLOCK,
+  LIVES_CURSOR_VIDEO_BLOCK,
   LIVES_CURSOR_FX_BLOCK
 } lives_cursor_t;
 
